Class: Zitadel::Client::Models::ActionServiceEventExecution
- Inherits:
-
Object
- Object
- Zitadel::Client::Models::ActionServiceEventExecution
- Defined in:
- lib/zitadel/client/models/action_service_event_execution.rb
Instance Attribute Summary collapse
-
#all ⇒ Object
Define all events as condition.
-
#event ⇒ Object
Define a specific event as condition.
-
#group ⇒ Object
Define an event group as condition.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ActionServiceEventExecution
constructor
Initializes the object.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ActionServiceEventExecution
Initializes the object
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/zitadel/client/models/action_service_event_execution.rb', line 63 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) # MODIFIED: Updated class name in error message fail ArgumentError, "The input argument (attributes) must be a hash in `Zitadel::Client::Models::ActionServiceEventExecution` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) # MODIFIED: Updated class name in error message fail ArgumentError, "`#{k}` is not a valid attribute in `Zitadel::Client::Models::ActionServiceEventExecution`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'all') self.all = attributes[:'all'] end if attributes.key?(:'event') self.event = attributes[:'event'] end if attributes.key?(:'group') self.group = attributes[:'group'] end end |
Instance Attribute Details
#all ⇒ Object
Define all events as condition. After any event is created, the execution is triggered.
19 20 21 |
# File 'lib/zitadel/client/models/action_service_event_execution.rb', line 19 def all @all end |
#event ⇒ Object
Define a specific event as condition. After this event is created, the execution is triggered.
22 23 24 |
# File 'lib/zitadel/client/models/action_service_event_execution.rb', line 22 def event @event end |
#group ⇒ Object
Define an event group as condition. After any event under this group is created, the execution is triggered.
25 26 27 |
# File 'lib/zitadel/client/models/action_service_event_execution.rb', line 25 def group @group end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 |
# File 'lib/zitadel/client/models/action_service_event_execution.rb', line 141 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf/anyOf constructs that resolve to a model name # MODIFIED: Ensure model is looked up in the Models namespace # 'type' here is expected to be the simple class name (e.g., "User", "OrderDetails") klass = Zitadel::Client::Models.const_get(type) # The `klass.build` method is for oneOf/anyOf types (defined in partial_oneof_module.mustache / partial_anyof_module.mustache) # The `klass.build_from_hash` is for regular model types (defined in this base_object.mustache itself) if klass.respond_to?(:openapi_one_of) || klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_allOf) klass.build(value) # For oneOf/anyOf/allOf, delegate to their specific build method else klass.build_from_hash(value) # For regular models end end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
37 38 39 |
# File 'lib/zitadel/client/models/action_service_event_execution.rb', line 37 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
42 43 44 |
# File 'lib/zitadel/client/models/action_service_event_execution.rb', line 42 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
28 29 30 31 32 33 34 |
# File 'lib/zitadel/client/models/action_service_event_execution.rb', line 28 def self.attribute_map { :'all' => :'all', :'event' => :'event', :'group' => :'group' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 |
# File 'lib/zitadel/client/models/action_service_event_execution.rb', line 117 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) # `new` will call the initialize method of the specific model class. end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
56 57 58 59 |
# File 'lib/zitadel/client/models/action_service_event_execution.rb', line 56 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
47 48 49 50 51 52 53 |
# File 'lib/zitadel/client/models/action_service_event_execution.rb', line 47 def self.openapi_types { :'all' => :'Boolean', :'event' => :'String', :'group' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
94 95 96 97 98 99 100 |
# File 'lib/zitadel/client/models/action_service_event_execution.rb', line 94 def ==(o) return true if self.equal?(o) self.class == o.class && all == o.all && event == o.event && group == o.group end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
220 221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/zitadel/client/models/action_service_event_execution.rb', line 220 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
104 105 106 |
# File 'lib/zitadel/client/models/action_service_event_execution.rb', line 104 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
110 111 112 |
# File 'lib/zitadel/client/models/action_service_event_execution.rb', line 110 def hash [all, event, group].hash end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
196 197 198 |
# File 'lib/zitadel/client/models/action_service_event_execution.rb', line 196 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
202 203 204 205 206 207 208 209 210 211 212 213 214 |
# File 'lib/zitadel/client/models/action_service_event_execution.rb', line 202 def to_hash hash = {} # Calls super.to_hash if parent exists self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
190 191 192 |
# File 'lib/zitadel/client/models/action_service_event_execution.rb', line 190 def to_s to_hash.to_s end |