Class: Zitadel::Client::Models::ApplicationServiceCreateApplicationRequest
- Inherits:
-
Object
- Object
- Zitadel::Client::Models::ApplicationServiceCreateApplicationRequest
- Defined in:
- lib/zitadel/client/models/application_service_create_application_request.rb
Instance Attribute Summary collapse
-
#api_configuration ⇒ Object
Returns the value of attribute api_configuration.
-
#application_id ⇒ Object
Optionally, provide the unique ID of the new application.
-
#name ⇒ Object
Publicly visible name of the application.
-
#oidc_configuration ⇒ Object
Returns the value of attribute oidc_configuration.
-
#project_id ⇒ Object
The ID of the project the application will be created in.
-
#saml_configuration ⇒ Object
Returns the value of attribute saml_configuration.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ApplicationServiceCreateApplicationRequest
constructor
Initializes the object.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ApplicationServiceCreateApplicationRequest
Initializes the object
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/zitadel/client/models/application_service_create_application_request.rb', line 75 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) # MODIFIED: Updated class name in error message fail ArgumentError, "The input argument (attributes) must be a hash in `Zitadel::Client::Models::ApplicationServiceCreateApplicationRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) # MODIFIED: Updated class name in error message fail ArgumentError, "`#{k}` is not a valid attribute in `Zitadel::Client::Models::ApplicationServiceCreateApplicationRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'project_id') self.project_id = attributes[:'project_id'] end if attributes.key?(:'application_id') self.application_id = attributes[:'application_id'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'api_configuration') self.api_configuration = attributes[:'api_configuration'] end if attributes.key?(:'oidc_configuration') self.oidc_configuration = attributes[:'oidc_configuration'] end if attributes.key?(:'saml_configuration') self.saml_configuration = attributes[:'saml_configuration'] end end |
Instance Attribute Details
#api_configuration ⇒ Object
Returns the value of attribute api_configuration.
27 28 29 |
# File 'lib/zitadel/client/models/application_service_create_application_request.rb', line 27 def api_configuration @api_configuration end |
#application_id ⇒ Object
Optionally, provide the unique ID of the new application. If omitted, the system will generate one for you, which is the recommended way. The generated ID will be returned in the response.
22 23 24 |
# File 'lib/zitadel/client/models/application_service_create_application_request.rb', line 22 def application_id @application_id end |
#name ⇒ Object
Publicly visible name of the application. This might be presented to users if they sign in.
25 26 27 |
# File 'lib/zitadel/client/models/application_service_create_application_request.rb', line 25 def name @name end |
#oidc_configuration ⇒ Object
Returns the value of attribute oidc_configuration.
29 30 31 |
# File 'lib/zitadel/client/models/application_service_create_application_request.rb', line 29 def oidc_configuration @oidc_configuration end |
#project_id ⇒ Object
The ID of the project the application will be created in.
19 20 21 |
# File 'lib/zitadel/client/models/application_service_create_application_request.rb', line 19 def project_id @project_id end |
#saml_configuration ⇒ Object
Returns the value of attribute saml_configuration.
31 32 33 |
# File 'lib/zitadel/client/models/application_service_create_application_request.rb', line 31 def saml_configuration @saml_configuration end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/zitadel/client/models/application_service_create_application_request.rb', line 168 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf/anyOf constructs that resolve to a model name # MODIFIED: Ensure model is looked up in the Models namespace # 'type' here is expected to be the simple class name (e.g., "User", "OrderDetails") klass = Zitadel::Client::Models.const_get(type) # The `klass.build` method is for oneOf/anyOf types (defined in partial_oneof_module.mustache / partial_anyof_module.mustache) # The `klass.build_from_hash` is for regular model types (defined in this base_object.mustache itself) if klass.respond_to?(:openapi_one_of) || klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_allOf) klass.build(value) # For oneOf/anyOf/allOf, delegate to their specific build method else klass.build_from_hash(value) # For regular models end end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
46 47 48 |
# File 'lib/zitadel/client/models/application_service_create_application_request.rb', line 46 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
51 52 53 |
# File 'lib/zitadel/client/models/application_service_create_application_request.rb', line 51 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
34 35 36 37 38 39 40 41 42 43 |
# File 'lib/zitadel/client/models/application_service_create_application_request.rb', line 34 def self.attribute_map { :'project_id' => :'projectId', :'application_id' => :'applicationId', :'name' => :'name', :'api_configuration' => :'apiConfiguration', :'oidc_configuration' => :'oidcConfiguration', :'saml_configuration' => :'samlConfiguration' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/zitadel/client/models/application_service_create_application_request.rb', line 144 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) # `new` will call the initialize method of the specific model class. end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
68 69 70 71 |
# File 'lib/zitadel/client/models/application_service_create_application_request.rb', line 68 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
56 57 58 59 60 61 62 63 64 65 |
# File 'lib/zitadel/client/models/application_service_create_application_request.rb', line 56 def self.openapi_types { :'project_id' => :'String', :'application_id' => :'String', :'name' => :'String', :'api_configuration' => :'ApplicationServiceCreateAPIApplicationRequest', :'oidc_configuration' => :'ApplicationServiceCreateOIDCApplicationRequest', :'saml_configuration' => :'ApplicationServiceCreateSAMLApplicationRequest' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
118 119 120 121 122 123 124 125 126 127 |
# File 'lib/zitadel/client/models/application_service_create_application_request.rb', line 118 def ==(o) return true if self.equal?(o) self.class == o.class && project_id == o.project_id && application_id == o.application_id && name == o.name && api_configuration == o.api_configuration && oidc_configuration == o.oidc_configuration && saml_configuration == o.saml_configuration end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
247 248 249 250 251 252 253 254 255 256 257 258 259 |
# File 'lib/zitadel/client/models/application_service_create_application_request.rb', line 247 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
131 132 133 |
# File 'lib/zitadel/client/models/application_service_create_application_request.rb', line 131 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
137 138 139 |
# File 'lib/zitadel/client/models/application_service_create_application_request.rb', line 137 def hash [project_id, application_id, name, api_configuration, oidc_configuration, saml_configuration].hash end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
223 224 225 |
# File 'lib/zitadel/client/models/application_service_create_application_request.rb', line 223 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
229 230 231 232 233 234 235 236 237 238 239 240 241 |
# File 'lib/zitadel/client/models/application_service_create_application_request.rb', line 229 def to_hash hash = {} # Calls super.to_hash if parent exists self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
217 218 219 |
# File 'lib/zitadel/client/models/application_service_create_application_request.rb', line 217 def to_s to_hash.to_s end |