Class: Zitadel::Client::Models::ApplicationServiceOIDCConfiguration

Inherits:
Object
  • Object
show all
Defined in:
lib/zitadel/client/models/application_service_o_i_d_c_configuration.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ApplicationServiceOIDCConfiguration

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Models attributes in the form of hash



170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
# File 'lib/zitadel/client/models/application_service_o_i_d_c_configuration.rb', line 170

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    # MODIFIED: Updated class name in error message
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zitadel::Client::Models::ApplicationServiceOIDCConfiguration` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      # MODIFIED: Updated class name in error message
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zitadel::Client::Models::ApplicationServiceOIDCConfiguration`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'redirect_uris')
    if (value = attributes[:'redirect_uris']).is_a?(Array)
      self.redirect_uris = value
    end
  end

  if attributes.key?(:'response_types')
    if (value = attributes[:'response_types']).is_a?(Array)
      self.response_types = value
    end
  end

  if attributes.key?(:'grant_types')
    if (value = attributes[:'grant_types']).is_a?(Array)
      self.grant_types = value
    end
  end

  if attributes.key?(:'application_type')
    self.application_type = attributes[:'application_type']
  end

  if attributes.key?(:'client_id')
    self.client_id = attributes[:'client_id']
  end

  if attributes.key?(:'auth_method_type')
    self.auth_method_type = attributes[:'auth_method_type']
  end

  if attributes.key?(:'post_logout_redirect_uris')
    if (value = attributes[:'post_logout_redirect_uris']).is_a?(Array)
      self.post_logout_redirect_uris = value
    end
  end

  if attributes.key?(:'version')
    self.version = attributes[:'version']
  end

  if attributes.key?(:'non_compliant')
    self.non_compliant = attributes[:'non_compliant']
  end

  if attributes.key?(:'compliance_problems')
    if (value = attributes[:'compliance_problems']).is_a?(Array)
      self.compliance_problems = value
    end
  end

  if attributes.key?(:'development_mode')
    self.development_mode = attributes[:'development_mode']
  end

  if attributes.key?(:'access_token_type')
    self.access_token_type = attributes[:'access_token_type']
  end

  if attributes.key?(:'access_token_role_assertion')
    self.access_token_role_assertion = attributes[:'access_token_role_assertion']
  end

  if attributes.key?(:'id_token_role_assertion')
    self.id_token_role_assertion = attributes[:'id_token_role_assertion']
  end

  if attributes.key?(:'id_token_userinfo_assertion')
    self.id_token_userinfo_assertion = attributes[:'id_token_userinfo_assertion']
  end

  if attributes.key?(:'clock_skew')
    self.clock_skew = attributes[:'clock_skew']
  end

  if attributes.key?(:'additional_origins')
    if (value = attributes[:'additional_origins']).is_a?(Array)
      self.additional_origins = value
    end
  end

  if attributes.key?(:'allowed_origins')
    if (value = attributes[:'allowed_origins']).is_a?(Array)
      self.allowed_origins = value
    end
  end

  if attributes.key?(:'skip_native_app_success_page')
    self.skip_native_app_success_page = attributes[:'skip_native_app_success_page']
  end

  if attributes.key?(:'back_channel_logout_uri')
    self.back_channel_logout_uri = attributes[:'back_channel_logout_uri']
  end

  if attributes.key?(:'login_version')
    self. = attributes[:'login_version']
  end
end

Instance Attribute Details

#access_token_role_assertionObject

If AccessTokenRoleAssertion is enabled, the roles of the user are added to the access token. Ensure that the access token is a JWT token and not a bearer token. And either request the roles by scope or enable the user role assertion on the project.



51
52
53
# File 'lib/zitadel/client/models/application_service_o_i_d_c_configuration.rb', line 51

def access_token_role_assertion
  @access_token_role_assertion
end

#access_token_typeObject

Returns the value of attribute access_token_type.



48
49
50
# File 'lib/zitadel/client/models/application_service_o_i_d_c_configuration.rb', line 48

def access_token_type
  @access_token_type
end

#additional_originsObject

AdditionalOrigins are HTTP origins (scheme + host + port) from where the API can be used additional to the redirect_uris. This is useful if the application is used from an origin different to the redirect_uris, e.g. if the application is a SPA served in a native app, where the redirect_uri is a custom scheme, but the application is served from a https origin.



63
64
65
# File 'lib/zitadel/client/models/application_service_o_i_d_c_configuration.rb', line 63

def additional_origins
  @additional_origins
end

#allowed_originsObject

AllowedOrigins are all HTTP origins where the application is allowed to be used from. This is used to prevent CORS issues in browsers. If the origin of the request is not in this list, the request will be rejected. This is especially important for SPAs. Note that this is a generated list from the redirect_uris and additional_origins. If you use the application from another origin, you have to add it to the additional_origins.



66
67
68
# File 'lib/zitadel/client/models/application_service_o_i_d_c_configuration.rb', line 66

def allowed_origins
  @allowed_origins
end

#application_typeObject

Returns the value of attribute application_type.



27
28
29
# File 'lib/zitadel/client/models/application_service_o_i_d_c_configuration.rb', line 27

def application_type
  @application_type
end

#auth_method_typeObject

Returns the value of attribute auth_method_type.



32
33
34
# File 'lib/zitadel/client/models/application_service_o_i_d_c_configuration.rb', line 32

def auth_method_type
  @auth_method_type
end

#back_channel_logout_uriObject

BackChannelLogoutURI is used to notify the application about terminated sessions according to the OIDC Back-Channel Logout (openid.net/specs/openid-connect-backchannel-1_0.html).



72
73
74
# File 'lib/zitadel/client/models/application_service_o_i_d_c_configuration.rb', line 72

def back_channel_logout_uri
  @back_channel_logout_uri
end

#client_idObject

The unique OAuth2/OIDC client_id used for authentication of the application, e.g. at the token endpoint.



30
31
32
# File 'lib/zitadel/client/models/application_service_o_i_d_c_configuration.rb', line 30

def client_id
  @client_id
end

#clock_skewObject

A Duration represents a signed, fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". It is related to Timestamp in that the difference between two Timestamp values is a Duration and it can be added or subtracted from a Timestamp. Range is approximately -10,000 years. # Examples Example 1: Compute Duration from two Timestamps in pseudo code. Timestamp start = …; Timestamp end = …; Duration duration = …; duration.seconds = end.seconds - start.seconds; duration.nanos = end.nanos - start.nanos; if (duration.seconds < 0 && duration.nanos > 0) { duration.seconds = 1; duration.nanos -= 1000000000; } else if (duration.seconds > 0 && duration.nanos < 0) { duration.seconds -= 1; duration.nanos = 1000000000; } Example 2: Compute Timestamp from Timestamp Duration in pseudo code. Timestamp start = …; Duration duration = …; Timestamp end = …; end.seconds = start.seconds + duration.seconds; end.nanos = start.nanos + duration.nanos; if (end.nanos < 0) { end.seconds -= 1; end.nanos = 1000000000; } else if (end.nanos >= 1000000000) { end.seconds = 1; end.nanos -= 1000000000; } Example 3: Compute Duration from datetime.timedelta in Python. td = datetime.timedelta(days=3, minutes=10) duration = Duration() duration.FromTimedelta(td) # JSON Mapping In JSON format, the Duration type is encoded as a string rather than an object, where the string ends in the suffix "s" (indicating seconds) and is preceded by the number of seconds, with nanoseconds expressed as fractional seconds. For example, 3 seconds with 0 nanoseconds should be encoded in JSON format as "3s", while 3 seconds and 1 nanosecond should be expressed in JSON format as "3.000000001s", and 3 seconds and 1 microsecond should be expressed in JSON format as "3.000001s".



60
61
62
# File 'lib/zitadel/client/models/application_service_o_i_d_c_configuration.rb', line 60

def clock_skew
  @clock_skew
end

#compliance_problemsObject

ComplianceProblems lists the problems for non-compliant configurations. In case of a compliant configuration, this list is empty.



43
44
45
# File 'lib/zitadel/client/models/application_service_o_i_d_c_configuration.rb', line 43

def compliance_problems
  @compliance_problems
end

#development_modeObject

DevelopmentMode can be enabled for development purposes. This allows the use of OIDC non-compliant and potentially insecure settings, such as the use of HTTP redirect URIs or wildcard redirect URIs.



46
47
48
# File 'lib/zitadel/client/models/application_service_o_i_d_c_configuration.rb', line 46

def development_mode
  @development_mode
end

#grant_typesObject

GrantTypes define the flow type the application is allowed to use. The grant_type parameter in the token request must exactly match one of these values.



25
26
27
# File 'lib/zitadel/client/models/application_service_o_i_d_c_configuration.rb', line 25

def grant_types
  @grant_types
end

#id_token_role_assertionObject

If IDTokenRoleAssertion is enabled, the roles of the user are added to the id token. Ensure that either the roles are requested by scope or enable the user role assertion on the project.



54
55
56
# File 'lib/zitadel/client/models/application_service_o_i_d_c_configuration.rb', line 54

def id_token_role_assertion
  @id_token_role_assertion
end

#id_token_userinfo_assertionObject

If IDTokenUserinfoAssertion is enabled, the claims of profile, email, address and phone scopes are added to the id token even if an access token is issued. This can be required by some applications that do not call the userinfo endpoint after authentication or directly use the id_token for retrieving user information. Attention: this violates the OIDC specification, which states that these claims must only be requested from the userinfo endpoint if an access token is issued. This is to prevent leaking of personal information in the id token, which is often stored in the browser and therefore more vulnerable.



57
58
59
# File 'lib/zitadel/client/models/application_service_o_i_d_c_configuration.rb', line 57

def id_token_userinfo_assertion
  @id_token_userinfo_assertion
end

#login_versionObject

Returns the value of attribute login_version.



74
75
76
# File 'lib/zitadel/client/models/application_service_o_i_d_c_configuration.rb', line 74

def 
  @login_version
end

#non_compliantObject

NonCompliant specifies whether the config is OIDC compliant. A production configuration SHOULD be compliant. Non-compliant configurations can run into interoperability issues with OIDC libraries and tools. Compliance problems are listed in the compliance_problems field.



40
41
42
# File 'lib/zitadel/client/models/application_service_o_i_d_c_configuration.rb', line 40

def non_compliant
  @non_compliant
end

#post_logout_redirect_urisObject

PostLogoutRedirectURIs are the allowed URIs to redirect to after a logout. The post_logout_redirect_uri parameter in the logout request must exactly match one of these URIs.



35
36
37
# File 'lib/zitadel/client/models/application_service_o_i_d_c_configuration.rb', line 35

def post_logout_redirect_uris
  @post_logout_redirect_uris
end

#redirect_urisObject

RedirectURIs are the allowed callback URIs for the OAuth2 / OIDC flows, where the authorization code or tokens will be sent to. The redirect_uri parameter in the authorization request must exactly match one of these URIs.



19
20
21
# File 'lib/zitadel/client/models/application_service_o_i_d_c_configuration.rb', line 19

def redirect_uris
  @redirect_uris
end

#response_typesObject

ResponseTypes define whether a code, id_token token or just id_token will be returned. The response_type parameter in the authorization request must exactly match one of these values.



22
23
24
# File 'lib/zitadel/client/models/application_service_o_i_d_c_configuration.rb', line 22

def response_types
  @response_types
end

#skip_native_app_success_pageObject

For native apps a successful login usually shows a success page with a link to open the application again. SkipNativeAppSuccessPage can be used to skip this page and open the application directly.



69
70
71
# File 'lib/zitadel/client/models/application_service_o_i_d_c_configuration.rb', line 69

def skip_native_app_success_page
  @skip_native_app_success_page
end

#versionObject

Returns the value of attribute version.



37
38
39
# File 'lib/zitadel/client/models/application_service_o_i_d_c_configuration.rb', line 37

def version
  @version
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
# File 'lib/zitadel/client/models/application_service_o_i_d_c_configuration.rb', line 352

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf/anyOf constructs that resolve to a model name
    # MODIFIED: Ensure model is looked up in the Models namespace
    # 'type' here is expected to be the simple class name (e.g., "User", "OrderDetails")
    klass = Zitadel::Client::Models.const_get(type)
    # The `klass.build` method is for oneOf/anyOf types (defined in partial_oneof_module.mustache / partial_anyof_module.mustache)
    # The `klass.build_from_hash` is for regular model types (defined in this base_object.mustache itself)
    if klass.respond_to?(:openapi_one_of) || klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_allOf)
      klass.build(value) # For oneOf/anyOf/allOf, delegate to their specific build method
    else
      klass.build_from_hash(value) # For regular models
    end
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



126
127
128
# File 'lib/zitadel/client/models/application_service_o_i_d_c_configuration.rb', line 126

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



131
132
133
# File 'lib/zitadel/client/models/application_service_o_i_d_c_configuration.rb', line 131

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'lib/zitadel/client/models/application_service_o_i_d_c_configuration.rb', line 99

def self.attribute_map
  {
    :'redirect_uris' => :'redirectUris',
    :'response_types' => :'responseTypes',
    :'grant_types' => :'grantTypes',
    :'application_type' => :'applicationType',
    :'client_id' => :'clientId',
    :'auth_method_type' => :'authMethodType',
    :'post_logout_redirect_uris' => :'postLogoutRedirectUris',
    :'version' => :'version',
    :'non_compliant' => :'nonCompliant',
    :'compliance_problems' => :'complianceProblems',
    :'development_mode' => :'developmentMode',
    :'access_token_type' => :'accessTokenType',
    :'access_token_role_assertion' => :'accessTokenRoleAssertion',
    :'id_token_role_assertion' => :'idTokenRoleAssertion',
    :'id_token_userinfo_assertion' => :'idTokenUserinfoAssertion',
    :'clock_skew' => :'clockSkew',
    :'additional_origins' => :'additionalOrigins',
    :'allowed_origins' => :'allowedOrigins',
    :'skip_native_app_success_page' => :'skipNativeAppSuccessPage',
    :'back_channel_logout_uri' => :'backChannelLogoutUri',
    :'login_version' => :'loginVersion'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Models attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
# File 'lib/zitadel/client/models/application_service_o_i_d_c_configuration.rb', line 328

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash) # `new` will call the initialize method of the specific model class.
end

.openapi_nullableObject

List of attributes with nullable: true



163
164
165
166
# File 'lib/zitadel/client/models/application_service_o_i_d_c_configuration.rb', line 163

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
# File 'lib/zitadel/client/models/application_service_o_i_d_c_configuration.rb', line 136

def self.openapi_types
  {
    :'redirect_uris' => :'Array<String>',
    :'response_types' => :'Array<ApplicationServiceOIDCResponseType>',
    :'grant_types' => :'Array<ApplicationServiceOIDCGrantType>',
    :'application_type' => :'ApplicationServiceOIDCApplicationType',
    :'client_id' => :'String',
    :'auth_method_type' => :'ApplicationServiceOIDCAuthMethodType',
    :'post_logout_redirect_uris' => :'Array<String>',
    :'version' => :'ApplicationServiceOIDCVersion',
    :'non_compliant' => :'Boolean',
    :'compliance_problems' => :'Array<ApplicationServiceOIDCLocalizedMessage>',
    :'development_mode' => :'Boolean',
    :'access_token_type' => :'ApplicationServiceOIDCTokenType',
    :'access_token_role_assertion' => :'Boolean',
    :'id_token_role_assertion' => :'Boolean',
    :'id_token_userinfo_assertion' => :'Boolean',
    :'clock_skew' => :'String',
    :'additional_origins' => :'Array<String>',
    :'allowed_origins' => :'Array<String>',
    :'skip_native_app_success_page' => :'Boolean',
    :'back_channel_logout_uri' => :'String',
    :'login_version' => :'ApplicationServiceLoginVersion'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
# File 'lib/zitadel/client/models/application_service_o_i_d_c_configuration.rb', line 287

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      redirect_uris == o.redirect_uris &&
      response_types == o.response_types &&
      grant_types == o.grant_types &&
      application_type == o.application_type &&
      client_id == o.client_id &&
      auth_method_type == o.auth_method_type &&
      post_logout_redirect_uris == o.post_logout_redirect_uris &&
      version == o.version &&
      non_compliant == o.non_compliant &&
      compliance_problems == o.compliance_problems &&
      development_mode == o.development_mode &&
      access_token_type == o.access_token_type &&
      access_token_role_assertion == o.access_token_role_assertion &&
      id_token_role_assertion == o.id_token_role_assertion &&
      id_token_userinfo_assertion == o.id_token_userinfo_assertion &&
      clock_skew == o.clock_skew &&
      additional_origins == o.additional_origins &&
      allowed_origins == o.allowed_origins &&
      skip_native_app_success_page == o.skip_native_app_success_page &&
      back_channel_logout_uri == o.back_channel_logout_uri &&
       == o.
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



431
432
433
434
435
436
437
438
439
440
441
442
443
# File 'lib/zitadel/client/models/application_service_o_i_d_c_configuration.rb', line 431

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


315
316
317
# File 'lib/zitadel/client/models/application_service_o_i_d_c_configuration.rb', line 315

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



321
322
323
# File 'lib/zitadel/client/models/application_service_o_i_d_c_configuration.rb', line 321

def hash
  [redirect_uris, response_types, grant_types, application_type, client_id, auth_method_type, post_logout_redirect_uris, version, non_compliant, compliance_problems, development_mode, access_token_type, access_token_role_assertion, id_token_role_assertion, id_token_userinfo_assertion, clock_skew, additional_origins, allowed_origins, skip_native_app_success_page, back_channel_logout_uri, ].hash
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



407
408
409
# File 'lib/zitadel/client/models/application_service_o_i_d_c_configuration.rb', line 407

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



413
414
415
416
417
418
419
420
421
422
423
424
425
# File 'lib/zitadel/client/models/application_service_o_i_d_c_configuration.rb', line 413

def to_hash
  hash = {} # Calls super.to_hash if parent exists
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



401
402
403
# File 'lib/zitadel/client/models/application_service_o_i_d_c_configuration.rb', line 401

def to_s
  to_hash.to_s
end