Class: Zitadel::Client::Models::AuthorizationServiceUser
- Inherits:
-
Object
- Object
- Zitadel::Client::Models::AuthorizationServiceUser
- Defined in:
- lib/zitadel/client/models/authorization_service_user.rb
Instance Attribute Summary collapse
-
#avatar_url ⇒ Object
AvatarURL is the URL to the user’s public avatar image.
-
#display_name ⇒ Object
DisplayName represents the public display name of the granted user.
-
#id ⇒ Object
ID represents the ID of the user who was granted the authorization.
-
#organization_id ⇒ Object
The organization the user belong to.
-
#preferred_login_name ⇒ Object
PreferredLoginName represents the preferred login name of the granted user.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AuthorizationServiceUser
constructor
Initializes the object.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ AuthorizationServiceUser
Initializes the object
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/zitadel/client/models/authorization_service_user.rb', line 73 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) # MODIFIED: Updated class name in error message fail ArgumentError, "The input argument (attributes) must be a hash in `Zitadel::Client::Models::AuthorizationServiceUser` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) # MODIFIED: Updated class name in error message fail ArgumentError, "`#{k}` is not a valid attribute in `Zitadel::Client::Models::AuthorizationServiceUser`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'preferred_login_name') self.preferred_login_name = attributes[:'preferred_login_name'] end if attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] end if attributes.key?(:'avatar_url') self.avatar_url = attributes[:'avatar_url'] end if attributes.key?(:'organization_id') self.organization_id = attributes[:'organization_id'] end end |
Instance Attribute Details
#avatar_url ⇒ Object
AvatarURL is the URL to the user’s public avatar image.
28 29 30 |
# File 'lib/zitadel/client/models/authorization_service_user.rb', line 28 def avatar_url @avatar_url end |
#display_name ⇒ Object
DisplayName represents the public display name of the granted user.
25 26 27 |
# File 'lib/zitadel/client/models/authorization_service_user.rb', line 25 def display_name @display_name end |
#id ⇒ Object
ID represents the ID of the user who was granted the authorization.
19 20 21 |
# File 'lib/zitadel/client/models/authorization_service_user.rb', line 19 def id @id end |
#organization_id ⇒ Object
The organization the user belong to. This does not have to correspond with the authorizations organization.
31 32 33 |
# File 'lib/zitadel/client/models/authorization_service_user.rb', line 31 def organization_id @organization_id end |
#preferred_login_name ⇒ Object
PreferredLoginName represents the preferred login name of the granted user.
22 23 24 |
# File 'lib/zitadel/client/models/authorization_service_user.rb', line 22 def preferred_login_name @preferred_login_name end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/zitadel/client/models/authorization_service_user.rb', line 161 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf/anyOf constructs that resolve to a model name # MODIFIED: Ensure model is looked up in the Models namespace # 'type' here is expected to be the simple class name (e.g., "User", "OrderDetails") klass = Zitadel::Client::Models.const_get(type) # The `klass.build` method is for oneOf/anyOf types (defined in partial_oneof_module.mustache / partial_anyof_module.mustache) # The `klass.build_from_hash` is for regular model types (defined in this base_object.mustache itself) if klass.respond_to?(:openapi_one_of) || klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_allOf) klass.build(value) # For oneOf/anyOf/allOf, delegate to their specific build method else klass.build_from_hash(value) # For regular models end end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
45 46 47 |
# File 'lib/zitadel/client/models/authorization_service_user.rb', line 45 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
50 51 52 |
# File 'lib/zitadel/client/models/authorization_service_user.rb', line 50 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
34 35 36 37 38 39 40 41 42 |
# File 'lib/zitadel/client/models/authorization_service_user.rb', line 34 def self.attribute_map { :'id' => :'id', :'preferred_login_name' => :'preferredLoginName', :'display_name' => :'displayName', :'avatar_url' => :'avatarUrl', :'organization_id' => :'organizationId' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/zitadel/client/models/authorization_service_user.rb', line 137 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) # `new` will call the initialize method of the specific model class. end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
66 67 68 69 |
# File 'lib/zitadel/client/models/authorization_service_user.rb', line 66 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
55 56 57 58 59 60 61 62 63 |
# File 'lib/zitadel/client/models/authorization_service_user.rb', line 55 def self.openapi_types { :'id' => :'String', :'preferred_login_name' => :'String', :'display_name' => :'String', :'avatar_url' => :'String', :'organization_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
112 113 114 115 116 117 118 119 120 |
# File 'lib/zitadel/client/models/authorization_service_user.rb', line 112 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && preferred_login_name == o.preferred_login_name && display_name == o.display_name && avatar_url == o.avatar_url && organization_id == o.organization_id end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
240 241 242 243 244 245 246 247 248 249 250 251 252 |
# File 'lib/zitadel/client/models/authorization_service_user.rb', line 240 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
124 125 126 |
# File 'lib/zitadel/client/models/authorization_service_user.rb', line 124 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
130 131 132 |
# File 'lib/zitadel/client/models/authorization_service_user.rb', line 130 def hash [id, preferred_login_name, display_name, avatar_url, organization_id].hash end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
216 217 218 |
# File 'lib/zitadel/client/models/authorization_service_user.rb', line 216 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
222 223 224 225 226 227 228 229 230 231 232 233 234 |
# File 'lib/zitadel/client/models/authorization_service_user.rb', line 222 def to_hash hash = {} # Calls super.to_hash if parent exists self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
210 211 212 |
# File 'lib/zitadel/client/models/authorization_service_user.rb', line 210 def to_s to_hash.to_s end |