Class: Zitadel::Client::Models::BetaAppServiceApplicationSearchFilter

Inherits:
Object
  • Object
show all
Defined in:
lib/zitadel/client/models/beta_app_service_application_search_filter.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ BetaAppServiceApplicationSearchFilter

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Models attributes in the form of hash



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/zitadel/client/models/beta_app_service_application_search_filter.rb', line 90

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    # MODIFIED: Updated class name in error message
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zitadel::Client::Models::BetaAppServiceApplicationSearchFilter` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      # MODIFIED: Updated class name in error message
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zitadel::Client::Models::BetaAppServiceApplicationSearchFilter`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'api_app_only')
    self.api_app_only = attributes[:'api_app_only']
  end

  if attributes.key?(:'name_filter')
    self.name_filter = attributes[:'name_filter']
  end

  if attributes.key?(:'oidc_app_only')
    self.oidc_app_only = attributes[:'oidc_app_only']
  end

  if attributes.key?(:'saml_app_only')
    self.saml_app_only = attributes[:'saml_app_only']
  end

  if attributes.key?(:'state_filter')
    self.state_filter = attributes[:'state_filter']
  end
end

Instance Attribute Details

#api_app_onlyObject

Returns the value of attribute api_app_only.



18
19
20
# File 'lib/zitadel/client/models/beta_app_service_application_search_filter.rb', line 18

def api_app_only
  @api_app_only
end

#name_filterObject

Returns the value of attribute name_filter.



20
21
22
# File 'lib/zitadel/client/models/beta_app_service_application_search_filter.rb', line 20

def name_filter
  @name_filter
end

#oidc_app_onlyObject

Returns the value of attribute oidc_app_only.



22
23
24
# File 'lib/zitadel/client/models/beta_app_service_application_search_filter.rb', line 22

def oidc_app_only
  @oidc_app_only
end

#saml_app_onlyObject

Returns the value of attribute saml_app_only.



24
25
26
# File 'lib/zitadel/client/models/beta_app_service_application_search_filter.rb', line 24

def saml_app_only
  @saml_app_only
end

#state_filterObject

Returns the value of attribute state_filter.



26
27
28
# File 'lib/zitadel/client/models/beta_app_service_application_search_filter.rb', line 26

def state_filter
  @state_filter
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/zitadel/client/models/beta_app_service_application_search_filter.rb', line 178

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf/anyOf constructs that resolve to a model name
    # MODIFIED: Ensure model is looked up in the Models namespace
    # 'type' here is expected to be the simple class name (e.g., "User", "OrderDetails")
    klass = Zitadel::Client::Models.const_get(type)
    # The `klass.build` method is for oneOf/anyOf types (defined in partial_oneof_module.mustache / partial_anyof_module.mustache)
    # The `klass.build_from_hash` is for regular model types (defined in this base_object.mustache itself)
    if klass.respond_to?(:openapi_one_of) || klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_allOf)
      klass.build(value) # For oneOf/anyOf/allOf, delegate to their specific build method
    else
      klass.build_from_hash(value) # For regular models
    end
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



62
63
64
# File 'lib/zitadel/client/models/beta_app_service_application_search_filter.rb', line 62

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



67
68
69
# File 'lib/zitadel/client/models/beta_app_service_application_search_filter.rb', line 67

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



51
52
53
54
55
56
57
58
59
# File 'lib/zitadel/client/models/beta_app_service_application_search_filter.rb', line 51

def self.attribute_map
  {
    :'api_app_only' => :'apiAppOnly',
    :'name_filter' => :'nameFilter',
    :'oidc_app_only' => :'oidcAppOnly',
    :'saml_app_only' => :'samlAppOnly',
    :'state_filter' => :'stateFilter'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Models attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
# File 'lib/zitadel/client/models/beta_app_service_application_search_filter.rb', line 154

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash) # `new` will call the initialize method of the specific model class.
end

.openapi_nullableObject

List of attributes with nullable: true



83
84
85
86
# File 'lib/zitadel/client/models/beta_app_service_application_search_filter.rb', line 83

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



72
73
74
75
76
77
78
79
80
# File 'lib/zitadel/client/models/beta_app_service_application_search_filter.rb', line 72

def self.openapi_types
  {
    :'api_app_only' => :'Boolean',
    :'name_filter' => :'BetaAppServiceApplicationNameQuery',
    :'oidc_app_only' => :'Boolean',
    :'saml_app_only' => :'Boolean',
    :'state_filter' => :'BetaAppServiceAppState'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



129
130
131
132
133
134
135
136
137
# File 'lib/zitadel/client/models/beta_app_service_application_search_filter.rb', line 129

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      api_app_only == o.api_app_only &&
      name_filter == o.name_filter &&
      oidc_app_only == o.oidc_app_only &&
      saml_app_only == o.saml_app_only &&
      state_filter == o.state_filter
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



257
258
259
260
261
262
263
264
265
266
267
268
269
# File 'lib/zitadel/client/models/beta_app_service_application_search_filter.rb', line 257

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


141
142
143
# File 'lib/zitadel/client/models/beta_app_service_application_search_filter.rb', line 141

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



147
148
149
# File 'lib/zitadel/client/models/beta_app_service_application_search_filter.rb', line 147

def hash
  [api_app_only, name_filter, oidc_app_only, saml_app_only, state_filter].hash
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



233
234
235
# File 'lib/zitadel/client/models/beta_app_service_application_search_filter.rb', line 233

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



239
240
241
242
243
244
245
246
247
248
249
250
251
# File 'lib/zitadel/client/models/beta_app_service_application_search_filter.rb', line 239

def to_hash
  hash = {} # Calls super.to_hash if parent exists
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



227
228
229
# File 'lib/zitadel/client/models/beta_app_service_application_search_filter.rb', line 227

def to_s
  to_hash.to_s
end