Class: Zitadel::Client::Models::BetaAppServiceCreateOIDCApplicationRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/zitadel/client/models/beta_app_service_create_o_i_d_c_application_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ BetaAppServiceCreateOIDCApplicationRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Models attributes in the form of hash



141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
# File 'lib/zitadel/client/models/beta_app_service_create_o_i_d_c_application_request.rb', line 141

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    # MODIFIED: Updated class name in error message
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zitadel::Client::Models::BetaAppServiceCreateOIDCApplicationRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      # MODIFIED: Updated class name in error message
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zitadel::Client::Models::BetaAppServiceCreateOIDCApplicationRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'redirect_uris')
    if (value = attributes[:'redirect_uris']).is_a?(Array)
      self.redirect_uris = value
    end
  end

  if attributes.key?(:'response_types')
    if (value = attributes[:'response_types']).is_a?(Array)
      self.response_types = value
    end
  end

  if attributes.key?(:'grant_types')
    if (value = attributes[:'grant_types']).is_a?(Array)
      self.grant_types = value
    end
  end

  if attributes.key?(:'app_type')
    self.app_type = attributes[:'app_type']
  end

  if attributes.key?(:'auth_method_type')
    self.auth_method_type = attributes[:'auth_method_type']
  end

  if attributes.key?(:'post_logout_redirect_uris')
    if (value = attributes[:'post_logout_redirect_uris']).is_a?(Array)
      self.post_logout_redirect_uris = value
    end
  end

  if attributes.key?(:'version')
    self.version = attributes[:'version']
  end

  if attributes.key?(:'dev_mode')
    self.dev_mode = attributes[:'dev_mode']
  end

  if attributes.key?(:'access_token_type')
    self.access_token_type = attributes[:'access_token_type']
  end

  if attributes.key?(:'access_token_role_assertion')
    self.access_token_role_assertion = attributes[:'access_token_role_assertion']
  end

  if attributes.key?(:'id_token_role_assertion')
    self.id_token_role_assertion = attributes[:'id_token_role_assertion']
  end

  if attributes.key?(:'id_token_userinfo_assertion')
    self.id_token_userinfo_assertion = attributes[:'id_token_userinfo_assertion']
  end

  if attributes.key?(:'clock_skew')
    self.clock_skew = attributes[:'clock_skew']
  end

  if attributes.key?(:'additional_origins')
    if (value = attributes[:'additional_origins']).is_a?(Array)
      self.additional_origins = value
    end
  end

  if attributes.key?(:'skip_native_app_success_page')
    self.skip_native_app_success_page = attributes[:'skip_native_app_success_page']
  end

  if attributes.key?(:'back_channel_logout_uri')
    self.back_channel_logout_uri = attributes[:'back_channel_logout_uri']
  end

  if attributes.key?(:'login_version')
    self. = attributes[:'login_version']
  end
end

Instance Attribute Details

#access_token_role_assertionObject

Returns the value of attribute access_token_role_assertion.



38
39
40
# File 'lib/zitadel/client/models/beta_app_service_create_o_i_d_c_application_request.rb', line 38

def access_token_role_assertion
  @access_token_role_assertion
end

#access_token_typeObject

Returns the value of attribute access_token_type.



36
37
38
# File 'lib/zitadel/client/models/beta_app_service_create_o_i_d_c_application_request.rb', line 36

def access_token_type
  @access_token_type
end

#additional_originsObject

Returns the value of attribute additional_origins.



47
48
49
# File 'lib/zitadel/client/models/beta_app_service_create_o_i_d_c_application_request.rb', line 47

def additional_origins
  @additional_origins
end

#app_typeObject

Returns the value of attribute app_type.



25
26
27
# File 'lib/zitadel/client/models/beta_app_service_create_o_i_d_c_application_request.rb', line 25

def app_type
  @app_type
end

#auth_method_typeObject

Returns the value of attribute auth_method_type.



27
28
29
# File 'lib/zitadel/client/models/beta_app_service_create_o_i_d_c_application_request.rb', line 27

def auth_method_type
  @auth_method_type
end

#back_channel_logout_uriObject

Returns the value of attribute back_channel_logout_uri.



51
52
53
# File 'lib/zitadel/client/models/beta_app_service_create_o_i_d_c_application_request.rb', line 51

def back_channel_logout_uri
  @back_channel_logout_uri
end

#clock_skewObject

A Duration represents a signed, fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". It is related to Timestamp in that the difference between two Timestamp values is a Duration and it can be added or subtracted from a Timestamp. Range is approximately -10,000 years. # Examples Example 1: Compute Duration from two Timestamps in pseudo code. Timestamp start = …; Timestamp end = …; Duration duration = …; duration.seconds = end.seconds - start.seconds; duration.nanos = end.nanos - start.nanos; if (duration.seconds < 0 && duration.nanos > 0) { duration.seconds = 1; duration.nanos -= 1000000000; } else if (duration.seconds > 0 && duration.nanos < 0) { duration.seconds -= 1; duration.nanos = 1000000000; } Example 2: Compute Timestamp from Timestamp Duration in pseudo code. Timestamp start = …; Duration duration = …; Timestamp end = …; end.seconds = start.seconds + duration.seconds; end.nanos = start.nanos + duration.nanos; if (end.nanos < 0) { end.seconds -= 1; end.nanos = 1000000000; } else if (end.nanos >= 1000000000) { end.seconds = 1; end.nanos -= 1000000000; } Example 3: Compute Duration from datetime.timedelta in Python. td = datetime.timedelta(days=3, minutes=10) duration = Duration() duration.FromTimedelta(td) # JSON Mapping In JSON format, the Duration type is encoded as a string rather than an object, where the string ends in the suffix "s" (indicating seconds) and is preceded by the number of seconds, with nanoseconds expressed as fractional seconds. For example, 3 seconds with 0 nanoseconds should be encoded in JSON format as "3s", while 3 seconds and 1 nanosecond should be expressed in JSON format as "3.000000001s", and 3 seconds and 1 microsecond should be expressed in JSON format as "3.000001s".



45
46
47
# File 'lib/zitadel/client/models/beta_app_service_create_o_i_d_c_application_request.rb', line 45

def clock_skew
  @clock_skew
end

#dev_modeObject

Returns the value of attribute dev_mode.



34
35
36
# File 'lib/zitadel/client/models/beta_app_service_create_o_i_d_c_application_request.rb', line 34

def dev_mode
  @dev_mode
end

#grant_typesObject

Returns the value of attribute grant_types.



23
24
25
# File 'lib/zitadel/client/models/beta_app_service_create_o_i_d_c_application_request.rb', line 23

def grant_types
  @grant_types
end

#id_token_role_assertionObject

Returns the value of attribute id_token_role_assertion.



40
41
42
# File 'lib/zitadel/client/models/beta_app_service_create_o_i_d_c_application_request.rb', line 40

def id_token_role_assertion
  @id_token_role_assertion
end

#id_token_userinfo_assertionObject

Returns the value of attribute id_token_userinfo_assertion.



42
43
44
# File 'lib/zitadel/client/models/beta_app_service_create_o_i_d_c_application_request.rb', line 42

def id_token_userinfo_assertion
  @id_token_userinfo_assertion
end

#login_versionObject

Returns the value of attribute login_version.



53
54
55
# File 'lib/zitadel/client/models/beta_app_service_create_o_i_d_c_application_request.rb', line 53

def 
  @login_version
end

#post_logout_redirect_urisObject

ZITADEL will redirect to this link after a successful logout



30
31
32
# File 'lib/zitadel/client/models/beta_app_service_create_o_i_d_c_application_request.rb', line 30

def post_logout_redirect_uris
  @post_logout_redirect_uris
end

#redirect_urisObject

Callback URI of the authorization request where the code or tokens will be sent to



19
20
21
# File 'lib/zitadel/client/models/beta_app_service_create_o_i_d_c_application_request.rb', line 19

def redirect_uris
  @redirect_uris
end

#response_typesObject

Returns the value of attribute response_types.



21
22
23
# File 'lib/zitadel/client/models/beta_app_service_create_o_i_d_c_application_request.rb', line 21

def response_types
  @response_types
end

#skip_native_app_success_pageObject

Returns the value of attribute skip_native_app_success_page.



49
50
51
# File 'lib/zitadel/client/models/beta_app_service_create_o_i_d_c_application_request.rb', line 49

def skip_native_app_success_page
  @skip_native_app_success_page
end

#versionObject

Returns the value of attribute version.



32
33
34
# File 'lib/zitadel/client/models/beta_app_service_create_o_i_d_c_application_request.rb', line 32

def version
  @version
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
# File 'lib/zitadel/client/models/beta_app_service_create_o_i_d_c_application_request.rb', line 299

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf/anyOf constructs that resolve to a model name
    # MODIFIED: Ensure model is looked up in the Models namespace
    # 'type' here is expected to be the simple class name (e.g., "User", "OrderDetails")
    klass = Zitadel::Client::Models.const_get(type)
    # The `klass.build` method is for oneOf/anyOf types (defined in partial_oneof_module.mustache / partial_anyof_module.mustache)
    # The `klass.build_from_hash` is for regular model types (defined in this base_object.mustache itself)
    if klass.respond_to?(:openapi_one_of) || klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_allOf)
      klass.build(value) # For oneOf/anyOf/allOf, delegate to their specific build method
    else
      klass.build_from_hash(value) # For regular models
    end
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



101
102
103
# File 'lib/zitadel/client/models/beta_app_service_create_o_i_d_c_application_request.rb', line 101

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



106
107
108
# File 'lib/zitadel/client/models/beta_app_service_create_o_i_d_c_application_request.rb', line 106

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/zitadel/client/models/beta_app_service_create_o_i_d_c_application_request.rb', line 78

def self.attribute_map
  {
    :'redirect_uris' => :'redirectUris',
    :'response_types' => :'responseTypes',
    :'grant_types' => :'grantTypes',
    :'app_type' => :'appType',
    :'auth_method_type' => :'authMethodType',
    :'post_logout_redirect_uris' => :'postLogoutRedirectUris',
    :'version' => :'version',
    :'dev_mode' => :'devMode',
    :'access_token_type' => :'accessTokenType',
    :'access_token_role_assertion' => :'accessTokenRoleAssertion',
    :'id_token_role_assertion' => :'idTokenRoleAssertion',
    :'id_token_userinfo_assertion' => :'idTokenUserinfoAssertion',
    :'clock_skew' => :'clockSkew',
    :'additional_origins' => :'additionalOrigins',
    :'skip_native_app_success_page' => :'skipNativeAppSuccessPage',
    :'back_channel_logout_uri' => :'backChannelLogoutUri',
    :'login_version' => :'loginVersion'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Models attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
# File 'lib/zitadel/client/models/beta_app_service_create_o_i_d_c_application_request.rb', line 275

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash) # `new` will call the initialize method of the specific model class.
end

.openapi_nullableObject

List of attributes with nullable: true



134
135
136
137
# File 'lib/zitadel/client/models/beta_app_service_create_o_i_d_c_application_request.rb', line 134

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'lib/zitadel/client/models/beta_app_service_create_o_i_d_c_application_request.rb', line 111

def self.openapi_types
  {
    :'redirect_uris' => :'Array<String>',
    :'response_types' => :'Array<BetaAppServiceOIDCResponseType>',
    :'grant_types' => :'Array<BetaAppServiceOIDCGrantType>',
    :'app_type' => :'BetaAppServiceOIDCAppType',
    :'auth_method_type' => :'BetaAppServiceOIDCAuthMethodType',
    :'post_logout_redirect_uris' => :'Array<String>',
    :'version' => :'BetaAppServiceOIDCVersion',
    :'dev_mode' => :'Boolean',
    :'access_token_type' => :'BetaAppServiceOIDCTokenType',
    :'access_token_role_assertion' => :'Boolean',
    :'id_token_role_assertion' => :'Boolean',
    :'id_token_userinfo_assertion' => :'Boolean',
    :'clock_skew' => :'String',
    :'additional_origins' => :'Array<String>',
    :'skip_native_app_success_page' => :'Boolean',
    :'back_channel_logout_uri' => :'String',
    :'login_version' => :'BetaAppServiceLoginVersion'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
# File 'lib/zitadel/client/models/beta_app_service_create_o_i_d_c_application_request.rb', line 238

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      redirect_uris == o.redirect_uris &&
      response_types == o.response_types &&
      grant_types == o.grant_types &&
      app_type == o.app_type &&
      auth_method_type == o.auth_method_type &&
      post_logout_redirect_uris == o.post_logout_redirect_uris &&
      version == o.version &&
      dev_mode == o.dev_mode &&
      access_token_type == o.access_token_type &&
      access_token_role_assertion == o.access_token_role_assertion &&
      id_token_role_assertion == o.id_token_role_assertion &&
      id_token_userinfo_assertion == o.id_token_userinfo_assertion &&
      clock_skew == o.clock_skew &&
      additional_origins == o.additional_origins &&
      skip_native_app_success_page == o.skip_native_app_success_page &&
      back_channel_logout_uri == o.back_channel_logout_uri &&
       == o.
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



378
379
380
381
382
383
384
385
386
387
388
389
390
# File 'lib/zitadel/client/models/beta_app_service_create_o_i_d_c_application_request.rb', line 378

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


262
263
264
# File 'lib/zitadel/client/models/beta_app_service_create_o_i_d_c_application_request.rb', line 262

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



268
269
270
# File 'lib/zitadel/client/models/beta_app_service_create_o_i_d_c_application_request.rb', line 268

def hash
  [redirect_uris, response_types, grant_types, app_type, auth_method_type, post_logout_redirect_uris, version, dev_mode, access_token_type, access_token_role_assertion, id_token_role_assertion, id_token_userinfo_assertion, clock_skew, additional_origins, skip_native_app_success_page, back_channel_logout_uri, ].hash
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



354
355
356
# File 'lib/zitadel/client/models/beta_app_service_create_o_i_d_c_application_request.rb', line 354

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



360
361
362
363
364
365
366
367
368
369
370
371
372
# File 'lib/zitadel/client/models/beta_app_service_create_o_i_d_c_application_request.rb', line 360

def to_hash
  hash = {} # Calls super.to_hash if parent exists
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



348
349
350
# File 'lib/zitadel/client/models/beta_app_service_create_o_i_d_c_application_request.rb', line 348

def to_s
  to_hash.to_s
end