Class: Zitadel::Client::Models::BetaAppServiceUpdateApplicationRequest
- Inherits:
-
Object
- Object
- Zitadel::Client::Models::BetaAppServiceUpdateApplicationRequest
- Defined in:
- lib/zitadel/client/models/beta_app_service_update_application_request.rb
Instance Attribute Summary collapse
-
#api_configuration_request ⇒ Object
Returns the value of attribute api_configuration_request.
-
#id ⇒ Object
Returns the value of attribute id.
-
#name ⇒ Object
Returns the value of attribute name.
-
#oidc_configuration_request ⇒ Object
Returns the value of attribute oidc_configuration_request.
-
#project_id ⇒ Object
Returns the value of attribute project_id.
-
#saml_configuration_request ⇒ Object
Returns the value of attribute saml_configuration_request.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BetaAppServiceUpdateApplicationRequest
constructor
Initializes the object.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ BetaAppServiceUpdateApplicationRequest
Initializes the object
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/zitadel/client/models/beta_app_service_update_application_request.rb', line 72 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) # MODIFIED: Updated class name in error message fail ArgumentError, "The input argument (attributes) must be a hash in `Zitadel::Client::Models::BetaAppServiceUpdateApplicationRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) # MODIFIED: Updated class name in error message fail ArgumentError, "`#{k}` is not a valid attribute in `Zitadel::Client::Models::BetaAppServiceUpdateApplicationRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'project_id') self.project_id = attributes[:'project_id'] end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'api_configuration_request') self.api_configuration_request = attributes[:'api_configuration_request'] end if attributes.key?(:'oidc_configuration_request') self.oidc_configuration_request = attributes[:'oidc_configuration_request'] end if attributes.key?(:'saml_configuration_request') self.saml_configuration_request = attributes[:'saml_configuration_request'] end end |
Instance Attribute Details
#api_configuration_request ⇒ Object
Returns the value of attribute api_configuration_request.
24 25 26 |
# File 'lib/zitadel/client/models/beta_app_service_update_application_request.rb', line 24 def api_configuration_request @api_configuration_request end |
#id ⇒ Object
Returns the value of attribute id.
20 21 22 |
# File 'lib/zitadel/client/models/beta_app_service_update_application_request.rb', line 20 def id @id end |
#name ⇒ Object
Returns the value of attribute name.
22 23 24 |
# File 'lib/zitadel/client/models/beta_app_service_update_application_request.rb', line 22 def name @name end |
#oidc_configuration_request ⇒ Object
Returns the value of attribute oidc_configuration_request.
26 27 28 |
# File 'lib/zitadel/client/models/beta_app_service_update_application_request.rb', line 26 def oidc_configuration_request @oidc_configuration_request end |
#project_id ⇒ Object
Returns the value of attribute project_id.
18 19 20 |
# File 'lib/zitadel/client/models/beta_app_service_update_application_request.rb', line 18 def project_id @project_id end |
#saml_configuration_request ⇒ Object
Returns the value of attribute saml_configuration_request.
28 29 30 |
# File 'lib/zitadel/client/models/beta_app_service_update_application_request.rb', line 28 def saml_configuration_request @saml_configuration_request end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 |
# File 'lib/zitadel/client/models/beta_app_service_update_application_request.rb', line 165 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf/anyOf constructs that resolve to a model name # MODIFIED: Ensure model is looked up in the Models namespace # 'type' here is expected to be the simple class name (e.g., "User", "OrderDetails") klass = Zitadel::Client::Models.const_get(type) # The `klass.build` method is for oneOf/anyOf types (defined in partial_oneof_module.mustache / partial_anyof_module.mustache) # The `klass.build_from_hash` is for regular model types (defined in this base_object.mustache itself) if klass.respond_to?(:openapi_one_of) || klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_allOf) klass.build(value) # For oneOf/anyOf/allOf, delegate to their specific build method else klass.build_from_hash(value) # For regular models end end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
43 44 45 |
# File 'lib/zitadel/client/models/beta_app_service_update_application_request.rb', line 43 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
48 49 50 |
# File 'lib/zitadel/client/models/beta_app_service_update_application_request.rb', line 48 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
31 32 33 34 35 36 37 38 39 40 |
# File 'lib/zitadel/client/models/beta_app_service_update_application_request.rb', line 31 def self.attribute_map { :'project_id' => :'projectId', :'id' => :'id', :'name' => :'name', :'api_configuration_request' => :'apiConfigurationRequest', :'oidc_configuration_request' => :'oidcConfigurationRequest', :'saml_configuration_request' => :'samlConfigurationRequest' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/zitadel/client/models/beta_app_service_update_application_request.rb', line 141 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) # `new` will call the initialize method of the specific model class. end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
65 66 67 68 |
# File 'lib/zitadel/client/models/beta_app_service_update_application_request.rb', line 65 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
53 54 55 56 57 58 59 60 61 62 |
# File 'lib/zitadel/client/models/beta_app_service_update_application_request.rb', line 53 def self.openapi_types { :'project_id' => :'String', :'id' => :'String', :'name' => :'String', :'api_configuration_request' => :'BetaAppServiceUpdateAPIApplicationConfigurationRequest', :'oidc_configuration_request' => :'BetaAppServiceUpdateOIDCApplicationConfigurationRequest', :'saml_configuration_request' => :'BetaAppServiceUpdateSAMLApplicationConfigurationRequest' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
115 116 117 118 119 120 121 122 123 124 |
# File 'lib/zitadel/client/models/beta_app_service_update_application_request.rb', line 115 def ==(o) return true if self.equal?(o) self.class == o.class && project_id == o.project_id && id == o.id && name == o.name && api_configuration_request == o.api_configuration_request && oidc_configuration_request == o.oidc_configuration_request && saml_configuration_request == o.saml_configuration_request end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
244 245 246 247 248 249 250 251 252 253 254 255 256 |
# File 'lib/zitadel/client/models/beta_app_service_update_application_request.rb', line 244 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
128 129 130 |
# File 'lib/zitadel/client/models/beta_app_service_update_application_request.rb', line 128 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
134 135 136 |
# File 'lib/zitadel/client/models/beta_app_service_update_application_request.rb', line 134 def hash [project_id, id, name, api_configuration_request, oidc_configuration_request, saml_configuration_request].hash end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
220 221 222 |
# File 'lib/zitadel/client/models/beta_app_service_update_application_request.rb', line 220 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/zitadel/client/models/beta_app_service_update_application_request.rb', line 226 def to_hash hash = {} # Calls super.to_hash if parent exists self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
214 215 216 |
# File 'lib/zitadel/client/models/beta_app_service_update_application_request.rb', line 214 def to_s to_hash.to_s end |