Class: Zitadel::Client::Models::BetaAuthorizationServiceCreateAuthorizationRequest
- Inherits:
-
Object
- Object
- Zitadel::Client::Models::BetaAuthorizationServiceCreateAuthorizationRequest
- Defined in:
- lib/zitadel/client/models/beta_authorization_service_create_authorization_request.rb
Instance Attribute Summary collapse
-
#organization_id ⇒ Object
OrganizationID is the ID of the organization on which the authorization should be created.
-
#project_id ⇒ Object
Project ID is the ID of the project the user should be authorized for.
-
#role_keys ⇒ Object
RoleKeys are the keys of the roles the user should be granted.
-
#user_id ⇒ Object
UserID is the ID of the user who should be granted the authorization.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BetaAuthorizationServiceCreateAuthorizationRequest
constructor
Initializes the object.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ BetaAuthorizationServiceCreateAuthorizationRequest
Initializes the object
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/zitadel/client/models/beta_authorization_service_create_authorization_request.rb', line 69 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) # MODIFIED: Updated class name in error message fail ArgumentError, "The input argument (attributes) must be a hash in `Zitadel::Client::Models::BetaAuthorizationServiceCreateAuthorizationRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) # MODIFIED: Updated class name in error message fail ArgumentError, "`#{k}` is not a valid attribute in `Zitadel::Client::Models::BetaAuthorizationServiceCreateAuthorizationRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'user_id') self.user_id = attributes[:'user_id'] end if attributes.key?(:'project_id') self.project_id = attributes[:'project_id'] end if attributes.key?(:'organization_id') self.organization_id = attributes[:'organization_id'] end if attributes.key?(:'role_keys') if (value = attributes[:'role_keys']).is_a?(Array) self.role_keys = value end end end |
Instance Attribute Details
#organization_id ⇒ Object
OrganizationID is the ID of the organization on which the authorization should be created. The organization must either own the project or have a grant for the project. If omitted, the authorization is created on the projects organization.
25 26 27 |
# File 'lib/zitadel/client/models/beta_authorization_service_create_authorization_request.rb', line 25 def organization_id @organization_id end |
#project_id ⇒ Object
Project ID is the ID of the project the user should be authorized for.
22 23 24 |
# File 'lib/zitadel/client/models/beta_authorization_service_create_authorization_request.rb', line 22 def project_id @project_id end |
#role_keys ⇒ Object
RoleKeys are the keys of the roles the user should be granted.
28 29 30 |
# File 'lib/zitadel/client/models/beta_authorization_service_create_authorization_request.rb', line 28 def role_keys @role_keys end |
#user_id ⇒ Object
UserID is the ID of the user who should be granted the authorization.
19 20 21 |
# File 'lib/zitadel/client/models/beta_authorization_service_create_authorization_request.rb', line 19 def user_id @user_id end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/zitadel/client/models/beta_authorization_service_create_authorization_request.rb', line 154 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf/anyOf constructs that resolve to a model name # MODIFIED: Ensure model is looked up in the Models namespace # 'type' here is expected to be the simple class name (e.g., "User", "OrderDetails") klass = Zitadel::Client::Models.const_get(type) # The `klass.build` method is for oneOf/anyOf types (defined in partial_oneof_module.mustache / partial_anyof_module.mustache) # The `klass.build_from_hash` is for regular model types (defined in this base_object.mustache itself) if klass.respond_to?(:openapi_one_of) || klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_allOf) klass.build(value) # For oneOf/anyOf/allOf, delegate to their specific build method else klass.build_from_hash(value) # For regular models end end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
41 42 43 |
# File 'lib/zitadel/client/models/beta_authorization_service_create_authorization_request.rb', line 41 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
46 47 48 |
# File 'lib/zitadel/client/models/beta_authorization_service_create_authorization_request.rb', line 46 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
31 32 33 34 35 36 37 38 |
# File 'lib/zitadel/client/models/beta_authorization_service_create_authorization_request.rb', line 31 def self.attribute_map { :'user_id' => :'userId', :'project_id' => :'projectId', :'organization_id' => :'organizationId', :'role_keys' => :'roleKeys' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/zitadel/client/models/beta_authorization_service_create_authorization_request.rb', line 130 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) # `new` will call the initialize method of the specific model class. end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
61 62 63 64 65 |
# File 'lib/zitadel/client/models/beta_authorization_service_create_authorization_request.rb', line 61 def self.openapi_nullable Set.new([ :'organization_id', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
51 52 53 54 55 56 57 58 |
# File 'lib/zitadel/client/models/beta_authorization_service_create_authorization_request.rb', line 51 def self.openapi_types { :'user_id' => :'String', :'project_id' => :'String', :'organization_id' => :'String', :'role_keys' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
106 107 108 109 110 111 112 113 |
# File 'lib/zitadel/client/models/beta_authorization_service_create_authorization_request.rb', line 106 def ==(o) return true if self.equal?(o) self.class == o.class && user_id == o.user_id && project_id == o.project_id && organization_id == o.organization_id && role_keys == o.role_keys end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/zitadel/client/models/beta_authorization_service_create_authorization_request.rb', line 233 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
117 118 119 |
# File 'lib/zitadel/client/models/beta_authorization_service_create_authorization_request.rb', line 117 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
123 124 125 |
# File 'lib/zitadel/client/models/beta_authorization_service_create_authorization_request.rb', line 123 def hash [user_id, project_id, organization_id, role_keys].hash end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
209 210 211 |
# File 'lib/zitadel/client/models/beta_authorization_service_create_authorization_request.rb', line 209 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
215 216 217 218 219 220 221 222 223 224 225 226 227 |
# File 'lib/zitadel/client/models/beta_authorization_service_create_authorization_request.rb', line 215 def to_hash hash = {} # Calls super.to_hash if parent exists self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
203 204 205 |
# File 'lib/zitadel/client/models/beta_authorization_service_create_authorization_request.rb', line 203 def to_s to_hash.to_s end |