Class: Zitadel::Client::Models::BetaProjectServiceCreateProjectRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/zitadel/client/models/beta_project_service_create_project_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ BetaProjectServiceCreateProjectRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Models attributes in the form of hash



110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
# File 'lib/zitadel/client/models/beta_project_service_create_project_request.rb', line 110

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    # MODIFIED: Updated class name in error message
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zitadel::Client::Models::BetaProjectServiceCreateProjectRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      # MODIFIED: Updated class name in error message
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zitadel::Client::Models::BetaProjectServiceCreateProjectRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'organization_id')
    self.organization_id = attributes[:'organization_id']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'project_role_assertion')
    self.project_role_assertion = attributes[:'project_role_assertion']
  end

  if attributes.key?(:'authorization_required')
    self.authorization_required = attributes[:'authorization_required']
  end

  if attributes.key?(:'project_access_required')
    self.project_access_required = attributes[:'project_access_required']
  end

  if attributes.key?(:'private_labeling_setting')
    self.private_labeling_setting = attributes[:'private_labeling_setting']
  end

  if attributes.key?(:'admins')
    if (value = attributes[:'admins']).is_a?(Array)
      self.admins = value
    end
  end
end

Instance Attribute Details

#adminsObject

List of users and Project Member roles (PROJECT_OWNER, by default) to be assigned to those users.



39
40
41
# File 'lib/zitadel/client/models/beta_project_service_create_project_request.rb', line 39

def admins
  @admins
end

#authorization_requiredObject

Deny authentication if the user has no authorization assigned to this project. Authorizations to the project without assigned a specific role to the user are allowed.



31
32
33
# File 'lib/zitadel/client/models/beta_project_service_create_project_request.rb', line 31

def authorization_required
  @authorization_required
end

#idObject

The unique identifier of the project.



22
23
24
# File 'lib/zitadel/client/models/beta_project_service_create_project_request.rb', line 22

def id
  @id
end

#nameObject

Name of the project.



25
26
27
# File 'lib/zitadel/client/models/beta_project_service_create_project_request.rb', line 25

def name
  @name
end

#organization_idObject

The unique identifier of the organization the project belongs to.



19
20
21
# File 'lib/zitadel/client/models/beta_project_service_create_project_request.rb', line 19

def organization_id
  @organization_id
end

#private_labeling_settingObject

Returns the value of attribute private_labeling_setting.



36
37
38
# File 'lib/zitadel/client/models/beta_project_service_create_project_request.rb', line 36

def private_labeling_setting
  @private_labeling_setting
end

#project_access_requiredObject

Before a user can be authenticated, it is verified that their affiliated organization has been granted access to this project. Authentication is not permitted for users from unauthorized organizations.



34
35
36
# File 'lib/zitadel/client/models/beta_project_service_create_project_request.rb', line 34

def project_access_required
  @project_access_required
end

#project_role_assertionObject

Enable this setting to provide role information to your application. For OpenID Connect, the roles can be requested from the UserInfo endpoint or sent in the ID or Access Token, based on your application’s configuration.



28
29
30
# File 'lib/zitadel/client/models/beta_project_service_create_project_request.rb', line 28

def project_role_assertion
  @project_role_assertion
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
# File 'lib/zitadel/client/models/beta_project_service_create_project_request.rb', line 215

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf/anyOf constructs that resolve to a model name
    # MODIFIED: Ensure model is looked up in the Models namespace
    # 'type' here is expected to be the simple class name (e.g., "User", "OrderDetails")
    klass = Zitadel::Client::Models.const_get(type)
    # The `klass.build` method is for oneOf/anyOf types (defined in partial_oneof_module.mustache / partial_anyof_module.mustache)
    # The `klass.build_from_hash` is for regular model types (defined in this base_object.mustache itself)
    if klass.respond_to?(:openapi_one_of) || klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_allOf)
      klass.build(value) # For oneOf/anyOf/allOf, delegate to their specific build method
    else
      klass.build_from_hash(value) # For regular models
    end
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



78
79
80
# File 'lib/zitadel/client/models/beta_project_service_create_project_request.rb', line 78

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



83
84
85
# File 'lib/zitadel/client/models/beta_project_service_create_project_request.rb', line 83

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/zitadel/client/models/beta_project_service_create_project_request.rb', line 64

def self.attribute_map
  {
    :'organization_id' => :'organizationId',
    :'id' => :'id',
    :'name' => :'name',
    :'project_role_assertion' => :'projectRoleAssertion',
    :'authorization_required' => :'authorizationRequired',
    :'project_access_required' => :'projectAccessRequired',
    :'private_labeling_setting' => :'privateLabelingSetting',
    :'admins' => :'admins'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Models attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/zitadel/client/models/beta_project_service_create_project_request.rb', line 191

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash) # `new` will call the initialize method of the specific model class.
end

.openapi_nullableObject

List of attributes with nullable: true



102
103
104
105
106
# File 'lib/zitadel/client/models/beta_project_service_create_project_request.rb', line 102

def self.openapi_nullable
  Set.new([
    :'id',
  ])
end

.openapi_typesObject

Attribute type mapping.



88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/zitadel/client/models/beta_project_service_create_project_request.rb', line 88

def self.openapi_types
  {
    :'organization_id' => :'String',
    :'id' => :'String',
    :'name' => :'String',
    :'project_role_assertion' => :'Boolean',
    :'authorization_required' => :'Boolean',
    :'project_access_required' => :'Boolean',
    :'private_labeling_setting' => :'BetaProjectServicePrivateLabelingSetting',
    :'admins' => :'Array<BetaProjectServiceAdmin>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



163
164
165
166
167
168
169
170
171
172
173
174
# File 'lib/zitadel/client/models/beta_project_service_create_project_request.rb', line 163

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      organization_id == o.organization_id &&
      id == o.id &&
      name == o.name &&
      project_role_assertion == o.project_role_assertion &&
      authorization_required == o.authorization_required &&
      project_access_required == o.project_access_required &&
      private_labeling_setting == o.private_labeling_setting &&
      admins == o.admins
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



294
295
296
297
298
299
300
301
302
303
304
305
306
# File 'lib/zitadel/client/models/beta_project_service_create_project_request.rb', line 294

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


178
179
180
# File 'lib/zitadel/client/models/beta_project_service_create_project_request.rb', line 178

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



184
185
186
# File 'lib/zitadel/client/models/beta_project_service_create_project_request.rb', line 184

def hash
  [organization_id, id, name, project_role_assertion, authorization_required, project_access_required, private_labeling_setting, admins].hash
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



270
271
272
# File 'lib/zitadel/client/models/beta_project_service_create_project_request.rb', line 270

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



276
277
278
279
280
281
282
283
284
285
286
287
288
# File 'lib/zitadel/client/models/beta_project_service_create_project_request.rb', line 276

def to_hash
  hash = {} # Calls super.to_hash if parent exists
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



264
265
266
# File 'lib/zitadel/client/models/beta_project_service_create_project_request.rb', line 264

def to_s
  to_hash.to_s
end