Class: Zitadel::Client::Models::BetaProjectServiceUpdateProjectRequest
- Inherits:
-
Object
- Object
- Zitadel::Client::Models::BetaProjectServiceUpdateProjectRequest
- Defined in:
- lib/zitadel/client/models/beta_project_service_update_project_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#has_project_check ⇒ Object
When enabled ZITADEL will check if the organization of the user, that is trying to log in, has a grant to this project.
-
#id ⇒ Object
Returns the value of attribute id.
-
#name ⇒ Object
Name of the project.
-
#private_labeling_setting ⇒ Object
Returns the value of attribute private_labeling_setting.
-
#project_role_assertion ⇒ Object
Enable this setting to have role information included in the user info endpoint.
-
#project_role_check ⇒ Object
When enabled ZITADEL will check if a user has a role of this project assigned when login into an application of this project.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BetaProjectServiceUpdateProjectRequest
constructor
Initializes the object.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ BetaProjectServiceUpdateProjectRequest
Initializes the object
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/zitadel/client/models/beta_project_service_update_project_request.rb', line 102 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) # MODIFIED: Updated class name in error message fail ArgumentError, "The input argument (attributes) must be a hash in `Zitadel::Client::Models::BetaProjectServiceUpdateProjectRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) # MODIFIED: Updated class name in error message fail ArgumentError, "`#{k}` is not a valid attribute in `Zitadel::Client::Models::BetaProjectServiceUpdateProjectRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'project_role_assertion') self.project_role_assertion = attributes[:'project_role_assertion'] end if attributes.key?(:'project_role_check') self.project_role_check = attributes[:'project_role_check'] end if attributes.key?(:'has_project_check') self.has_project_check = attributes[:'has_project_check'] end if attributes.key?(:'private_labeling_setting') self.private_labeling_setting = attributes[:'private_labeling_setting'] end end |
Instance Attribute Details
#has_project_check ⇒ Object
When enabled ZITADEL will check if the organization of the user, that is trying to log in, has a grant to this project.
30 31 32 |
# File 'lib/zitadel/client/models/beta_project_service_update_project_request.rb', line 30 def has_project_check @has_project_check end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/zitadel/client/models/beta_project_service_update_project_request.rb', line 18 def id @id end |
#name ⇒ Object
Name of the project.
21 22 23 |
# File 'lib/zitadel/client/models/beta_project_service_update_project_request.rb', line 21 def name @name end |
#private_labeling_setting ⇒ Object
Returns the value of attribute private_labeling_setting.
32 33 34 |
# File 'lib/zitadel/client/models/beta_project_service_update_project_request.rb', line 32 def private_labeling_setting @private_labeling_setting end |
#project_role_assertion ⇒ Object
Enable this setting to have role information included in the user info endpoint. It is also dependent on your application settings to include it in tokens and other types.
24 25 26 |
# File 'lib/zitadel/client/models/beta_project_service_update_project_request.rb', line 24 def project_role_assertion @project_role_assertion end |
#project_role_check ⇒ Object
When enabled ZITADEL will check if a user has a role of this project assigned when login into an application of this project.
27 28 29 |
# File 'lib/zitadel/client/models/beta_project_service_update_project_request.rb', line 27 def project_role_check @project_role_check end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 |
# File 'lib/zitadel/client/models/beta_project_service_update_project_request.rb', line 195 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf/anyOf constructs that resolve to a model name # MODIFIED: Ensure model is looked up in the Models namespace # 'type' here is expected to be the simple class name (e.g., "User", "OrderDetails") klass = Zitadel::Client::Models.const_get(type) # The `klass.build` method is for oneOf/anyOf types (defined in partial_oneof_module.mustache / partial_anyof_module.mustache) # The `klass.build_from_hash` is for regular model types (defined in this base_object.mustache itself) if klass.respond_to?(:openapi_one_of) || klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_allOf) klass.build(value) # For oneOf/anyOf/allOf, delegate to their specific build method else klass.build_from_hash(value) # For regular models end end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
69 70 71 |
# File 'lib/zitadel/client/models/beta_project_service_update_project_request.rb', line 69 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
74 75 76 |
# File 'lib/zitadel/client/models/beta_project_service_update_project_request.rb', line 74 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
57 58 59 60 61 62 63 64 65 66 |
# File 'lib/zitadel/client/models/beta_project_service_update_project_request.rb', line 57 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'project_role_assertion' => :'projectRoleAssertion', :'project_role_check' => :'projectRoleCheck', :'has_project_check' => :'hasProjectCheck', :'private_labeling_setting' => :'privateLabelingSetting' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/zitadel/client/models/beta_project_service_update_project_request.rb', line 171 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) # `new` will call the initialize method of the specific model class. end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
91 92 93 94 95 96 97 98 |
# File 'lib/zitadel/client/models/beta_project_service_update_project_request.rb', line 91 def self.openapi_nullable Set.new([ :'name', :'project_role_assertion', :'project_role_check', :'has_project_check', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
79 80 81 82 83 84 85 86 87 88 |
# File 'lib/zitadel/client/models/beta_project_service_update_project_request.rb', line 79 def self.openapi_types { :'id' => :'String', :'name' => :'String', :'project_role_assertion' => :'Boolean', :'project_role_check' => :'Boolean', :'has_project_check' => :'Boolean', :'private_labeling_setting' => :'BetaProjectServicePrivateLabelingSetting' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
145 146 147 148 149 150 151 152 153 154 |
# File 'lib/zitadel/client/models/beta_project_service_update_project_request.rb', line 145 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && project_role_assertion == o.project_role_assertion && project_role_check == o.project_role_check && has_project_check == o.has_project_check && private_labeling_setting == o.private_labeling_setting end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
274 275 276 277 278 279 280 281 282 283 284 285 286 |
# File 'lib/zitadel/client/models/beta_project_service_update_project_request.rb', line 274 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
158 159 160 |
# File 'lib/zitadel/client/models/beta_project_service_update_project_request.rb', line 158 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
164 165 166 |
# File 'lib/zitadel/client/models/beta_project_service_update_project_request.rb', line 164 def hash [id, name, project_role_assertion, project_role_check, has_project_check, private_labeling_setting].hash end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
250 251 252 |
# File 'lib/zitadel/client/models/beta_project_service_update_project_request.rb', line 250 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
256 257 258 259 260 261 262 263 264 265 266 267 268 |
# File 'lib/zitadel/client/models/beta_project_service_update_project_request.rb', line 256 def to_hash hash = {} # Calls super.to_hash if parent exists self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
244 245 246 |
# File 'lib/zitadel/client/models/beta_project_service_update_project_request.rb', line 244 def to_s to_hash.to_s end |