Class: Zitadel::Client::Models::BetaSettingsServiceBrandingSettings

Inherits:
Object
  • Object
show all
Defined in:
lib/zitadel/client/models/beta_settings_service_branding_settings.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ BetaSettingsServiceBrandingSettings

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Models attributes in the form of hash



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
# File 'lib/zitadel/client/models/beta_settings_service_branding_settings.rb', line 99

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    # MODIFIED: Updated class name in error message
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zitadel::Client::Models::BetaSettingsServiceBrandingSettings` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      # MODIFIED: Updated class name in error message
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zitadel::Client::Models::BetaSettingsServiceBrandingSettings`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'light_theme')
    self.light_theme = attributes[:'light_theme']
  end

  if attributes.key?(:'dark_theme')
    self.dark_theme = attributes[:'dark_theme']
  end

  if attributes.key?(:'font_url')
    self.font_url = attributes[:'font_url']
  end

  if attributes.key?(:'hide_login_name_suffix')
    self. = attributes[:'hide_login_name_suffix']
  end

  if attributes.key?(:'disable_watermark')
    self.disable_watermark = attributes[:'disable_watermark']
  end

  if attributes.key?(:'resource_owner_type')
    self.resource_owner_type = attributes[:'resource_owner_type']
  end

  if attributes.key?(:'theme_mode')
    self.theme_mode = attributes[:'theme_mode']
  end
end

Instance Attribute Details

#dark_themeObject

Returns the value of attribute dark_theme.



20
21
22
# File 'lib/zitadel/client/models/beta_settings_service_branding_settings.rb', line 20

def dark_theme
  @dark_theme
end

#disable_watermarkObject

Returns the value of attribute disable_watermark.



27
28
29
# File 'lib/zitadel/client/models/beta_settings_service_branding_settings.rb', line 27

def disable_watermark
  @disable_watermark
end

#font_urlObject

Returns the value of attribute font_url.



22
23
24
# File 'lib/zitadel/client/models/beta_settings_service_branding_settings.rb', line 22

def font_url
  @font_url
end

#hide_login_name_suffixObject

hides the org suffix on the login form if the scope \"urn:zitadel:iam:org:domain:primary:domainname\" is set



25
26
27
# File 'lib/zitadel/client/models/beta_settings_service_branding_settings.rb', line 25

def 
  @hide_login_name_suffix
end

#light_themeObject

Returns the value of attribute light_theme.



18
19
20
# File 'lib/zitadel/client/models/beta_settings_service_branding_settings.rb', line 18

def light_theme
  @light_theme
end

#resource_owner_typeObject

Returns the value of attribute resource_owner_type.



29
30
31
# File 'lib/zitadel/client/models/beta_settings_service_branding_settings.rb', line 29

def resource_owner_type
  @resource_owner_type
end

#theme_modeObject

Returns the value of attribute theme_mode.



31
32
33
# File 'lib/zitadel/client/models/beta_settings_service_branding_settings.rb', line 31

def theme_mode
  @theme_mode
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/zitadel/client/models/beta_settings_service_branding_settings.rb', line 197

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf/anyOf constructs that resolve to a model name
    # MODIFIED: Ensure model is looked up in the Models namespace
    # 'type' here is expected to be the simple class name (e.g., "User", "OrderDetails")
    klass = Zitadel::Client::Models.const_get(type)
    # The `klass.build` method is for oneOf/anyOf types (defined in partial_oneof_module.mustache / partial_anyof_module.mustache)
    # The `klass.build_from_hash` is for regular model types (defined in this base_object.mustache itself)
    if klass.respond_to?(:openapi_one_of) || klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_allOf)
      klass.build(value) # For oneOf/anyOf/allOf, delegate to their specific build method
    else
      klass.build_from_hash(value) # For regular models
    end
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



69
70
71
# File 'lib/zitadel/client/models/beta_settings_service_branding_settings.rb', line 69

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



74
75
76
# File 'lib/zitadel/client/models/beta_settings_service_branding_settings.rb', line 74

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



56
57
58
59
60
61
62
63
64
65
66
# File 'lib/zitadel/client/models/beta_settings_service_branding_settings.rb', line 56

def self.attribute_map
  {
    :'light_theme' => :'lightTheme',
    :'dark_theme' => :'darkTheme',
    :'font_url' => :'fontUrl',
    :'hide_login_name_suffix' => :'hideLoginNameSuffix',
    :'disable_watermark' => :'disableWatermark',
    :'resource_owner_type' => :'resourceOwnerType',
    :'theme_mode' => :'themeMode'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Models attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
# File 'lib/zitadel/client/models/beta_settings_service_branding_settings.rb', line 173

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash) # `new` will call the initialize method of the specific model class.
end

.openapi_nullableObject

List of attributes with nullable: true



92
93
94
95
# File 'lib/zitadel/client/models/beta_settings_service_branding_settings.rb', line 92

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



79
80
81
82
83
84
85
86
87
88
89
# File 'lib/zitadel/client/models/beta_settings_service_branding_settings.rb', line 79

def self.openapi_types
  {
    :'light_theme' => :'BetaSettingsServiceTheme',
    :'dark_theme' => :'BetaSettingsServiceTheme',
    :'font_url' => :'String',
    :'hide_login_name_suffix' => :'Boolean',
    :'disable_watermark' => :'Boolean',
    :'resource_owner_type' => :'BetaSettingsServiceResourceOwnerType',
    :'theme_mode' => :'BetaSettingsServiceThemeMode'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



146
147
148
149
150
151
152
153
154
155
156
# File 'lib/zitadel/client/models/beta_settings_service_branding_settings.rb', line 146

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      light_theme == o.light_theme &&
      dark_theme == o.dark_theme &&
      font_url == o.font_url &&
       == o. &&
      disable_watermark == o.disable_watermark &&
      resource_owner_type == o.resource_owner_type &&
      theme_mode == o.theme_mode
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



276
277
278
279
280
281
282
283
284
285
286
287
288
# File 'lib/zitadel/client/models/beta_settings_service_branding_settings.rb', line 276

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


160
161
162
# File 'lib/zitadel/client/models/beta_settings_service_branding_settings.rb', line 160

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



166
167
168
# File 'lib/zitadel/client/models/beta_settings_service_branding_settings.rb', line 166

def hash
  [light_theme, dark_theme, font_url, , disable_watermark, resource_owner_type, theme_mode].hash
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



252
253
254
# File 'lib/zitadel/client/models/beta_settings_service_branding_settings.rb', line 252

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



258
259
260
261
262
263
264
265
266
267
268
269
270
# File 'lib/zitadel/client/models/beta_settings_service_branding_settings.rb', line 258

def to_hash
  hash = {} # Calls super.to_hash if parent exists
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



246
247
248
# File 'lib/zitadel/client/models/beta_settings_service_branding_settings.rb', line 246

def to_s
  to_hash.to_s
end