Class: Zitadel::Client::Models::BetaTelemetryServiceResourceCount

Inherits:
Object
  • Object
show all
Defined in:
lib/zitadel/client/models/beta_telemetry_service_resource_count.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ BetaTelemetryServiceResourceCount

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Models attributes in the form of hash



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'lib/zitadel/client/models/beta_telemetry_service_resource_count.rb', line 104

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    # MODIFIED: Updated class name in error message
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zitadel::Client::Models::BetaTelemetryServiceResourceCount` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      # MODIFIED: Updated class name in error message
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zitadel::Client::Models::BetaTelemetryServiceResourceCount`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'instance_id')
    self.instance_id = attributes[:'instance_id']
  end

  if attributes.key?(:'parent_type')
    self.parent_type = attributes[:'parent_type']
  end

  if attributes.key?(:'parent_id')
    self.parent_id = attributes[:'parent_id']
  end

  if attributes.key?(:'resource_name')
    self.resource_name = attributes[:'resource_name']
  end

  if attributes.key?(:'table_name')
    self.table_name = attributes[:'table_name']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end

  if attributes.key?(:'amount')
    self.amount = attributes[:'amount']
  end
end

Instance Attribute Details

#amountObject

The actual amount of the resource.



36
37
38
# File 'lib/zitadel/client/models/beta_telemetry_service_resource_count.rb', line 36

def amount
  @amount
end

#instance_idObject

The ID of the instance for which the resource counts are reported.



19
20
21
# File 'lib/zitadel/client/models/beta_telemetry_service_resource_count.rb', line 19

def instance_id
  @instance_id
end

#parent_idObject

The parent ID of the resource counts (e.g. organization or instance ID). For example, reporting the amount of users per organization would use ‘COUNT_PARENT_TYPE_ORGANIZATION` as parent type and the organization ID as parent ID.



24
25
26
# File 'lib/zitadel/client/models/beta_telemetry_service_resource_count.rb', line 24

def parent_id
  @parent_id
end

#parent_typeObject

Returns the value of attribute parent_type.



21
22
23
# File 'lib/zitadel/client/models/beta_telemetry_service_resource_count.rb', line 21

def parent_type
  @parent_type
end

#resource_nameObject

The resource counts to report, e.g. amount of ‘users`, `organizations`, etc.



27
28
29
# File 'lib/zitadel/client/models/beta_telemetry_service_resource_count.rb', line 27

def resource_name
  @resource_name
end

#table_nameObject

The name of the table in the database, which was used to calculate the counts. This can be used to deduplicate counts in case of multiple reports. For example, if the counts were calculated from the ‘users14` table, the table name would be `users14`, where there could also be a `users15` table reported at the same time as the system is rolling out a new version.



30
31
32
# File 'lib/zitadel/client/models/beta_telemetry_service_resource_count.rb', line 30

def table_name
  @table_name
end

#updated_atObject

A Timestamp represents a point in time independent of any time zone or local calendar, encoded as a count of seconds and fractions of seconds at nanosecond resolution. The count is relative to an epoch at UTC midnight on January 1, 1970, in the proleptic Gregorian calendar which extends the Gregorian calendar backwards to year one. All minutes are 60 seconds long. Leap seconds are "smeared" so that no leap second table is needed for interpretation, using a [24-hour linear smear](developers.google.com/time/smear). The range is from 0001-01-01T00:00:00Z to 9999-12-31T23:59:59.999999999Z. By restricting to that range, we ensure that we can convert to and from [RFC 3339](www.ietf.org/rfc/rfc3339.txt) date strings. # Examples Example 1: Compute Timestamp from POSIX ‘time()`. Timestamp timestamp; timestamp.set_seconds(time(NULL)); timestamp.set_nanos(0); Example 2: Compute Timestamp from POSIX `gettimeofday()`. struct timeval tv; gettimeofday(&tv, NULL); Timestamp timestamp; timestamp.set_seconds(tv.tv_sec); timestamp.set_nanos(tv.tv_usec * 1000); Example 3: Compute Timestamp from Win32 `GetSystemTimeAsFileTime()`. FILETIME ft; GetSystemTimeAsFileTime(&ft); UINT64 ticks = (((UINT64)ft.dwHighDateTime) << 32) | ft.dwLowDateTime; // A Windows tick is 100 nanoseconds. Windows epoch 1601-01-01T00:00:00Z // is 11644473600 seconds before Unix epoch 1970-01-01T00:00:00Z. Timestamp timestamp; timestamp.set_seconds((INT64) ((ticks / 10000000) - 11644473600LL)); timestamp.set_nanos((INT32) ((ticks % 10000000) * 100)); Example 4: Compute Timestamp from Java `System.currentTimeMillis()`. long millis = System.currentTimeMillis(); Timestamp timestamp = Timestamp.newBuilder().setSeconds(millis / 1000) .setNanos((int) ((millis % 1000) * 1000000)).build(); Example 5: Compute Timestamp from Java `Instant.now()`. Instant now = Instant.now(); Timestamp timestamp = Timestamp.newBuilder().setSeconds(now.getEpochSecond()) .setNanos(now.getNano()).build(); Example 6: Compute Timestamp from current time in Python. timestamp = Timestamp() timestamp.GetCurrentTime() # JSON Mapping In JSON format, the Timestamp type is encoded as a string in the [RFC 3339](www.ietf.org/rfc/rfc3339.txt) format. That is, the format is "year-month-dayThour:min:secZ" where year is always expressed using four digits while month, day, hour, min, and sec are zero-padded to two digits each. The fractional seconds, which can go up to 9 digits (i.e. up to 1 nanosecond resolution), are optional. The "Z" suffix indicates the timezone ("UTC"); the timezone is required. A proto3 JSON serializer should always use UTC (as indicated by "Z") when printing the Timestamp type and a proto3 JSON parser should be able to accept both UTC and other timezones (as indicated by an offset). For example, "2017-01-15T01:30:15.01Z" encodes 15.01 seconds past 01:30 UTC on January 15, 2017. In JavaScript, one can convert a Date object to this format using the standard [toISOString()](developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString) method. In Python, a standard `datetime.datetime` object can be converted to this format using [`strftime`](docs.python.org/2/library/time.html#time.strftime) with the time format spec ’%Y-%m-%dT%H:%M:%S.%fZ’. Likewise, in Java, one can use the Joda Time’s [‘ISODateTimeFormat.dateTime()`]( joda-time.sourceforge.net/apidocs/org/joda/time/format/ISODateTimeFormat.html#dateTime() ) to obtain a formatter capable of generating timestamps in this format.



33
34
35
# File 'lib/zitadel/client/models/beta_telemetry_service_resource_count.rb', line 33

def updated_at
  @updated_at
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
# File 'lib/zitadel/client/models/beta_telemetry_service_resource_count.rb', line 202

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf/anyOf constructs that resolve to a model name
    # MODIFIED: Ensure model is looked up in the Models namespace
    # 'type' here is expected to be the simple class name (e.g., "User", "OrderDetails")
    klass = Zitadel::Client::Models.const_get(type)
    # The `klass.build` method is for oneOf/anyOf types (defined in partial_oneof_module.mustache / partial_anyof_module.mustache)
    # The `klass.build_from_hash` is for regular model types (defined in this base_object.mustache itself)
    if klass.respond_to?(:openapi_one_of) || klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_allOf)
      klass.build(value) # For oneOf/anyOf/allOf, delegate to their specific build method
    else
      klass.build_from_hash(value) # For regular models
    end
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



74
75
76
# File 'lib/zitadel/client/models/beta_telemetry_service_resource_count.rb', line 74

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



79
80
81
# File 'lib/zitadel/client/models/beta_telemetry_service_resource_count.rb', line 79

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



61
62
63
64
65
66
67
68
69
70
71
# File 'lib/zitadel/client/models/beta_telemetry_service_resource_count.rb', line 61

def self.attribute_map
  {
    :'instance_id' => :'instanceId',
    :'parent_type' => :'parentType',
    :'parent_id' => :'parentId',
    :'resource_name' => :'resourceName',
    :'table_name' => :'tableName',
    :'updated_at' => :'updatedAt',
    :'amount' => :'amount'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Models attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
# File 'lib/zitadel/client/models/beta_telemetry_service_resource_count.rb', line 178

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash) # `new` will call the initialize method of the specific model class.
end

.openapi_nullableObject

List of attributes with nullable: true



97
98
99
100
# File 'lib/zitadel/client/models/beta_telemetry_service_resource_count.rb', line 97

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



84
85
86
87
88
89
90
91
92
93
94
# File 'lib/zitadel/client/models/beta_telemetry_service_resource_count.rb', line 84

def self.openapi_types
  {
    :'instance_id' => :'String',
    :'parent_type' => :'BetaTelemetryServiceCountParentType',
    :'parent_id' => :'String',
    :'resource_name' => :'String',
    :'table_name' => :'String',
    :'updated_at' => :'Time',
    :'amount' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



151
152
153
154
155
156
157
158
159
160
161
# File 'lib/zitadel/client/models/beta_telemetry_service_resource_count.rb', line 151

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      instance_id == o.instance_id &&
      parent_type == o.parent_type &&
      parent_id == o.parent_id &&
      resource_name == o.resource_name &&
      table_name == o.table_name &&
      updated_at == o.updated_at &&
      amount == o.amount
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



281
282
283
284
285
286
287
288
289
290
291
292
293
# File 'lib/zitadel/client/models/beta_telemetry_service_resource_count.rb', line 281

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


165
166
167
# File 'lib/zitadel/client/models/beta_telemetry_service_resource_count.rb', line 165

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



171
172
173
# File 'lib/zitadel/client/models/beta_telemetry_service_resource_count.rb', line 171

def hash
  [instance_id, parent_type, parent_id, resource_name, table_name, updated_at, amount].hash
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



257
258
259
# File 'lib/zitadel/client/models/beta_telemetry_service_resource_count.rb', line 257

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'lib/zitadel/client/models/beta_telemetry_service_resource_count.rb', line 263

def to_hash
  hash = {} # Calls super.to_hash if parent exists
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



251
252
253
# File 'lib/zitadel/client/models/beta_telemetry_service_resource_count.rb', line 251

def to_s
  to_hash.to_s
end