Class: Zitadel::Client::Models::BetaUserServiceHumanUser
- Inherits:
-
Object
- Object
- Zitadel::Client::Models::BetaUserServiceHumanUser
- Defined in:
- lib/zitadel/client/models/beta_user_service_human_user.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#email ⇒ Object
Returns the value of attribute email.
-
#login_names ⇒ Object
Possible usable login names for the user.
-
#password_change_required ⇒ Object
User is required to change the used password on the next login.
-
#password_changed ⇒ Object
A Timestamp represents a point in time independent of any time zone or local calendar, encoded as a count of seconds and fractions of seconds at nanosecond resolution.
-
#phone ⇒ Object
Returns the value of attribute phone.
-
#preferred_login_name ⇒ Object
Preferred login name of the user.
-
#profile ⇒ Object
Returns the value of attribute profile.
-
#state ⇒ Object
Returns the value of attribute state.
-
#user_id ⇒ Object
Unique identifier of the user.
-
#username ⇒ Object
Username of the user, which can be globally unique or unique on organization level.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BetaUserServiceHumanUser
constructor
Initializes the object.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ BetaUserServiceHumanUser
Initializes the object
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'lib/zitadel/client/models/beta_user_service_human_user.rb', line 116 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) # MODIFIED: Updated class name in error message fail ArgumentError, "The input argument (attributes) must be a hash in `Zitadel::Client::Models::BetaUserServiceHumanUser` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) # MODIFIED: Updated class name in error message fail ArgumentError, "`#{k}` is not a valid attribute in `Zitadel::Client::Models::BetaUserServiceHumanUser`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'user_id') self.user_id = attributes[:'user_id'] end if attributes.key?(:'state') self.state = attributes[:'state'] end if attributes.key?(:'username') self.username = attributes[:'username'] end if attributes.key?(:'login_names') if (value = attributes[:'login_names']).is_a?(Array) self.login_names = value end end if attributes.key?(:'preferred_login_name') self.preferred_login_name = attributes[:'preferred_login_name'] end if attributes.key?(:'profile') self.profile = attributes[:'profile'] end if attributes.key?(:'email') self.email = attributes[:'email'] end if attributes.key?(:'phone') self.phone = attributes[:'phone'] end if attributes.key?(:'password_change_required') self.password_change_required = attributes[:'password_change_required'] end if attributes.key?(:'password_changed') self.password_changed = attributes[:'password_changed'] end end |
Instance Attribute Details
#email ⇒ Object
Returns the value of attribute email.
34 35 36 |
# File 'lib/zitadel/client/models/beta_user_service_human_user.rb', line 34 def email @email end |
#login_names ⇒ Object
Possible usable login names for the user.
27 28 29 |
# File 'lib/zitadel/client/models/beta_user_service_human_user.rb', line 27 def login_names @login_names end |
#password_change_required ⇒ Object
User is required to change the used password on the next login.
39 40 41 |
# File 'lib/zitadel/client/models/beta_user_service_human_user.rb', line 39 def password_change_required @password_change_required end |
#password_changed ⇒ Object
A Timestamp represents a point in time independent of any time zone or local calendar, encoded as a count of seconds and fractions of seconds at nanosecond resolution. The count is relative to an epoch at UTC midnight on January 1, 1970, in the proleptic Gregorian calendar which extends the Gregorian calendar backwards to year one. All minutes are 60 seconds long. Leap seconds are "smeared" so that no leap second table is needed for interpretation, using a [24-hour linear smear](developers.google.com/time/smear). The range is from 0001-01-01T00:00:00Z to 9999-12-31T23:59:59.999999999Z. By restricting to that range, we ensure that we can convert to and from [RFC 3339](www.ietf.org/rfc/rfc3339.txt) date strings. # Examples Example 1: Compute Timestamp from POSIX ‘time()`. Timestamp timestamp; timestamp.set_seconds(time(NULL)); timestamp.set_nanos(0); Example 2: Compute Timestamp from POSIX `gettimeofday()`. struct timeval tv; gettimeofday(&tv, NULL); Timestamp timestamp; timestamp.set_seconds(tv.tv_sec); timestamp.set_nanos(tv.tv_usec * 1000); Example 3: Compute Timestamp from Win32 `GetSystemTimeAsFileTime()`. FILETIME ft; GetSystemTimeAsFileTime(&ft); UINT64 ticks = (((UINT64)ft.dwHighDateTime) << 32) | ft.dwLowDateTime; // A Windows tick is 100 nanoseconds. Windows epoch 1601-01-01T00:00:00Z // is 11644473600 seconds before Unix epoch 1970-01-01T00:00:00Z. Timestamp timestamp; timestamp.set_seconds((INT64) ((ticks / 10000000) - 11644473600LL)); timestamp.set_nanos((INT32) ((ticks % 10000000) * 100)); Example 4: Compute Timestamp from Java `System.currentTimeMillis()`. long millis = System.currentTimeMillis(); Timestamp timestamp = Timestamp.newBuilder().setSeconds(millis / 1000) .setNanos((int) ((millis % 1000) * 1000000)).build(); Example 5: Compute Timestamp from Java `Instant.now()`. Instant now = Instant.now(); Timestamp timestamp = Timestamp.newBuilder().setSeconds(now.getEpochSecond()) .setNanos(now.getNano()).build(); Example 6: Compute Timestamp from current time in Python. timestamp = Timestamp() timestamp.GetCurrentTime() # JSON Mapping In JSON format, the Timestamp type is encoded as a string in the [RFC 3339](www.ietf.org/rfc/rfc3339.txt) format. That is, the format is "year-month-dayThour:min:secZ" where year is always expressed using four digits while month, day, hour, min, and sec are zero-padded to two digits each. The fractional seconds, which can go up to 9 digits (i.e. up to 1 nanosecond resolution), are optional. The "Z" suffix indicates the timezone ("UTC"); the timezone is required. A proto3 JSON serializer should always use UTC (as indicated by "Z") when printing the Timestamp type and a proto3 JSON parser should be able to accept both UTC and other timezones (as indicated by an offset). For example, "2017-01-15T01:30:15.01Z" encodes 15.01 seconds past 01:30 UTC on January 15, 2017. In JavaScript, one can convert a Date object to this format using the standard [toISOString()](developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString) method. In Python, a standard `datetime.datetime` object can be converted to this format using [`strftime`](docs.python.org/2/library/time.html#time.strftime) with the time format spec ’%Y-%m-%dT%H:%M:%S.%fZ’. Likewise, in Java, one can use the Joda Time’s [‘ISODateTimeFormat.dateTime()`]( joda-time.sourceforge.net/apidocs/org/joda/time/format/ISODateTimeFormat.html#dateTime() ) to obtain a formatter capable of generating timestamps in this format.
42 43 44 |
# File 'lib/zitadel/client/models/beta_user_service_human_user.rb', line 42 def password_changed @password_changed end |
#phone ⇒ Object
Returns the value of attribute phone.
36 37 38 |
# File 'lib/zitadel/client/models/beta_user_service_human_user.rb', line 36 def phone @phone end |
#preferred_login_name ⇒ Object
Preferred login name of the user.
30 31 32 |
# File 'lib/zitadel/client/models/beta_user_service_human_user.rb', line 30 def preferred_login_name @preferred_login_name end |
#profile ⇒ Object
Returns the value of attribute profile.
32 33 34 |
# File 'lib/zitadel/client/models/beta_user_service_human_user.rb', line 32 def profile @profile end |
#state ⇒ Object
Returns the value of attribute state.
21 22 23 |
# File 'lib/zitadel/client/models/beta_user_service_human_user.rb', line 21 def state @state end |
#user_id ⇒ Object
Unique identifier of the user.
19 20 21 |
# File 'lib/zitadel/client/models/beta_user_service_human_user.rb', line 19 def user_id @user_id end |
#username ⇒ Object
Username of the user, which can be globally unique or unique on organization level.
24 25 26 |
# File 'lib/zitadel/client/models/beta_user_service_human_user.rb', line 24 def username @username end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 |
# File 'lib/zitadel/client/models/beta_user_service_human_user.rb', line 231 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf/anyOf constructs that resolve to a model name # MODIFIED: Ensure model is looked up in the Models namespace # 'type' here is expected to be the simple class name (e.g., "User", "OrderDetails") klass = Zitadel::Client::Models.const_get(type) # The `klass.build` method is for oneOf/anyOf types (defined in partial_oneof_module.mustache / partial_anyof_module.mustache) # The `klass.build_from_hash` is for regular model types (defined in this base_object.mustache itself) if klass.respond_to?(:openapi_one_of) || klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_allOf) klass.build(value) # For oneOf/anyOf/allOf, delegate to their specific build method else klass.build_from_hash(value) # For regular models end end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
83 84 85 |
# File 'lib/zitadel/client/models/beta_user_service_human_user.rb', line 83 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
88 89 90 |
# File 'lib/zitadel/client/models/beta_user_service_human_user.rb', line 88 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/zitadel/client/models/beta_user_service_human_user.rb', line 67 def self.attribute_map { :'user_id' => :'userId', :'state' => :'state', :'username' => :'username', :'login_names' => :'loginNames', :'preferred_login_name' => :'preferredLoginName', :'profile' => :'profile', :'email' => :'email', :'phone' => :'phone', :'password_change_required' => :'passwordChangeRequired', :'password_changed' => :'passwordChanged' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/zitadel/client/models/beta_user_service_human_user.rb', line 207 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) # `new` will call the initialize method of the specific model class. end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
109 110 111 112 |
# File 'lib/zitadel/client/models/beta_user_service_human_user.rb', line 109 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/zitadel/client/models/beta_user_service_human_user.rb', line 93 def self.openapi_types { :'user_id' => :'String', :'state' => :'BetaUserServiceUserState', :'username' => :'String', :'login_names' => :'Array<String>', :'preferred_login_name' => :'String', :'profile' => :'BetaUserServiceHumanProfile', :'email' => :'BetaUserServiceHumanEmail', :'phone' => :'BetaUserServiceHumanPhone', :'password_change_required' => :'Boolean', :'password_changed' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
177 178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/zitadel/client/models/beta_user_service_human_user.rb', line 177 def ==(o) return true if self.equal?(o) self.class == o.class && user_id == o.user_id && state == o.state && username == o.username && login_names == o.login_names && preferred_login_name == o.preferred_login_name && profile == o.profile && email == o.email && phone == o.phone && password_change_required == o.password_change_required && password_changed == o.password_changed end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
310 311 312 313 314 315 316 317 318 319 320 321 322 |
# File 'lib/zitadel/client/models/beta_user_service_human_user.rb', line 310 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
194 195 196 |
# File 'lib/zitadel/client/models/beta_user_service_human_user.rb', line 194 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
200 201 202 |
# File 'lib/zitadel/client/models/beta_user_service_human_user.rb', line 200 def hash [user_id, state, username, login_names, preferred_login_name, profile, email, phone, password_change_required, password_changed].hash end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
286 287 288 |
# File 'lib/zitadel/client/models/beta_user_service_human_user.rb', line 286 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
292 293 294 295 296 297 298 299 300 301 302 303 304 |
# File 'lib/zitadel/client/models/beta_user_service_human_user.rb', line 292 def to_hash hash = {} # Calls super.to_hash if parent exists self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
280 281 282 |
# File 'lib/zitadel/client/models/beta_user_service_human_user.rb', line 280 def to_s to_hash.to_s end |