Class: Zitadel::Client::Models::BetaUserServiceStartIdentityProviderIntentResponse

Inherits:
Object
  • Object
show all
Defined in:
lib/zitadel/client/models/beta_user_service_start_identity_provider_intent_response.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ BetaUserServiceStartIdentityProviderIntentResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Models attributes in the form of hash



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/zitadel/client/models/beta_user_service_start_identity_provider_intent_response.rb', line 70

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    # MODIFIED: Updated class name in error message
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zitadel::Client::Models::BetaUserServiceStartIdentityProviderIntentResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      # MODIFIED: Updated class name in error message
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zitadel::Client::Models::BetaUserServiceStartIdentityProviderIntentResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'details')
    self.details = attributes[:'details']
  end

  if attributes.key?(:'auth_url')
    self.auth_url = attributes[:'auth_url']
  end

  if attributes.key?(:'form_data')
    self.form_data = attributes[:'form_data']
  end

  if attributes.key?(:'idp_intent')
    self.idp_intent = attributes[:'idp_intent']
  end

  if attributes.key?(:'post_form')
    self.post_form = attributes[:'post_form']
  end
end

Instance Attribute Details

#auth_urlObject

URL to which the client should redirect



21
22
23
# File 'lib/zitadel/client/models/beta_user_service_start_identity_provider_intent_response.rb', line 21

def auth_url
  @auth_url
end

#detailsObject

Returns the value of attribute details.



18
19
20
# File 'lib/zitadel/client/models/beta_user_service_start_identity_provider_intent_response.rb', line 18

def details
  @details
end

#form_dataObject

Returns the value of attribute form_data.



23
24
25
# File 'lib/zitadel/client/models/beta_user_service_start_identity_provider_intent_response.rb', line 23

def form_data
  @form_data
end

#idp_intentObject

Returns the value of attribute idp_intent.



25
26
27
# File 'lib/zitadel/client/models/beta_user_service_start_identity_provider_intent_response.rb', line 25

def idp_intent
  @idp_intent
end

#post_formObject

POST call information Deprecated: Use form_data instead



28
29
30
# File 'lib/zitadel/client/models/beta_user_service_start_identity_provider_intent_response.rb', line 28

def post_form
  @post_form
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
# File 'lib/zitadel/client/models/beta_user_service_start_identity_provider_intent_response.rb', line 158

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf/anyOf constructs that resolve to a model name
    # MODIFIED: Ensure model is looked up in the Models namespace
    # 'type' here is expected to be the simple class name (e.g., "User", "OrderDetails")
    klass = Zitadel::Client::Models.const_get(type)
    # The `klass.build` method is for oneOf/anyOf types (defined in partial_oneof_module.mustache / partial_anyof_module.mustache)
    # The `klass.build_from_hash` is for regular model types (defined in this base_object.mustache itself)
    if klass.respond_to?(:openapi_one_of) || klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_allOf)
      klass.build(value) # For oneOf/anyOf/allOf, delegate to their specific build method
    else
      klass.build_from_hash(value) # For regular models
    end
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



42
43
44
# File 'lib/zitadel/client/models/beta_user_service_start_identity_provider_intent_response.rb', line 42

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



47
48
49
# File 'lib/zitadel/client/models/beta_user_service_start_identity_provider_intent_response.rb', line 47

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



31
32
33
34
35
36
37
38
39
# File 'lib/zitadel/client/models/beta_user_service_start_identity_provider_intent_response.rb', line 31

def self.attribute_map
  {
    :'details' => :'details',
    :'auth_url' => :'authUrl',
    :'form_data' => :'formData',
    :'idp_intent' => :'idpIntent',
    :'post_form' => :'postForm'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Models attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'lib/zitadel/client/models/beta_user_service_start_identity_provider_intent_response.rb', line 134

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash) # `new` will call the initialize method of the specific model class.
end

.openapi_nullableObject

List of attributes with nullable: true



63
64
65
66
# File 'lib/zitadel/client/models/beta_user_service_start_identity_provider_intent_response.rb', line 63

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



52
53
54
55
56
57
58
59
60
# File 'lib/zitadel/client/models/beta_user_service_start_identity_provider_intent_response.rb', line 52

def self.openapi_types
  {
    :'details' => :'BetaUserServiceDetails',
    :'auth_url' => :'String',
    :'form_data' => :'BetaUserServiceFormData',
    :'idp_intent' => :'BetaUserServiceIDPIntent',
    :'post_form' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



109
110
111
112
113
114
115
116
117
# File 'lib/zitadel/client/models/beta_user_service_start_identity_provider_intent_response.rb', line 109

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      details == o.details &&
      auth_url == o.auth_url &&
      form_data == o.form_data &&
      idp_intent == o.idp_intent &&
      post_form == o.post_form
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



237
238
239
240
241
242
243
244
245
246
247
248
249
# File 'lib/zitadel/client/models/beta_user_service_start_identity_provider_intent_response.rb', line 237

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


121
122
123
# File 'lib/zitadel/client/models/beta_user_service_start_identity_provider_intent_response.rb', line 121

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



127
128
129
# File 'lib/zitadel/client/models/beta_user_service_start_identity_provider_intent_response.rb', line 127

def hash
  [details, auth_url, form_data, idp_intent, post_form].hash
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



213
214
215
# File 'lib/zitadel/client/models/beta_user_service_start_identity_provider_intent_response.rb', line 213

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



219
220
221
222
223
224
225
226
227
228
229
230
231
# File 'lib/zitadel/client/models/beta_user_service_start_identity_provider_intent_response.rb', line 219

def to_hash
  hash = {} # Calls super.to_hash if parent exists
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



207
208
209
# File 'lib/zitadel/client/models/beta_user_service_start_identity_provider_intent_response.rb', line 207

def to_s
  to_hash.to_s
end