Class: Zitadel::Client::Models::FeatureServiceGetInstanceFeaturesResponse
- Inherits:
-
Object
- Object
- Zitadel::Client::Models::FeatureServiceGetInstanceFeaturesResponse
- Defined in:
- lib/zitadel/client/models/feature_service_get_instance_features_response.rb
Instance Attribute Summary collapse
-
#console_use_v2_user_api ⇒ Object
Returns the value of attribute console_use_v2_user_api.
-
#debug_oidc_parent_error ⇒ Object
Returns the value of attribute debug_oidc_parent_error.
-
#details ⇒ Object
Returns the value of attribute details.
-
#enable_back_channel_logout ⇒ Object
Returns the value of attribute enable_back_channel_logout.
-
#improved_performance ⇒ Object
Returns the value of attribute improved_performance.
-
#login_default_org ⇒ Object
Returns the value of attribute login_default_org.
-
#login_v2 ⇒ Object
Returns the value of attribute login_v2.
-
#oidc_single_v1_session_termination ⇒ Object
Returns the value of attribute oidc_single_v1_session_termination.
-
#oidc_token_exchange ⇒ Object
Returns the value of attribute oidc_token_exchange.
-
#permission_check_v2 ⇒ Object
Returns the value of attribute permission_check_v2.
-
#user_schema ⇒ Object
Returns the value of attribute user_schema.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ FeatureServiceGetInstanceFeaturesResponse
constructor
Initializes the object.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ FeatureServiceGetInstanceFeaturesResponse
Initializes the object
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/zitadel/client/models/feature_service_get_instance_features_response.rb', line 92 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) # MODIFIED: Updated class name in error message fail ArgumentError, "The input argument (attributes) must be a hash in `Zitadel::Client::Models::FeatureServiceGetInstanceFeaturesResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) # MODIFIED: Updated class name in error message fail ArgumentError, "`#{k}` is not a valid attribute in `Zitadel::Client::Models::FeatureServiceGetInstanceFeaturesResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'details') self.details = attributes[:'details'] end if attributes.key?(:'login_default_org') self.login_default_org = attributes[:'login_default_org'] end if attributes.key?(:'user_schema') self.user_schema = attributes[:'user_schema'] end if attributes.key?(:'oidc_token_exchange') self.oidc_token_exchange = attributes[:'oidc_token_exchange'] end if attributes.key?(:'improved_performance') self.improved_performance = attributes[:'improved_performance'] end if attributes.key?(:'debug_oidc_parent_error') self.debug_oidc_parent_error = attributes[:'debug_oidc_parent_error'] end if attributes.key?(:'oidc_single_v1_session_termination') self.oidc_single_v1_session_termination = attributes[:'oidc_single_v1_session_termination'] end if attributes.key?(:'enable_back_channel_logout') self.enable_back_channel_logout = attributes[:'enable_back_channel_logout'] end if attributes.key?(:'login_v2') self.login_v2 = attributes[:'login_v2'] end if attributes.key?(:'permission_check_v2') self. = attributes[:'permission_check_v2'] end if attributes.key?(:'console_use_v2_user_api') self.console_use_v2_user_api = attributes[:'console_use_v2_user_api'] end end |
Instance Attribute Details
#console_use_v2_user_api ⇒ Object
Returns the value of attribute console_use_v2_user_api.
38 39 40 |
# File 'lib/zitadel/client/models/feature_service_get_instance_features_response.rb', line 38 def console_use_v2_user_api @console_use_v2_user_api end |
#debug_oidc_parent_error ⇒ Object
Returns the value of attribute debug_oidc_parent_error.
28 29 30 |
# File 'lib/zitadel/client/models/feature_service_get_instance_features_response.rb', line 28 def debug_oidc_parent_error @debug_oidc_parent_error end |
#details ⇒ Object
Returns the value of attribute details.
18 19 20 |
# File 'lib/zitadel/client/models/feature_service_get_instance_features_response.rb', line 18 def details @details end |
#enable_back_channel_logout ⇒ Object
Returns the value of attribute enable_back_channel_logout.
32 33 34 |
# File 'lib/zitadel/client/models/feature_service_get_instance_features_response.rb', line 32 def enable_back_channel_logout @enable_back_channel_logout end |
#improved_performance ⇒ Object
Returns the value of attribute improved_performance.
26 27 28 |
# File 'lib/zitadel/client/models/feature_service_get_instance_features_response.rb', line 26 def improved_performance @improved_performance end |
#login_default_org ⇒ Object
Returns the value of attribute login_default_org.
20 21 22 |
# File 'lib/zitadel/client/models/feature_service_get_instance_features_response.rb', line 20 def login_default_org @login_default_org end |
#login_v2 ⇒ Object
Returns the value of attribute login_v2.
34 35 36 |
# File 'lib/zitadel/client/models/feature_service_get_instance_features_response.rb', line 34 def login_v2 @login_v2 end |
#oidc_single_v1_session_termination ⇒ Object
Returns the value of attribute oidc_single_v1_session_termination.
30 31 32 |
# File 'lib/zitadel/client/models/feature_service_get_instance_features_response.rb', line 30 def oidc_single_v1_session_termination @oidc_single_v1_session_termination end |
#oidc_token_exchange ⇒ Object
Returns the value of attribute oidc_token_exchange.
24 25 26 |
# File 'lib/zitadel/client/models/feature_service_get_instance_features_response.rb', line 24 def oidc_token_exchange @oidc_token_exchange end |
#permission_check_v2 ⇒ Object
Returns the value of attribute permission_check_v2.
36 37 38 |
# File 'lib/zitadel/client/models/feature_service_get_instance_features_response.rb', line 36 def @permission_check_v2 end |
#user_schema ⇒ Object
Returns the value of attribute user_schema.
22 23 24 |
# File 'lib/zitadel/client/models/feature_service_get_instance_features_response.rb', line 22 def user_schema @user_schema end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'lib/zitadel/client/models/feature_service_get_instance_features_response.rb', line 210 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf/anyOf constructs that resolve to a model name # MODIFIED: Ensure model is looked up in the Models namespace # 'type' here is expected to be the simple class name (e.g., "User", "OrderDetails") klass = Zitadel::Client::Models.const_get(type) # The `klass.build` method is for oneOf/anyOf types (defined in partial_oneof_module.mustache / partial_anyof_module.mustache) # The `klass.build_from_hash` is for regular model types (defined in this base_object.mustache itself) if klass.respond_to?(:openapi_one_of) || klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_allOf) klass.build(value) # For oneOf/anyOf/allOf, delegate to their specific build method else klass.build_from_hash(value) # For regular models end end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
58 59 60 |
# File 'lib/zitadel/client/models/feature_service_get_instance_features_response.rb', line 58 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
63 64 65 |
# File 'lib/zitadel/client/models/feature_service_get_instance_features_response.rb', line 63 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/zitadel/client/models/feature_service_get_instance_features_response.rb', line 41 def self.attribute_map { :'details' => :'details', :'login_default_org' => :'loginDefaultOrg', :'user_schema' => :'userSchema', :'oidc_token_exchange' => :'oidcTokenExchange', :'improved_performance' => :'improvedPerformance', :'debug_oidc_parent_error' => :'debugOidcParentError', :'oidc_single_v1_session_termination' => :'oidcSingleV1SessionTermination', :'enable_back_channel_logout' => :'enableBackChannelLogout', :'login_v2' => :'loginV2', :'permission_check_v2' => :'permissionCheckV2', :'console_use_v2_user_api' => :'consoleUseV2UserApi' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 |
# File 'lib/zitadel/client/models/feature_service_get_instance_features_response.rb', line 186 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) # `new` will call the initialize method of the specific model class. end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
85 86 87 88 |
# File 'lib/zitadel/client/models/feature_service_get_instance_features_response.rb', line 85 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/zitadel/client/models/feature_service_get_instance_features_response.rb', line 68 def self.openapi_types { :'details' => :'FeatureServiceDetails', :'login_default_org' => :'FeatureServiceFeatureFlag', :'user_schema' => :'FeatureServiceFeatureFlag', :'oidc_token_exchange' => :'FeatureServiceFeatureFlag', :'improved_performance' => :'FeatureServiceImprovedPerformanceFeatureFlag', :'debug_oidc_parent_error' => :'FeatureServiceFeatureFlag', :'oidc_single_v1_session_termination' => :'FeatureServiceFeatureFlag', :'enable_back_channel_logout' => :'FeatureServiceFeatureFlag', :'login_v2' => :'FeatureServiceLoginV2FeatureFlag', :'permission_check_v2' => :'FeatureServiceFeatureFlag', :'console_use_v2_user_api' => :'FeatureServiceFeatureFlag' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/zitadel/client/models/feature_service_get_instance_features_response.rb', line 155 def ==(o) return true if self.equal?(o) self.class == o.class && details == o.details && login_default_org == o.login_default_org && user_schema == o.user_schema && oidc_token_exchange == o.oidc_token_exchange && improved_performance == o.improved_performance && debug_oidc_parent_error == o.debug_oidc_parent_error && oidc_single_v1_session_termination == o.oidc_single_v1_session_termination && enable_back_channel_logout == o.enable_back_channel_logout && login_v2 == o.login_v2 && == o. && console_use_v2_user_api == o.console_use_v2_user_api end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
289 290 291 292 293 294 295 296 297 298 299 300 301 |
# File 'lib/zitadel/client/models/feature_service_get_instance_features_response.rb', line 289 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
173 174 175 |
# File 'lib/zitadel/client/models/feature_service_get_instance_features_response.rb', line 173 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
179 180 181 |
# File 'lib/zitadel/client/models/feature_service_get_instance_features_response.rb', line 179 def hash [details, login_default_org, user_schema, oidc_token_exchange, improved_performance, debug_oidc_parent_error, oidc_single_v1_session_termination, enable_back_channel_logout, login_v2, , console_use_v2_user_api].hash end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
265 266 267 |
# File 'lib/zitadel/client/models/feature_service_get_instance_features_response.rb', line 265 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
271 272 273 274 275 276 277 278 279 280 281 282 283 |
# File 'lib/zitadel/client/models/feature_service_get_instance_features_response.rb', line 271 def to_hash hash = {} # Calls super.to_hash if parent exists self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
259 260 261 |
# File 'lib/zitadel/client/models/feature_service_get_instance_features_response.rb', line 259 def to_s to_hash.to_s end |