Class: Zitadel::Client::Models::InternalPermissionServiceAdministratorSearchFilter

Inherits:
Object
  • Object
show all
Defined in:
lib/zitadel/client/models/internal_permission_service_administrator_search_filter.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ InternalPermissionServiceAdministratorSearchFilter

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Models attributes in the form of hash



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/zitadel/client/models/internal_permission_service_administrator_search_filter.rb', line 92

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    # MODIFIED: Updated class name in error message
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zitadel::Client::Models::InternalPermissionServiceAdministratorSearchFilter` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      # MODIFIED: Updated class name in error message
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zitadel::Client::Models::InternalPermissionServiceAdministratorSearchFilter`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'_and')
    self._and = attributes[:'_and']
  end

  if attributes.key?(:'change_date')
    self.change_date = attributes[:'change_date']
  end

  if attributes.key?(:'creation_date')
    self.creation_date = attributes[:'creation_date']
  end

  if attributes.key?(:'in_user_ids_filter')
    self.in_user_ids_filter = attributes[:'in_user_ids_filter']
  end

  if attributes.key?(:'_not')
    self._not = attributes[:'_not']
  end

  if attributes.key?(:'_or')
    self._or = attributes[:'_or']
  end

  if attributes.key?(:'resource')
    self.resource = attributes[:'resource']
  end

  if attributes.key?(:'role')
    self.role = attributes[:'role']
  end

  if attributes.key?(:'user_display_name')
    self.user_display_name = attributes[:'user_display_name']
  end

  if attributes.key?(:'user_organization_id')
    self.user_organization_id = attributes[:'user_organization_id']
  end

  if attributes.key?(:'user_preferred_login_name')
    self. = attributes[:'user_preferred_login_name']
  end
end

Instance Attribute Details

#_andObject

Returns the value of attribute _and.



18
19
20
# File 'lib/zitadel/client/models/internal_permission_service_administrator_search_filter.rb', line 18

def _and
  @_and
end

#_notObject

Returns the value of attribute _not.



26
27
28
# File 'lib/zitadel/client/models/internal_permission_service_administrator_search_filter.rb', line 26

def _not
  @_not
end

#_orObject

Returns the value of attribute _or.



28
29
30
# File 'lib/zitadel/client/models/internal_permission_service_administrator_search_filter.rb', line 28

def _or
  @_or
end

#change_dateObject

Returns the value of attribute change_date.



20
21
22
# File 'lib/zitadel/client/models/internal_permission_service_administrator_search_filter.rb', line 20

def change_date
  @change_date
end

#creation_dateObject

Returns the value of attribute creation_date.



22
23
24
# File 'lib/zitadel/client/models/internal_permission_service_administrator_search_filter.rb', line 22

def creation_date
  @creation_date
end

#in_user_ids_filterObject

Returns the value of attribute in_user_ids_filter.



24
25
26
# File 'lib/zitadel/client/models/internal_permission_service_administrator_search_filter.rb', line 24

def in_user_ids_filter
  @in_user_ids_filter
end

#resourceObject

Returns the value of attribute resource.



30
31
32
# File 'lib/zitadel/client/models/internal_permission_service_administrator_search_filter.rb', line 30

def resource
  @resource
end

#roleObject

Returns the value of attribute role.



32
33
34
# File 'lib/zitadel/client/models/internal_permission_service_administrator_search_filter.rb', line 32

def role
  @role
end

#user_display_nameObject

Returns the value of attribute user_display_name.



34
35
36
# File 'lib/zitadel/client/models/internal_permission_service_administrator_search_filter.rb', line 34

def user_display_name
  @user_display_name
end

#user_organization_idObject

Returns the value of attribute user_organization_id.



36
37
38
# File 'lib/zitadel/client/models/internal_permission_service_administrator_search_filter.rb', line 36

def user_organization_id
  @user_organization_id
end

#user_preferred_login_nameObject

Returns the value of attribute user_preferred_login_name.



38
39
40
# File 'lib/zitadel/client/models/internal_permission_service_administrator_search_filter.rb', line 38

def 
  @user_preferred_login_name
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'lib/zitadel/client/models/internal_permission_service_administrator_search_filter.rb', line 210

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf/anyOf constructs that resolve to a model name
    # MODIFIED: Ensure model is looked up in the Models namespace
    # 'type' here is expected to be the simple class name (e.g., "User", "OrderDetails")
    klass = Zitadel::Client::Models.const_get(type)
    # The `klass.build` method is for oneOf/anyOf types (defined in partial_oneof_module.mustache / partial_anyof_module.mustache)
    # The `klass.build_from_hash` is for regular model types (defined in this base_object.mustache itself)
    if klass.respond_to?(:openapi_one_of) || klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_allOf)
      klass.build(value) # For oneOf/anyOf/allOf, delegate to their specific build method
    else
      klass.build_from_hash(value) # For regular models
    end
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



58
59
60
# File 'lib/zitadel/client/models/internal_permission_service_administrator_search_filter.rb', line 58

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



63
64
65
# File 'lib/zitadel/client/models/internal_permission_service_administrator_search_filter.rb', line 63

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
# File 'lib/zitadel/client/models/internal_permission_service_administrator_search_filter.rb', line 41

def self.attribute_map
  {
    :'_and' => :'and',
    :'change_date' => :'changeDate',
    :'creation_date' => :'creationDate',
    :'in_user_ids_filter' => :'inUserIdsFilter',
    :'_not' => :'not',
    :'_or' => :'or',
    :'resource' => :'resource',
    :'role' => :'role',
    :'user_display_name' => :'userDisplayName',
    :'user_organization_id' => :'userOrganizationId',
    :'user_preferred_login_name' => :'userPreferredLoginName'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Models attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
# File 'lib/zitadel/client/models/internal_permission_service_administrator_search_filter.rb', line 186

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash) # `new` will call the initialize method of the specific model class.
end

.openapi_nullableObject

List of attributes with nullable: true



85
86
87
88
# File 'lib/zitadel/client/models/internal_permission_service_administrator_search_filter.rb', line 85

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/zitadel/client/models/internal_permission_service_administrator_search_filter.rb', line 68

def self.openapi_types
  {
    :'_and' => :'InternalPermissionServiceAndFilter',
    :'change_date' => :'InternalPermissionServiceTimestampFilter',
    :'creation_date' => :'InternalPermissionServiceTimestampFilter',
    :'in_user_ids_filter' => :'InternalPermissionServiceInIDsFilter',
    :'_not' => :'InternalPermissionServiceNotFilter',
    :'_or' => :'InternalPermissionServiceOrFilter',
    :'resource' => :'InternalPermissionServiceResourceFilter',
    :'role' => :'InternalPermissionServiceRoleFilter',
    :'user_display_name' => :'InternalPermissionServiceUserDisplayNameFilter',
    :'user_organization_id' => :'InternalPermissionServiceIDFilter',
    :'user_preferred_login_name' => :'InternalPermissionServiceUserPreferredLoginNameFilter'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
# File 'lib/zitadel/client/models/internal_permission_service_administrator_search_filter.rb', line 155

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      _and == o._and &&
      change_date == o.change_date &&
      creation_date == o.creation_date &&
      in_user_ids_filter == o.in_user_ids_filter &&
      _not == o._not &&
      _or == o._or &&
      resource == o.resource &&
      role == o.role &&
      user_display_name == o.user_display_name &&
      user_organization_id == o.user_organization_id &&
       == o.
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



289
290
291
292
293
294
295
296
297
298
299
300
301
# File 'lib/zitadel/client/models/internal_permission_service_administrator_search_filter.rb', line 289

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


173
174
175
# File 'lib/zitadel/client/models/internal_permission_service_administrator_search_filter.rb', line 173

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



179
180
181
# File 'lib/zitadel/client/models/internal_permission_service_administrator_search_filter.rb', line 179

def hash
  [_and, change_date, creation_date, in_user_ids_filter, _not, _or, resource, role, user_display_name, user_organization_id, ].hash
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



265
266
267
# File 'lib/zitadel/client/models/internal_permission_service_administrator_search_filter.rb', line 265

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



271
272
273
274
275
276
277
278
279
280
281
282
283
# File 'lib/zitadel/client/models/internal_permission_service_administrator_search_filter.rb', line 271

def to_hash
  hash = {} # Calls super.to_hash if parent exists
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



259
260
261
# File 'lib/zitadel/client/models/internal_permission_service_administrator_search_filter.rb', line 259

def to_s
  to_hash.to_s
end