Class: Zitadel::Client::Models::InternalPermissionServiceCreateAdministratorRequest
- Inherits:
-
Object
- Object
- Zitadel::Client::Models::InternalPermissionServiceCreateAdministratorRequest
- Defined in:
- lib/zitadel/client/models/internal_permission_service_create_administrator_request.rb
Instance Attribute Summary collapse
-
#resource ⇒ Object
Returns the value of attribute resource.
-
#roles ⇒ Object
Roles are the roles that should be granted to the user for the specified resource.
-
#user_id ⇒ Object
UserID is the ID of the user who should be granted the administrator role.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ InternalPermissionServiceCreateAdministratorRequest
constructor
Initializes the object.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ InternalPermissionServiceCreateAdministratorRequest
Initializes the object
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/zitadel/client/models/internal_permission_service_create_administrator_request.rb', line 62 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) # MODIFIED: Updated class name in error message fail ArgumentError, "The input argument (attributes) must be a hash in `Zitadel::Client::Models::InternalPermissionServiceCreateAdministratorRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) # MODIFIED: Updated class name in error message fail ArgumentError, "`#{k}` is not a valid attribute in `Zitadel::Client::Models::InternalPermissionServiceCreateAdministratorRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'user_id') self.user_id = attributes[:'user_id'] end if attributes.key?(:'resource') self.resource = attributes[:'resource'] end if attributes.key?(:'roles') if (value = attributes[:'roles']).is_a?(Array) self.roles = value end end end |
Instance Attribute Details
#resource ⇒ Object
Returns the value of attribute resource.
21 22 23 |
# File 'lib/zitadel/client/models/internal_permission_service_create_administrator_request.rb', line 21 def resource @resource end |
#roles ⇒ Object
Roles are the roles that should be granted to the user for the specified resource. Note that roles are currently specific to the resource type. This means that if you want to grant a user the administrator role for an organization and a project, you need to create two administrator roles.
24 25 26 |
# File 'lib/zitadel/client/models/internal_permission_service_create_administrator_request.rb', line 24 def roles @roles end |
#user_id ⇒ Object
UserID is the ID of the user who should be granted the administrator role.
19 20 21 |
# File 'lib/zitadel/client/models/internal_permission_service_create_administrator_request.rb', line 19 def user_id @user_id end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/zitadel/client/models/internal_permission_service_create_administrator_request.rb', line 142 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf/anyOf constructs that resolve to a model name # MODIFIED: Ensure model is looked up in the Models namespace # 'type' here is expected to be the simple class name (e.g., "User", "OrderDetails") klass = Zitadel::Client::Models.const_get(type) # The `klass.build` method is for oneOf/anyOf types (defined in partial_oneof_module.mustache / partial_anyof_module.mustache) # The `klass.build_from_hash` is for regular model types (defined in this base_object.mustache itself) if klass.respond_to?(:openapi_one_of) || klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_allOf) klass.build(value) # For oneOf/anyOf/allOf, delegate to their specific build method else klass.build_from_hash(value) # For regular models end end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
36 37 38 |
# File 'lib/zitadel/client/models/internal_permission_service_create_administrator_request.rb', line 36 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
41 42 43 |
# File 'lib/zitadel/client/models/internal_permission_service_create_administrator_request.rb', line 41 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
27 28 29 30 31 32 33 |
# File 'lib/zitadel/client/models/internal_permission_service_create_administrator_request.rb', line 27 def self.attribute_map { :'user_id' => :'userId', :'resource' => :'resource', :'roles' => :'roles' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/zitadel/client/models/internal_permission_service_create_administrator_request.rb', line 118 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) # `new` will call the initialize method of the specific model class. end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
55 56 57 58 |
# File 'lib/zitadel/client/models/internal_permission_service_create_administrator_request.rb', line 55 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
46 47 48 49 50 51 52 |
# File 'lib/zitadel/client/models/internal_permission_service_create_administrator_request.rb', line 46 def self.openapi_types { :'user_id' => :'String', :'resource' => :'InternalPermissionServiceResourceType', :'roles' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
95 96 97 98 99 100 101 |
# File 'lib/zitadel/client/models/internal_permission_service_create_administrator_request.rb', line 95 def ==(o) return true if self.equal?(o) self.class == o.class && user_id == o.user_id && resource == o.resource && roles == o.roles end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'lib/zitadel/client/models/internal_permission_service_create_administrator_request.rb', line 221 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
105 106 107 |
# File 'lib/zitadel/client/models/internal_permission_service_create_administrator_request.rb', line 105 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
111 112 113 |
# File 'lib/zitadel/client/models/internal_permission_service_create_administrator_request.rb', line 111 def hash [user_id, resource, roles].hash end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
197 198 199 |
# File 'lib/zitadel/client/models/internal_permission_service_create_administrator_request.rb', line 197 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
203 204 205 206 207 208 209 210 211 212 213 214 215 |
# File 'lib/zitadel/client/models/internal_permission_service_create_administrator_request.rb', line 203 def to_hash hash = {} # Calls super.to_hash if parent exists self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
191 192 193 |
# File 'lib/zitadel/client/models/internal_permission_service_create_administrator_request.rb', line 191 def to_s to_hash.to_s end |