Class: Zitadel::Client::Models::OIDCServiceAuthRequest
- Inherits:
-
Object
- Object
- Zitadel::Client::Models::OIDCServiceAuthRequest
- Defined in:
- lib/zitadel/client/models/o_i_d_c_service_auth_request.rb
Overview
AuthRequest represents an OpenID Connect Authorization Request as defined in openid.net/specs/openid-connect-core-1_0.html#AuthRequest
Instance Attribute Summary collapse
-
#client_id ⇒ Object
The OAuth2/OIDC client_id of the application that initiated the authorization request.
-
#creation_date ⇒ Object
A Timestamp represents a point in time independent of any time zone or local calendar, encoded as a count of seconds and fractions of seconds at nanosecond resolution.
-
#hint_user_id ⇒ Object
User ID taken from a ID Token Hint if it was present and valid.
-
#id ⇒ Object
The unique identifier of the authorization request.
-
#login_hint ⇒ Object
Login hint can be set by the application with a user identifier such as an email or phone number.
-
#max_age ⇒ Object
A Duration represents a signed, fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
-
#prompt ⇒ Object
Prompts that must be displayed to the user.
-
#redirect_uri ⇒ Object
The redirect_uri used in the authorization request.
-
#scope ⇒ Object
The scopes by the application that the user must consent to.
-
#ui_locales ⇒ Object
End-User’s preferred languages and scripts for the user interface, represented as a list of BCP47 [RFC5646] language tag values, ordered by preference.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ OIDCServiceAuthRequest
constructor
Initializes the object.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ OIDCServiceAuthRequest
Initializes the object
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/zitadel/client/models/o_i_d_c_service_auth_request.rb', line 101 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) # MODIFIED: Updated class name in error message fail ArgumentError, "The input argument (attributes) must be a hash in `Zitadel::Client::Models::OIDCServiceAuthRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) # MODIFIED: Updated class name in error message fail ArgumentError, "`#{k}` is not a valid attribute in `Zitadel::Client::Models::OIDCServiceAuthRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'creation_date') self.creation_date = attributes[:'creation_date'] end if attributes.key?(:'client_id') self.client_id = attributes[:'client_id'] end if attributes.key?(:'scope') if (value = attributes[:'scope']).is_a?(Array) self.scope = value end end if attributes.key?(:'redirect_uri') self.redirect_uri = attributes[:'redirect_uri'] end if attributes.key?(:'prompt') if (value = attributes[:'prompt']).is_a?(Array) self.prompt = value end end if attributes.key?(:'ui_locales') if (value = attributes[:'ui_locales']).is_a?(Array) self.ui_locales = value end end if attributes.key?(:'login_hint') self.login_hint = attributes[:'login_hint'] end if attributes.key?(:'max_age') self.max_age = attributes[:'max_age'] end if attributes.key?(:'hint_user_id') self.hint_user_id = attributes[:'hint_user_id'] end end |
Instance Attribute Details
#client_id ⇒ Object
The OAuth2/OIDC client_id of the application that initiated the authorization request.
26 27 28 |
# File 'lib/zitadel/client/models/o_i_d_c_service_auth_request.rb', line 26 def client_id @client_id end |
#creation_date ⇒ Object
A Timestamp represents a point in time independent of any time zone or local calendar, encoded as a count of seconds and fractions of seconds at nanosecond resolution. The count is relative to an epoch at UTC midnight on January 1, 1970, in the proleptic Gregorian calendar which extends the Gregorian calendar backwards to year one. All minutes are 60 seconds long. Leap seconds are "smeared" so that no leap second table is needed for interpretation, using a [24-hour linear smear](developers.google.com/time/smear). The range is from 0001-01-01T00:00:00Z to 9999-12-31T23:59:59.999999999Z. By restricting to that range, we ensure that we can convert to and from [RFC 3339](www.ietf.org/rfc/rfc3339.txt) date strings. # Examples Example 1: Compute Timestamp from POSIX ‘time()`. Timestamp timestamp; timestamp.set_seconds(time(NULL)); timestamp.set_nanos(0); Example 2: Compute Timestamp from POSIX `gettimeofday()`. struct timeval tv; gettimeofday(&tv, NULL); Timestamp timestamp; timestamp.set_seconds(tv.tv_sec); timestamp.set_nanos(tv.tv_usec * 1000); Example 3: Compute Timestamp from Win32 `GetSystemTimeAsFileTime()`. FILETIME ft; GetSystemTimeAsFileTime(&ft); UINT64 ticks = (((UINT64)ft.dwHighDateTime) << 32) | ft.dwLowDateTime; // A Windows tick is 100 nanoseconds. Windows epoch 1601-01-01T00:00:00Z // is 11644473600 seconds before Unix epoch 1970-01-01T00:00:00Z. Timestamp timestamp; timestamp.set_seconds((INT64) ((ticks / 10000000) - 11644473600LL)); timestamp.set_nanos((INT32) ((ticks % 10000000) * 100)); Example 4: Compute Timestamp from Java `System.currentTimeMillis()`. long millis = System.currentTimeMillis(); Timestamp timestamp = Timestamp.newBuilder().setSeconds(millis / 1000) .setNanos((int) ((millis % 1000) * 1000000)).build(); Example 5: Compute Timestamp from Java `Instant.now()`. Instant now = Instant.now(); Timestamp timestamp = Timestamp.newBuilder().setSeconds(now.getEpochSecond()) .setNanos(now.getNano()).build(); Example 6: Compute Timestamp from current time in Python. timestamp = Timestamp() timestamp.GetCurrentTime() # JSON Mapping In JSON format, the Timestamp type is encoded as a string in the [RFC 3339](www.ietf.org/rfc/rfc3339.txt) format. That is, the format is "year-month-dayThour:min:secZ" where year is always expressed using four digits while month, day, hour, min, and sec are zero-padded to two digits each. The fractional seconds, which can go up to 9 digits (i.e. up to 1 nanosecond resolution), are optional. The "Z" suffix indicates the timezone ("UTC"); the timezone is required. A proto3 JSON serializer should always use UTC (as indicated by "Z") when printing the Timestamp type and a proto3 JSON parser should be able to accept both UTC and other timezones (as indicated by an offset). For example, "2017-01-15T01:30:15.01Z" encodes 15.01 seconds past 01:30 UTC on January 15, 2017. In JavaScript, one can convert a Date object to this format using the standard [toISOString()](developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString) method. In Python, a standard `datetime.datetime` object can be converted to this format using [`strftime`](docs.python.org/2/library/time.html#time.strftime) with the time format spec ’%Y-%m-%dT%H:%M:%S.%fZ’. Likewise, in Java, one can use the Joda Time’s [‘ISODateTimeFormat.dateTime()`]( joda-time.sourceforge.net/apidocs/org/joda/time/format/ISODateTimeFormat.html#dateTime() ) to obtain a formatter capable of generating timestamps in this format.
23 24 25 |
# File 'lib/zitadel/client/models/o_i_d_c_service_auth_request.rb', line 23 def creation_date @creation_date end |
#hint_user_id ⇒ Object
User ID taken from a ID Token Hint if it was present and valid.
47 48 49 |
# File 'lib/zitadel/client/models/o_i_d_c_service_auth_request.rb', line 47 def hint_user_id @hint_user_id end |
#id ⇒ Object
The unique identifier of the authorization request.
20 21 22 |
# File 'lib/zitadel/client/models/o_i_d_c_service_auth_request.rb', line 20 def id @id end |
#login_hint ⇒ Object
Login hint can be set by the application with a user identifier such as an email or phone number.
41 42 43 |
# File 'lib/zitadel/client/models/o_i_d_c_service_auth_request.rb', line 41 def login_hint @login_hint end |
#max_age ⇒ Object
A Duration represents a signed, fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". It is related to Timestamp in that the difference between two Timestamp values is a Duration and it can be added or subtracted from a Timestamp. Range is approximately -10,000 years. # Examples Example 1: Compute Duration from two Timestamps in pseudo code. Timestamp start = …; Timestamp end = …; Duration duration = …; duration.seconds = end.seconds - start.seconds; duration.nanos = end.nanos - start.nanos; if (duration.seconds < 0 && duration.nanos > 0) { duration.seconds = 1; duration.nanos -= 1000000000; } else if (duration.seconds > 0 && duration.nanos < 0) { duration.seconds -= 1; duration.nanos = 1000000000; } Example 2: Compute Timestamp from Timestamp Duration in pseudo code. Timestamp start = …; Duration duration = …; Timestamp end = …; end.seconds = start.seconds + duration.seconds; end.nanos = start.nanos + duration.nanos; if (end.nanos < 0) { end.seconds -= 1; end.nanos = 1000000000; } else if (end.nanos >= 1000000000) { end.seconds = 1; end.nanos -= 1000000000; } Example 3: Compute Duration from datetime.timedelta in Python. td = datetime.timedelta(days=3, minutes=10) duration = Duration() duration.FromTimedelta(td) # JSON Mapping In JSON format, the Duration type is encoded as a string rather than an object, where the string ends in the suffix "s" (indicating seconds) and is preceded by the number of seconds, with nanoseconds expressed as fractional seconds. For example, 3 seconds with 0 nanoseconds should be encoded in JSON format as "3s", while 3 seconds and 1 nanosecond should be expressed in JSON format as "3.000000001s", and 3 seconds and 1 microsecond should be expressed in JSON format as "3.000001s".
44 45 46 |
# File 'lib/zitadel/client/models/o_i_d_c_service_auth_request.rb', line 44 def max_age @max_age end |
#prompt ⇒ Object
Prompts that must be displayed to the user.
35 36 37 |
# File 'lib/zitadel/client/models/o_i_d_c_service_auth_request.rb', line 35 def prompt @prompt end |
#redirect_uri ⇒ Object
The redirect_uri used in the authorization request. This must exactly match one of the redirect URIs registered for the client. This uri is used to send the authorization code or tokens back to the application.
32 33 34 |
# File 'lib/zitadel/client/models/o_i_d_c_service_auth_request.rb', line 32 def redirect_uri @redirect_uri end |
#scope ⇒ Object
The scopes by the application that the user must consent to.
29 30 31 |
# File 'lib/zitadel/client/models/o_i_d_c_service_auth_request.rb', line 29 def scope @scope end |
#ui_locales ⇒ Object
End-User’s preferred languages and scripts for the user interface, represented as a list of BCP47 [RFC5646] language tag values, ordered by preference. For instance, the value [fr-CA, fr, en] represents a preference for French as spoken in Canada, then French (without a region designation), followed by English (without a region designation). An error SHOULD NOT result if some or all of the requested locales are not supported.
38 39 40 |
# File 'lib/zitadel/client/models/o_i_d_c_service_auth_request.rb', line 38 def ui_locales @ui_locales end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 |
# File 'lib/zitadel/client/models/o_i_d_c_service_auth_request.rb', line 220 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf/anyOf constructs that resolve to a model name # MODIFIED: Ensure model is looked up in the Models namespace # 'type' here is expected to be the simple class name (e.g., "User", "OrderDetails") klass = Zitadel::Client::Models.const_get(type) # The `klass.build` method is for oneOf/anyOf types (defined in partial_oneof_module.mustache / partial_anyof_module.mustache) # The `klass.build_from_hash` is for regular model types (defined in this base_object.mustache itself) if klass.respond_to?(:openapi_one_of) || klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_allOf) klass.build(value) # For oneOf/anyOf/allOf, delegate to their specific build method else klass.build_from_hash(value) # For regular models end end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
66 67 68 |
# File 'lib/zitadel/client/models/o_i_d_c_service_auth_request.rb', line 66 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
71 72 73 |
# File 'lib/zitadel/client/models/o_i_d_c_service_auth_request.rb', line 71 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/zitadel/client/models/o_i_d_c_service_auth_request.rb', line 50 def self.attribute_map { :'id' => :'id', :'creation_date' => :'creationDate', :'client_id' => :'clientId', :'scope' => :'scope', :'redirect_uri' => :'redirectUri', :'prompt' => :'prompt', :'ui_locales' => :'uiLocales', :'login_hint' => :'loginHint', :'max_age' => :'maxAge', :'hint_user_id' => :'hintUserId' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 |
# File 'lib/zitadel/client/models/o_i_d_c_service_auth_request.rb', line 196 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) # `new` will call the initialize method of the specific model class. end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
92 93 94 95 96 97 |
# File 'lib/zitadel/client/models/o_i_d_c_service_auth_request.rb', line 92 def self.openapi_nullable Set.new([ :'login_hint', :'hint_user_id' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/zitadel/client/models/o_i_d_c_service_auth_request.rb', line 76 def self.openapi_types { :'id' => :'String', :'creation_date' => :'Time', :'client_id' => :'String', :'scope' => :'Array<String>', :'redirect_uri' => :'String', :'prompt' => :'Array<OIDCServicePrompt>', :'ui_locales' => :'Array<String>', :'login_hint' => :'String', :'max_age' => :'String', :'hint_user_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
166 167 168 169 170 171 172 173 174 175 176 177 178 179 |
# File 'lib/zitadel/client/models/o_i_d_c_service_auth_request.rb', line 166 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && creation_date == o.creation_date && client_id == o.client_id && scope == o.scope && redirect_uri == o.redirect_uri && prompt == o.prompt && ui_locales == o.ui_locales && login_hint == o.login_hint && max_age == o.max_age && hint_user_id == o.hint_user_id end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
299 300 301 302 303 304 305 306 307 308 309 310 311 |
# File 'lib/zitadel/client/models/o_i_d_c_service_auth_request.rb', line 299 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
183 184 185 |
# File 'lib/zitadel/client/models/o_i_d_c_service_auth_request.rb', line 183 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
189 190 191 |
# File 'lib/zitadel/client/models/o_i_d_c_service_auth_request.rb', line 189 def hash [id, creation_date, client_id, scope, redirect_uri, prompt, ui_locales, login_hint, max_age, hint_user_id].hash end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
275 276 277 |
# File 'lib/zitadel/client/models/o_i_d_c_service_auth_request.rb', line 275 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
281 282 283 284 285 286 287 288 289 290 291 292 293 |
# File 'lib/zitadel/client/models/o_i_d_c_service_auth_request.rb', line 281 def to_hash hash = {} # Calls super.to_hash if parent exists self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
269 270 271 |
# File 'lib/zitadel/client/models/o_i_d_c_service_auth_request.rb', line 269 def to_s to_hash.to_s end |