Class: Zitadel::Client::Models::ProjectServiceProjectGrant

Inherits:
Object
  • Object
show all
Defined in:
lib/zitadel/client/models/project_service_project_grant.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ProjectServiceProjectGrant

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Models attributes in the form of hash



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
# File 'lib/zitadel/client/models/project_service_project_grant.rb', line 114

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    # MODIFIED: Updated class name in error message
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zitadel::Client::Models::ProjectServiceProjectGrant` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      # MODIFIED: Updated class name in error message
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zitadel::Client::Models::ProjectServiceProjectGrant`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'organization_id')
    self.organization_id = attributes[:'organization_id']
  end

  if attributes.key?(:'creation_date')
    self.creation_date = attributes[:'creation_date']
  end

  if attributes.key?(:'change_date')
    self.change_date = attributes[:'change_date']
  end

  if attributes.key?(:'granted_organization_id')
    self.granted_organization_id = attributes[:'granted_organization_id']
  end

  if attributes.key?(:'granted_organization_name')
    self.granted_organization_name = attributes[:'granted_organization_name']
  end

  if attributes.key?(:'granted_role_keys')
    if (value = attributes[:'granted_role_keys']).is_a?(Array)
      self.granted_role_keys = value
    end
  end

  if attributes.key?(:'project_id')
    self.project_id = attributes[:'project_id']
  end

  if attributes.key?(:'project_name')
    self.project_name = attributes[:'project_name']
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  end
end

Instance Attribute Details

#change_dateObject

A Timestamp represents a point in time independent of any time zone or local calendar, encoded as a count of seconds and fractions of seconds at nanosecond resolution. The count is relative to an epoch at UTC midnight on January 1, 1970, in the proleptic Gregorian calendar which extends the Gregorian calendar backwards to year one. All minutes are 60 seconds long. Leap seconds are "smeared" so that no leap second table is needed for interpretation, using a [24-hour linear smear](developers.google.com/time/smear). The range is from 0001-01-01T00:00:00Z to 9999-12-31T23:59:59.999999999Z. By restricting to that range, we ensure that we can convert to and from [RFC 3339](www.ietf.org/rfc/rfc3339.txt) date strings. # Examples Example 1: Compute Timestamp from POSIX ‘time()`. Timestamp timestamp; timestamp.set_seconds(time(NULL)); timestamp.set_nanos(0); Example 2: Compute Timestamp from POSIX `gettimeofday()`. struct timeval tv; gettimeofday(&tv, NULL); Timestamp timestamp; timestamp.set_seconds(tv.tv_sec); timestamp.set_nanos(tv.tv_usec * 1000); Example 3: Compute Timestamp from Win32 `GetSystemTimeAsFileTime()`. FILETIME ft; GetSystemTimeAsFileTime(&ft); UINT64 ticks = (((UINT64)ft.dwHighDateTime) << 32) | ft.dwLowDateTime; // A Windows tick is 100 nanoseconds. Windows epoch 1601-01-01T00:00:00Z // is 11644473600 seconds before Unix epoch 1970-01-01T00:00:00Z. Timestamp timestamp; timestamp.set_seconds((INT64) ((ticks / 10000000) - 11644473600LL)); timestamp.set_nanos((INT32) ((ticks % 10000000) * 100)); Example 4: Compute Timestamp from Java `System.currentTimeMillis()`. long millis = System.currentTimeMillis(); Timestamp timestamp = Timestamp.newBuilder().setSeconds(millis / 1000) .setNanos((int) ((millis % 1000) * 1000000)).build(); Example 5: Compute Timestamp from Java `Instant.now()`. Instant now = Instant.now(); Timestamp timestamp = Timestamp.newBuilder().setSeconds(now.getEpochSecond()) .setNanos(now.getNano()).build(); Example 6: Compute Timestamp from current time in Python. timestamp = Timestamp() timestamp.GetCurrentTime() # JSON Mapping In JSON format, the Timestamp type is encoded as a string in the [RFC 3339](www.ietf.org/rfc/rfc3339.txt) format. That is, the format is "year-month-dayThour:min:secZ" where year is always expressed using four digits while month, day, hour, min, and sec are zero-padded to two digits each. The fractional seconds, which can go up to 9 digits (i.e. up to 1 nanosecond resolution), are optional. The "Z" suffix indicates the timezone ("UTC"); the timezone is required. A proto3 JSON serializer should always use UTC (as indicated by "Z") when printing the Timestamp type and a proto3 JSON parser should be able to accept both UTC and other timezones (as indicated by an offset). For example, "2017-01-15T01:30:15.01Z" encodes 15.01 seconds past 01:30 UTC on January 15, 2017. In JavaScript, one can convert a Date object to this format using the standard [toISOString()](developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString) method. In Python, a standard `datetime.datetime` object can be converted to this format using [`strftime`](docs.python.org/2/library/time.html#time.strftime) with the time format spec ’%Y-%m-%dT%H:%M:%S.%fZ’. Likewise, in Java, one can use the Joda Time’s [‘ISODateTimeFormat.dateTime()`]( joda-time.sourceforge.net/apidocs/org/joda/time/format/ISODateTimeFormat.html#dateTime() ) to obtain a formatter capable of generating timestamps in this format.



25
26
27
# File 'lib/zitadel/client/models/project_service_project_grant.rb', line 25

def change_date
  @change_date
end

#creation_dateObject

A Timestamp represents a point in time independent of any time zone or local calendar, encoded as a count of seconds and fractions of seconds at nanosecond resolution. The count is relative to an epoch at UTC midnight on January 1, 1970, in the proleptic Gregorian calendar which extends the Gregorian calendar backwards to year one. All minutes are 60 seconds long. Leap seconds are "smeared" so that no leap second table is needed for interpretation, using a [24-hour linear smear](developers.google.com/time/smear). The range is from 0001-01-01T00:00:00Z to 9999-12-31T23:59:59.999999999Z. By restricting to that range, we ensure that we can convert to and from [RFC 3339](www.ietf.org/rfc/rfc3339.txt) date strings. # Examples Example 1: Compute Timestamp from POSIX ‘time()`. Timestamp timestamp; timestamp.set_seconds(time(NULL)); timestamp.set_nanos(0); Example 2: Compute Timestamp from POSIX `gettimeofday()`. struct timeval tv; gettimeofday(&tv, NULL); Timestamp timestamp; timestamp.set_seconds(tv.tv_sec); timestamp.set_nanos(tv.tv_usec * 1000); Example 3: Compute Timestamp from Win32 `GetSystemTimeAsFileTime()`. FILETIME ft; GetSystemTimeAsFileTime(&ft); UINT64 ticks = (((UINT64)ft.dwHighDateTime) << 32) | ft.dwLowDateTime; // A Windows tick is 100 nanoseconds. Windows epoch 1601-01-01T00:00:00Z // is 11644473600 seconds before Unix epoch 1970-01-01T00:00:00Z. Timestamp timestamp; timestamp.set_seconds((INT64) ((ticks / 10000000) - 11644473600LL)); timestamp.set_nanos((INT32) ((ticks % 10000000) * 100)); Example 4: Compute Timestamp from Java `System.currentTimeMillis()`. long millis = System.currentTimeMillis(); Timestamp timestamp = Timestamp.newBuilder().setSeconds(millis / 1000) .setNanos((int) ((millis % 1000) * 1000000)).build(); Example 5: Compute Timestamp from Java `Instant.now()`. Instant now = Instant.now(); Timestamp timestamp = Timestamp.newBuilder().setSeconds(now.getEpochSecond()) .setNanos(now.getNano()).build(); Example 6: Compute Timestamp from current time in Python. timestamp = Timestamp() timestamp.GetCurrentTime() # JSON Mapping In JSON format, the Timestamp type is encoded as a string in the [RFC 3339](www.ietf.org/rfc/rfc3339.txt) format. That is, the format is "year-month-dayThour:min:secZ" where year is always expressed using four digits while month, day, hour, min, and sec are zero-padded to two digits each. The fractional seconds, which can go up to 9 digits (i.e. up to 1 nanosecond resolution), are optional. The "Z" suffix indicates the timezone ("UTC"); the timezone is required. A proto3 JSON serializer should always use UTC (as indicated by "Z") when printing the Timestamp type and a proto3 JSON parser should be able to accept both UTC and other timezones (as indicated by an offset). For example, "2017-01-15T01:30:15.01Z" encodes 15.01 seconds past 01:30 UTC on January 15, 2017. In JavaScript, one can convert a Date object to this format using the standard [toISOString()](developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString) method. In Python, a standard `datetime.datetime` object can be converted to this format using [`strftime`](docs.python.org/2/library/time.html#time.strftime) with the time format spec ’%Y-%m-%dT%H:%M:%S.%fZ’. Likewise, in Java, one can use the Joda Time’s [‘ISODateTimeFormat.dateTime()`]( joda-time.sourceforge.net/apidocs/org/joda/time/format/ISODateTimeFormat.html#dateTime() ) to obtain a formatter capable of generating timestamps in this format.



22
23
24
# File 'lib/zitadel/client/models/project_service_project_grant.rb', line 22

def creation_date
  @creation_date
end

#granted_organization_idObject

The ID of the organization the project is granted to.



28
29
30
# File 'lib/zitadel/client/models/project_service_project_grant.rb', line 28

def granted_organization_id
  @granted_organization_id
end

#granted_organization_nameObject

The name of the organization the project is granted to.



31
32
33
# File 'lib/zitadel/client/models/project_service_project_grant.rb', line 31

def granted_organization_name
  @granted_organization_name
end

#granted_role_keysObject

The roles granted to the organization for self-management of the project.



34
35
36
# File 'lib/zitadel/client/models/project_service_project_grant.rb', line 34

def granted_role_keys
  @granted_role_keys
end

#organization_idObject

The unique identifier of the organization which granted the project to the granted_organization_id.



19
20
21
# File 'lib/zitadel/client/models/project_service_project_grant.rb', line 19

def organization_id
  @organization_id
end

#project_idObject

The ID of the granted project.



37
38
39
# File 'lib/zitadel/client/models/project_service_project_grant.rb', line 37

def project_id
  @project_id
end

#project_nameObject

The name of the granted project.



40
41
42
# File 'lib/zitadel/client/models/project_service_project_grant.rb', line 40

def project_name
  @project_name
end

#stateObject

Returns the value of attribute state.



42
43
44
# File 'lib/zitadel/client/models/project_service_project_grant.rb', line 42

def state
  @state
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
# File 'lib/zitadel/client/models/project_service_project_grant.rb', line 224

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf/anyOf constructs that resolve to a model name
    # MODIFIED: Ensure model is looked up in the Models namespace
    # 'type' here is expected to be the simple class name (e.g., "User", "OrderDetails")
    klass = Zitadel::Client::Models.const_get(type)
    # The `klass.build` method is for oneOf/anyOf types (defined in partial_oneof_module.mustache / partial_anyof_module.mustache)
    # The `klass.build_from_hash` is for regular model types (defined in this base_object.mustache itself)
    if klass.respond_to?(:openapi_one_of) || klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_allOf)
      klass.build(value) # For oneOf/anyOf/allOf, delegate to their specific build method
    else
      klass.build_from_hash(value) # For regular models
    end
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



82
83
84
# File 'lib/zitadel/client/models/project_service_project_grant.rb', line 82

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



87
88
89
# File 'lib/zitadel/client/models/project_service_project_grant.rb', line 87

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/zitadel/client/models/project_service_project_grant.rb', line 67

def self.attribute_map
  {
    :'organization_id' => :'organizationId',
    :'creation_date' => :'creationDate',
    :'change_date' => :'changeDate',
    :'granted_organization_id' => :'grantedOrganizationId',
    :'granted_organization_name' => :'grantedOrganizationName',
    :'granted_role_keys' => :'grantedRoleKeys',
    :'project_id' => :'projectId',
    :'project_name' => :'projectName',
    :'state' => :'state'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Models attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/zitadel/client/models/project_service_project_grant.rb', line 200

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash) # `new` will call the initialize method of the specific model class.
end

.openapi_nullableObject

List of attributes with nullable: true



107
108
109
110
# File 'lib/zitadel/client/models/project_service_project_grant.rb', line 107

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/zitadel/client/models/project_service_project_grant.rb', line 92

def self.openapi_types
  {
    :'organization_id' => :'String',
    :'creation_date' => :'Time',
    :'change_date' => :'Time',
    :'granted_organization_id' => :'String',
    :'granted_organization_name' => :'String',
    :'granted_role_keys' => :'Array<String>',
    :'project_id' => :'String',
    :'project_name' => :'String',
    :'state' => :'ProjectServiceProjectGrantState'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



171
172
173
174
175
176
177
178
179
180
181
182
183
# File 'lib/zitadel/client/models/project_service_project_grant.rb', line 171

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      organization_id == o.organization_id &&
      creation_date == o.creation_date &&
      change_date == o.change_date &&
      granted_organization_id == o.granted_organization_id &&
      granted_organization_name == o.granted_organization_name &&
      granted_role_keys == o.granted_role_keys &&
      project_id == o.project_id &&
      project_name == o.project_name &&
      state == o.state
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



303
304
305
306
307
308
309
310
311
312
313
314
315
# File 'lib/zitadel/client/models/project_service_project_grant.rb', line 303

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


187
188
189
# File 'lib/zitadel/client/models/project_service_project_grant.rb', line 187

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



193
194
195
# File 'lib/zitadel/client/models/project_service_project_grant.rb', line 193

def hash
  [organization_id, creation_date, change_date, granted_organization_id, granted_organization_name, granted_role_keys, project_id, project_name, state].hash
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



279
280
281
# File 'lib/zitadel/client/models/project_service_project_grant.rb', line 279

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



285
286
287
288
289
290
291
292
293
294
295
296
297
# File 'lib/zitadel/client/models/project_service_project_grant.rb', line 285

def to_hash
  hash = {} # Calls super.to_hash if parent exists
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



273
274
275
# File 'lib/zitadel/client/models/project_service_project_grant.rb', line 273

def to_s
  to_hash.to_s
end