Class: Zitadel::Client::Models::ProjectServiceProjectGrantSearchFilter
- Inherits:
-
Object
- Object
- Zitadel::Client::Models::ProjectServiceProjectGrantSearchFilter
- Defined in:
- lib/zitadel/client/models/project_service_project_grant_search_filter.rb
Instance Attribute Summary collapse
-
#granted_organization_id_filter ⇒ Object
Returns the value of attribute granted_organization_id_filter.
-
#in_project_ids_filter ⇒ Object
Returns the value of attribute in_project_ids_filter.
-
#organization_id_filter ⇒ Object
Returns the value of attribute organization_id_filter.
-
#project_name_filter ⇒ Object
Returns the value of attribute project_name_filter.
-
#role_key_filter ⇒ Object
Returns the value of attribute role_key_filter.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ProjectServiceProjectGrantSearchFilter
constructor
Initializes the object.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ProjectServiceProjectGrantSearchFilter
Initializes the object
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/zitadel/client/models/project_service_project_grant_search_filter.rb', line 68 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) # MODIFIED: Updated class name in error message fail ArgumentError, "The input argument (attributes) must be a hash in `Zitadel::Client::Models::ProjectServiceProjectGrantSearchFilter` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) # MODIFIED: Updated class name in error message fail ArgumentError, "`#{k}` is not a valid attribute in `Zitadel::Client::Models::ProjectServiceProjectGrantSearchFilter`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'granted_organization_id_filter') self.granted_organization_id_filter = attributes[:'granted_organization_id_filter'] end if attributes.key?(:'in_project_ids_filter') self.in_project_ids_filter = attributes[:'in_project_ids_filter'] end if attributes.key?(:'organization_id_filter') self.organization_id_filter = attributes[:'organization_id_filter'] end if attributes.key?(:'project_name_filter') self.project_name_filter = attributes[:'project_name_filter'] end if attributes.key?(:'role_key_filter') self.role_key_filter = attributes[:'role_key_filter'] end end |
Instance Attribute Details
#granted_organization_id_filter ⇒ Object
Returns the value of attribute granted_organization_id_filter.
18 19 20 |
# File 'lib/zitadel/client/models/project_service_project_grant_search_filter.rb', line 18 def granted_organization_id_filter @granted_organization_id_filter end |
#in_project_ids_filter ⇒ Object
Returns the value of attribute in_project_ids_filter.
20 21 22 |
# File 'lib/zitadel/client/models/project_service_project_grant_search_filter.rb', line 20 def in_project_ids_filter @in_project_ids_filter end |
#organization_id_filter ⇒ Object
Returns the value of attribute organization_id_filter.
22 23 24 |
# File 'lib/zitadel/client/models/project_service_project_grant_search_filter.rb', line 22 def organization_id_filter @organization_id_filter end |
#project_name_filter ⇒ Object
Returns the value of attribute project_name_filter.
24 25 26 |
# File 'lib/zitadel/client/models/project_service_project_grant_search_filter.rb', line 24 def project_name_filter @project_name_filter end |
#role_key_filter ⇒ Object
Returns the value of attribute role_key_filter.
26 27 28 |
# File 'lib/zitadel/client/models/project_service_project_grant_search_filter.rb', line 26 def role_key_filter @role_key_filter end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/zitadel/client/models/project_service_project_grant_search_filter.rb', line 156 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf/anyOf constructs that resolve to a model name # MODIFIED: Ensure model is looked up in the Models namespace # 'type' here is expected to be the simple class name (e.g., "User", "OrderDetails") klass = Zitadel::Client::Models.const_get(type) # The `klass.build` method is for oneOf/anyOf types (defined in partial_oneof_module.mustache / partial_anyof_module.mustache) # The `klass.build_from_hash` is for regular model types (defined in this base_object.mustache itself) if klass.respond_to?(:openapi_one_of) || klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_allOf) klass.build(value) # For oneOf/anyOf/allOf, delegate to their specific build method else klass.build_from_hash(value) # For regular models end end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
40 41 42 |
# File 'lib/zitadel/client/models/project_service_project_grant_search_filter.rb', line 40 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
45 46 47 |
# File 'lib/zitadel/client/models/project_service_project_grant_search_filter.rb', line 45 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
29 30 31 32 33 34 35 36 37 |
# File 'lib/zitadel/client/models/project_service_project_grant_search_filter.rb', line 29 def self.attribute_map { :'granted_organization_id_filter' => :'grantedOrganizationIdFilter', :'in_project_ids_filter' => :'inProjectIdsFilter', :'organization_id_filter' => :'organizationIdFilter', :'project_name_filter' => :'projectNameFilter', :'role_key_filter' => :'roleKeyFilter' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/zitadel/client/models/project_service_project_grant_search_filter.rb', line 132 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) # `new` will call the initialize method of the specific model class. end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
61 62 63 64 |
# File 'lib/zitadel/client/models/project_service_project_grant_search_filter.rb', line 61 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
50 51 52 53 54 55 56 57 58 |
# File 'lib/zitadel/client/models/project_service_project_grant_search_filter.rb', line 50 def self.openapi_types { :'granted_organization_id_filter' => :'ProjectServiceIDFilter', :'in_project_ids_filter' => :'ProjectServiceInIDsFilter', :'organization_id_filter' => :'ProjectServiceIDFilter', :'project_name_filter' => :'ProjectServiceProjectNameFilter', :'role_key_filter' => :'ProjectServiceProjectRoleKeyFilter' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
107 108 109 110 111 112 113 114 115 |
# File 'lib/zitadel/client/models/project_service_project_grant_search_filter.rb', line 107 def ==(o) return true if self.equal?(o) self.class == o.class && granted_organization_id_filter == o.granted_organization_id_filter && in_project_ids_filter == o.in_project_ids_filter && organization_id_filter == o.organization_id_filter && project_name_filter == o.project_name_filter && role_key_filter == o.role_key_filter end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
235 236 237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/zitadel/client/models/project_service_project_grant_search_filter.rb', line 235 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
119 120 121 |
# File 'lib/zitadel/client/models/project_service_project_grant_search_filter.rb', line 119 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
125 126 127 |
# File 'lib/zitadel/client/models/project_service_project_grant_search_filter.rb', line 125 def hash [granted_organization_id_filter, in_project_ids_filter, organization_id_filter, project_name_filter, role_key_filter].hash end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
211 212 213 |
# File 'lib/zitadel/client/models/project_service_project_grant_search_filter.rb', line 211 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
217 218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/zitadel/client/models/project_service_project_grant_search_filter.rb', line 217 def to_hash hash = {} # Calls super.to_hash if parent exists self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
205 206 207 |
# File 'lib/zitadel/client/models/project_service_project_grant_search_filter.rb', line 205 def to_s to_hash.to_s end |