Class: Zitadel::Client::Models::ProjectServiceUpdateProjectRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/zitadel/client/models/project_service_update_project_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ProjectServiceUpdateProjectRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Models attributes in the form of hash



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
# File 'lib/zitadel/client/models/project_service_update_project_request.rb', line 103

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    # MODIFIED: Updated class name in error message
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zitadel::Client::Models::ProjectServiceUpdateProjectRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      # MODIFIED: Updated class name in error message
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zitadel::Client::Models::ProjectServiceUpdateProjectRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'project_id')
    self.project_id = attributes[:'project_id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'project_role_assertion')
    self.project_role_assertion = attributes[:'project_role_assertion']
  end

  if attributes.key?(:'authorization_required')
    self.authorization_required = attributes[:'authorization_required']
  end

  if attributes.key?(:'project_access_required')
    self.project_access_required = attributes[:'project_access_required']
  end

  if attributes.key?(:'private_labeling_setting')
    self.private_labeling_setting = attributes[:'private_labeling_setting']
  end
end

Instance Attribute Details

#authorization_requiredObject

AuthorizationRequired is a boolean flag that can be enabled to check if a user has a role of this project assigned when logging into an application of this project. If omitted, the setting will remain unchanged.



28
29
30
# File 'lib/zitadel/client/models/project_service_update_project_request.rb', line 28

def authorization_required
  @authorization_required
end

#nameObject

Name is used to update the name of the project. This field is optional. If omitted, the name will remain unchanged.



22
23
24
# File 'lib/zitadel/client/models/project_service_update_project_request.rb', line 22

def name
  @name
end

#private_labeling_settingObject

Returns the value of attribute private_labeling_setting.



33
34
35
# File 'lib/zitadel/client/models/project_service_update_project_request.rb', line 33

def private_labeling_setting
  @private_labeling_setting
end

#project_access_requiredObject

ProjectAccessRequired is a boolean flag that can be enabled to check if the organization of the user has a grant to this project. If omitted, the setting will remain unchanged.



31
32
33
# File 'lib/zitadel/client/models/project_service_update_project_request.rb', line 31

def project_access_required
  @project_access_required
end

#project_idObject

ProjectID is the unique identifier of the project to be updated.



19
20
21
# File 'lib/zitadel/client/models/project_service_update_project_request.rb', line 19

def project_id
  @project_id
end

#project_role_assertionObject

ProjectRoleAssertion is a setting that can be enabled to have role information included in the user info endpoint. It is also dependent on your application settings to include it in tokens and other types. If omitted, the setting will remain unchanged.



25
26
27
# File 'lib/zitadel/client/models/project_service_update_project_request.rb', line 25

def project_role_assertion
  @project_role_assertion
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/zitadel/client/models/project_service_update_project_request.rb', line 196

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf/anyOf constructs that resolve to a model name
    # MODIFIED: Ensure model is looked up in the Models namespace
    # 'type' here is expected to be the simple class name (e.g., "User", "OrderDetails")
    klass = Zitadel::Client::Models.const_get(type)
    # The `klass.build` method is for oneOf/anyOf types (defined in partial_oneof_module.mustache / partial_anyof_module.mustache)
    # The `klass.build_from_hash` is for regular model types (defined in this base_object.mustache itself)
    if klass.respond_to?(:openapi_one_of) || klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_allOf)
      klass.build(value) # For oneOf/anyOf/allOf, delegate to their specific build method
    else
      klass.build_from_hash(value) # For regular models
    end
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



70
71
72
# File 'lib/zitadel/client/models/project_service_update_project_request.rb', line 70

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



75
76
77
# File 'lib/zitadel/client/models/project_service_update_project_request.rb', line 75

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



58
59
60
61
62
63
64
65
66
67
# File 'lib/zitadel/client/models/project_service_update_project_request.rb', line 58

def self.attribute_map
  {
    :'project_id' => :'projectId',
    :'name' => :'name',
    :'project_role_assertion' => :'projectRoleAssertion',
    :'authorization_required' => :'authorizationRequired',
    :'project_access_required' => :'projectAccessRequired',
    :'private_labeling_setting' => :'privateLabelingSetting'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Models attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'lib/zitadel/client/models/project_service_update_project_request.rb', line 172

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash) # `new` will call the initialize method of the specific model class.
end

.openapi_nullableObject

List of attributes with nullable: true



92
93
94
95
96
97
98
99
# File 'lib/zitadel/client/models/project_service_update_project_request.rb', line 92

def self.openapi_nullable
  Set.new([
    :'name',
    :'project_role_assertion',
    :'authorization_required',
    :'project_access_required',
  ])
end

.openapi_typesObject

Attribute type mapping.



80
81
82
83
84
85
86
87
88
89
# File 'lib/zitadel/client/models/project_service_update_project_request.rb', line 80

def self.openapi_types
  {
    :'project_id' => :'String',
    :'name' => :'String',
    :'project_role_assertion' => :'Boolean',
    :'authorization_required' => :'Boolean',
    :'project_access_required' => :'Boolean',
    :'private_labeling_setting' => :'ProjectServicePrivateLabelingSetting'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



146
147
148
149
150
151
152
153
154
155
# File 'lib/zitadel/client/models/project_service_update_project_request.rb', line 146

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      project_id == o.project_id &&
      name == o.name &&
      project_role_assertion == o.project_role_assertion &&
      authorization_required == o.authorization_required &&
      project_access_required == o.project_access_required &&
      private_labeling_setting == o.private_labeling_setting
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



275
276
277
278
279
280
281
282
283
284
285
286
287
# File 'lib/zitadel/client/models/project_service_update_project_request.rb', line 275

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


159
160
161
# File 'lib/zitadel/client/models/project_service_update_project_request.rb', line 159

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



165
166
167
# File 'lib/zitadel/client/models/project_service_update_project_request.rb', line 165

def hash
  [project_id, name, project_role_assertion, authorization_required, project_access_required, private_labeling_setting].hash
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



251
252
253
# File 'lib/zitadel/client/models/project_service_update_project_request.rb', line 251

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



257
258
259
260
261
262
263
264
265
266
267
268
269
# File 'lib/zitadel/client/models/project_service_update_project_request.rb', line 257

def to_hash
  hash = {} # Calls super.to_hash if parent exists
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



245
246
247
# File 'lib/zitadel/client/models/project_service_update_project_request.rb', line 245

def to_s
  to_hash.to_s
end