Class: Zitadel::Client::Models::SettingsServiceLegalAndSupportSettings

Inherits:
Object
  • Object
show all
Defined in:
lib/zitadel/client/models/settings_service_legal_and_support_settings.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ SettingsServiceLegalAndSupportSettings

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Models attributes in the form of hash



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
# File 'lib/zitadel/client/models/settings_service_legal_and_support_settings.rb', line 109

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    # MODIFIED: Updated class name in error message
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zitadel::Client::Models::SettingsServiceLegalAndSupportSettings` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      # MODIFIED: Updated class name in error message
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zitadel::Client::Models::SettingsServiceLegalAndSupportSettings`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'tos_link')
    self.tos_link = attributes[:'tos_link']
  end

  if attributes.key?(:'privacy_policy_link')
    self.privacy_policy_link = attributes[:'privacy_policy_link']
  end

  if attributes.key?(:'help_link')
    self.help_link = attributes[:'help_link']
  end

  if attributes.key?(:'support_email')
    self.support_email = attributes[:'support_email']
  end

  if attributes.key?(:'resource_owner_type')
    self.resource_owner_type = attributes[:'resource_owner_type']
  end

  if attributes.key?(:'docs_link')
    self.docs_link = attributes[:'docs_link']
  end

  if attributes.key?(:'custom_link')
    self.custom_link = attributes[:'custom_link']
  end

  if attributes.key?(:'custom_link_text')
    self.custom_link_text = attributes[:'custom_link_text']
  end
end

Instance Attribute Details

Link to an external resource that will be available to users in the console.



36
37
38
# File 'lib/zitadel/client/models/settings_service_legal_and_support_settings.rb', line 36

def custom_link
  @custom_link
end

The button text that would be shown in console pointing to custom link.



39
40
41
# File 'lib/zitadel/client/models/settings_service_legal_and_support_settings.rb', line 39

def custom_link_text
  @custom_link_text
end

Link to documentation to be shown in the console.



33
34
35
# File 'lib/zitadel/client/models/settings_service_legal_and_support_settings.rb', line 33

def docs_link
  @docs_link
end

Link to a help page. Can be a relative or absolute URL.



25
26
27
# File 'lib/zitadel/client/models/settings_service_legal_and_support_settings.rb', line 25

def help_link
  @help_link
end

Link to the Privacy Policy. Can be a relative or absolute URL.



22
23
24
# File 'lib/zitadel/client/models/settings_service_legal_and_support_settings.rb', line 22

def privacy_policy_link
  @privacy_policy_link
end

#resource_owner_typeObject

Returns the value of attribute resource_owner_type.



30
31
32
# File 'lib/zitadel/client/models/settings_service_legal_and_support_settings.rb', line 30

def resource_owner_type
  @resource_owner_type
end

#support_emailObject

Email address for support issues.



28
29
30
# File 'lib/zitadel/client/models/settings_service_legal_and_support_settings.rb', line 28

def support_email
  @support_email
end

Link to the Terms of Service. Can be a relative or absolute URL.



19
20
21
# File 'lib/zitadel/client/models/settings_service_legal_and_support_settings.rb', line 19

def tos_link
  @tos_link
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
# File 'lib/zitadel/client/models/settings_service_legal_and_support_settings.rb', line 212

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf/anyOf constructs that resolve to a model name
    # MODIFIED: Ensure model is looked up in the Models namespace
    # 'type' here is expected to be the simple class name (e.g., "User", "OrderDetails")
    klass = Zitadel::Client::Models.const_get(type)
    # The `klass.build` method is for oneOf/anyOf types (defined in partial_oneof_module.mustache / partial_anyof_module.mustache)
    # The `klass.build_from_hash` is for regular model types (defined in this base_object.mustache itself)
    if klass.respond_to?(:openapi_one_of) || klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_allOf)
      klass.build(value) # For oneOf/anyOf/allOf, delegate to their specific build method
    else
      klass.build_from_hash(value) # For regular models
    end
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



78
79
80
# File 'lib/zitadel/client/models/settings_service_legal_and_support_settings.rb', line 78

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



83
84
85
# File 'lib/zitadel/client/models/settings_service_legal_and_support_settings.rb', line 83

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/zitadel/client/models/settings_service_legal_and_support_settings.rb', line 64

def self.attribute_map
  {
    :'tos_link' => :'tosLink',
    :'privacy_policy_link' => :'privacyPolicyLink',
    :'help_link' => :'helpLink',
    :'support_email' => :'supportEmail',
    :'resource_owner_type' => :'resourceOwnerType',
    :'docs_link' => :'docsLink',
    :'custom_link' => :'customLink',
    :'custom_link_text' => :'customLinkText'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Models attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
# File 'lib/zitadel/client/models/settings_service_legal_and_support_settings.rb', line 188

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash) # `new` will call the initialize method of the specific model class.
end

.openapi_nullableObject

List of attributes with nullable: true



102
103
104
105
# File 'lib/zitadel/client/models/settings_service_legal_and_support_settings.rb', line 102

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/zitadel/client/models/settings_service_legal_and_support_settings.rb', line 88

def self.openapi_types
  {
    :'tos_link' => :'String',
    :'privacy_policy_link' => :'String',
    :'help_link' => :'String',
    :'support_email' => :'String',
    :'resource_owner_type' => :'SettingsServiceResourceOwnerType',
    :'docs_link' => :'String',
    :'custom_link' => :'String',
    :'custom_link_text' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



160
161
162
163
164
165
166
167
168
169
170
171
# File 'lib/zitadel/client/models/settings_service_legal_and_support_settings.rb', line 160

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      tos_link == o.tos_link &&
      privacy_policy_link == o.privacy_policy_link &&
      help_link == o.help_link &&
      support_email == o.support_email &&
      resource_owner_type == o.resource_owner_type &&
      docs_link == o.docs_link &&
      custom_link == o.custom_link &&
      custom_link_text == o.custom_link_text
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



291
292
293
294
295
296
297
298
299
300
301
302
303
# File 'lib/zitadel/client/models/settings_service_legal_and_support_settings.rb', line 291

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


175
176
177
# File 'lib/zitadel/client/models/settings_service_legal_and_support_settings.rb', line 175

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



181
182
183
# File 'lib/zitadel/client/models/settings_service_legal_and_support_settings.rb', line 181

def hash
  [tos_link, privacy_policy_link, help_link, support_email, resource_owner_type, docs_link, custom_link, custom_link_text].hash
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



267
268
269
# File 'lib/zitadel/client/models/settings_service_legal_and_support_settings.rb', line 267

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



273
274
275
276
277
278
279
280
281
282
283
284
285
# File 'lib/zitadel/client/models/settings_service_legal_and_support_settings.rb', line 273

def to_hash
  hash = {} # Calls super.to_hash if parent exists
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



261
262
263
# File 'lib/zitadel/client/models/settings_service_legal_and_support_settings.rb', line 261

def to_s
  to_hash.to_s
end