Class: Zitadel::Client::Models::UserServiceHumanProfile

Inherits:
Object
  • Object
show all
Defined in:
lib/zitadel/client/models/user_service_human_profile.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UserServiceHumanProfile

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Models attributes in the form of hash



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'lib/zitadel/client/models/user_service_human_profile.rb', line 101

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    # MODIFIED: Updated class name in error message
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zitadel::Client::Models::UserServiceHumanProfile` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      # MODIFIED: Updated class name in error message
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zitadel::Client::Models::UserServiceHumanProfile`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'given_name')
    self.given_name = attributes[:'given_name']
  end

  if attributes.key?(:'family_name')
    self.family_name = attributes[:'family_name']
  end

  if attributes.key?(:'nick_name')
    self.nick_name = attributes[:'nick_name']
  end

  if attributes.key?(:'display_name')
    self.display_name = attributes[:'display_name']
  end

  if attributes.key?(:'preferred_language')
    self.preferred_language = attributes[:'preferred_language']
  end

  if attributes.key?(:'gender')
    self.gender = attributes[:'gender']
  end

  if attributes.key?(:'avatar_url')
    self.avatar_url = attributes[:'avatar_url']
  end
end

Instance Attribute Details

#avatar_urlObject

Returns the value of attribute avatar_url.



30
31
32
# File 'lib/zitadel/client/models/user_service_human_profile.rb', line 30

def avatar_url
  @avatar_url
end

#display_nameObject

Returns the value of attribute display_name.



24
25
26
# File 'lib/zitadel/client/models/user_service_human_profile.rb', line 24

def display_name
  @display_name
end

#family_nameObject

Returns the value of attribute family_name.



20
21
22
# File 'lib/zitadel/client/models/user_service_human_profile.rb', line 20

def family_name
  @family_name
end

#genderObject

Returns the value of attribute gender.



28
29
30
# File 'lib/zitadel/client/models/user_service_human_profile.rb', line 28

def gender
  @gender
end

#given_nameObject

Returns the value of attribute given_name.



18
19
20
# File 'lib/zitadel/client/models/user_service_human_profile.rb', line 18

def given_name
  @given_name
end

#nick_nameObject

Returns the value of attribute nick_name.



22
23
24
# File 'lib/zitadel/client/models/user_service_human_profile.rb', line 22

def nick_name
  @nick_name
end

#preferred_languageObject

Returns the value of attribute preferred_language.



26
27
28
# File 'lib/zitadel/client/models/user_service_human_profile.rb', line 26

def preferred_language
  @preferred_language
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
# File 'lib/zitadel/client/models/user_service_human_profile.rb', line 199

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf/anyOf constructs that resolve to a model name
    # MODIFIED: Ensure model is looked up in the Models namespace
    # 'type' here is expected to be the simple class name (e.g., "User", "OrderDetails")
    klass = Zitadel::Client::Models.const_get(type)
    # The `klass.build` method is for oneOf/anyOf types (defined in partial_oneof_module.mustache / partial_anyof_module.mustache)
    # The `klass.build_from_hash` is for regular model types (defined in this base_object.mustache itself)
    if klass.respond_to?(:openapi_one_of) || klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_allOf)
      klass.build(value) # For oneOf/anyOf/allOf, delegate to their specific build method
    else
      klass.build_from_hash(value) # For regular models
    end
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



68
69
70
# File 'lib/zitadel/client/models/user_service_human_profile.rb', line 68

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



73
74
75
# File 'lib/zitadel/client/models/user_service_human_profile.rb', line 73

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



55
56
57
58
59
60
61
62
63
64
65
# File 'lib/zitadel/client/models/user_service_human_profile.rb', line 55

def self.attribute_map
  {
    :'given_name' => :'givenName',
    :'family_name' => :'familyName',
    :'nick_name' => :'nickName',
    :'display_name' => :'displayName',
    :'preferred_language' => :'preferredLanguage',
    :'gender' => :'gender',
    :'avatar_url' => :'avatarUrl'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Models attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/zitadel/client/models/user_service_human_profile.rb', line 175

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash) # `new` will call the initialize method of the specific model class.
end

.openapi_nullableObject

List of attributes with nullable: true



91
92
93
94
95
96
97
# File 'lib/zitadel/client/models/user_service_human_profile.rb', line 91

def self.openapi_nullable
  Set.new([
    :'nick_name',
    :'display_name',
    :'preferred_language',
  ])
end

.openapi_typesObject

Attribute type mapping.



78
79
80
81
82
83
84
85
86
87
88
# File 'lib/zitadel/client/models/user_service_human_profile.rb', line 78

def self.openapi_types
  {
    :'given_name' => :'String',
    :'family_name' => :'String',
    :'nick_name' => :'String',
    :'display_name' => :'String',
    :'preferred_language' => :'String',
    :'gender' => :'UserServiceGender',
    :'avatar_url' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



148
149
150
151
152
153
154
155
156
157
158
# File 'lib/zitadel/client/models/user_service_human_profile.rb', line 148

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      given_name == o.given_name &&
      family_name == o.family_name &&
      nick_name == o.nick_name &&
      display_name == o.display_name &&
      preferred_language == o.preferred_language &&
      gender == o.gender &&
      avatar_url == o.avatar_url
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



278
279
280
281
282
283
284
285
286
287
288
289
290
# File 'lib/zitadel/client/models/user_service_human_profile.rb', line 278

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


162
163
164
# File 'lib/zitadel/client/models/user_service_human_profile.rb', line 162

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



168
169
170
# File 'lib/zitadel/client/models/user_service_human_profile.rb', line 168

def hash
  [given_name, family_name, nick_name, display_name, preferred_language, gender, avatar_url].hash
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



254
255
256
# File 'lib/zitadel/client/models/user_service_human_profile.rb', line 254

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



260
261
262
263
264
265
266
267
268
269
270
271
272
# File 'lib/zitadel/client/models/user_service_human_profile.rb', line 260

def to_hash
  hash = {} # Calls super.to_hash if parent exists
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



248
249
250
# File 'lib/zitadel/client/models/user_service_human_profile.rb', line 248

def to_s
  to_hash.to_s
end