Class: Zitadel::Client::Models::UserServiceProfile
- Inherits:
-
Object
- Object
- Zitadel::Client::Models::UserServiceProfile
- Defined in:
- lib/zitadel/client/models/user_service_profile.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#display_name ⇒ Object
The display name is how a user should primarily be displayed in lists.
-
#family_name ⇒ Object
The family name is the last name of the user.
-
#gender ⇒ Object
Returns the value of attribute gender.
-
#given_name ⇒ Object
The given name is the first name of the user.
-
#nick_name ⇒ Object
The nick name is the users short name.
-
#preferred_language ⇒ Object
The users preferred language is the language that systems should use to interact with the user.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UserServiceProfile
constructor
Initializes the object.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UserServiceProfile
Initializes the object
104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/zitadel/client/models/user_service_profile.rb', line 104 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) # MODIFIED: Updated class name in error message fail ArgumentError, "The input argument (attributes) must be a hash in `Zitadel::Client::Models::UserServiceProfile` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) # MODIFIED: Updated class name in error message fail ArgumentError, "`#{k}` is not a valid attribute in `Zitadel::Client::Models::UserServiceProfile`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'given_name') self.given_name = attributes[:'given_name'] end if attributes.key?(:'family_name') self.family_name = attributes[:'family_name'] end if attributes.key?(:'nick_name') self.nick_name = attributes[:'nick_name'] end if attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] end if attributes.key?(:'preferred_language') self.preferred_language = attributes[:'preferred_language'] end if attributes.key?(:'gender') self.gender = attributes[:'gender'] end end |
Instance Attribute Details
#display_name ⇒ Object
The display name is how a user should primarily be displayed in lists. It can also for example be used to personalize user interfaces and notifications.
28 29 30 |
# File 'lib/zitadel/client/models/user_service_profile.rb', line 28 def display_name @display_name end |
#family_name ⇒ Object
The family name is the last name of the user. For example, it can be used to personalize user interfaces and notifications.
22 23 24 |
# File 'lib/zitadel/client/models/user_service_profile.rb', line 22 def family_name @family_name end |
#gender ⇒ Object
Returns the value of attribute gender.
33 34 35 |
# File 'lib/zitadel/client/models/user_service_profile.rb', line 33 def gender @gender end |
#given_name ⇒ Object
The given name is the first name of the user. For example, it can be used to personalize notifications and login UIs.
19 20 21 |
# File 'lib/zitadel/client/models/user_service_profile.rb', line 19 def given_name @given_name end |
#nick_name ⇒ Object
The nick name is the users short name. For example, it can be used to personalize user interfaces and notifications.
25 26 27 |
# File 'lib/zitadel/client/models/user_service_profile.rb', line 25 def nick_name @nick_name end |
#preferred_language ⇒ Object
The users preferred language is the language that systems should use to interact with the user. It has the format of a [BCP-47 language tag](datatracker.ietf.org/doc/html/rfc3066). It is used by Zitadel where no higher prioritized preferred language can be used. For example, browser settings can overwrite a users preferred_language. Notification messages and standard login UIs use the users preferred language if it is supported and allowed on the instance. Else, the default language of the instance is used.
31 32 33 |
# File 'lib/zitadel/client/models/user_service_profile.rb', line 31 def preferred_language @preferred_language end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 |
# File 'lib/zitadel/client/models/user_service_profile.rb', line 197 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf/anyOf constructs that resolve to a model name # MODIFIED: Ensure model is looked up in the Models namespace # 'type' here is expected to be the simple class name (e.g., "User", "OrderDetails") klass = Zitadel::Client::Models.const_get(type) # The `klass.build` method is for oneOf/anyOf types (defined in partial_oneof_module.mustache / partial_anyof_module.mustache) # The `klass.build_from_hash` is for regular model types (defined in this base_object.mustache itself) if klass.respond_to?(:openapi_one_of) || klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_allOf) klass.build(value) # For oneOf/anyOf/allOf, delegate to their specific build method else klass.build_from_hash(value) # For regular models end end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
70 71 72 |
# File 'lib/zitadel/client/models/user_service_profile.rb', line 70 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
75 76 77 |
# File 'lib/zitadel/client/models/user_service_profile.rb', line 75 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
58 59 60 61 62 63 64 65 66 67 |
# File 'lib/zitadel/client/models/user_service_profile.rb', line 58 def self.attribute_map { :'given_name' => :'givenName', :'family_name' => :'familyName', :'nick_name' => :'nickName', :'display_name' => :'displayName', :'preferred_language' => :'preferredLanguage', :'gender' => :'gender' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/zitadel/client/models/user_service_profile.rb', line 173 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) # `new` will call the initialize method of the specific model class. end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
92 93 94 95 96 97 98 99 100 |
# File 'lib/zitadel/client/models/user_service_profile.rb', line 92 def self.openapi_nullable Set.new([ :'given_name', :'family_name', :'nick_name', :'display_name', :'preferred_language', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
80 81 82 83 84 85 86 87 88 89 |
# File 'lib/zitadel/client/models/user_service_profile.rb', line 80 def self.openapi_types { :'given_name' => :'String', :'family_name' => :'String', :'nick_name' => :'String', :'display_name' => :'String', :'preferred_language' => :'String', :'gender' => :'UserServiceGender' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
147 148 149 150 151 152 153 154 155 156 |
# File 'lib/zitadel/client/models/user_service_profile.rb', line 147 def ==(o) return true if self.equal?(o) self.class == o.class && given_name == o.given_name && family_name == o.family_name && nick_name == o.nick_name && display_name == o.display_name && preferred_language == o.preferred_language && gender == o.gender end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
276 277 278 279 280 281 282 283 284 285 286 287 288 |
# File 'lib/zitadel/client/models/user_service_profile.rb', line 276 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
160 161 162 |
# File 'lib/zitadel/client/models/user_service_profile.rb', line 160 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
166 167 168 |
# File 'lib/zitadel/client/models/user_service_profile.rb', line 166 def hash [given_name, family_name, nick_name, display_name, preferred_language, gender].hash end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
252 253 254 |
# File 'lib/zitadel/client/models/user_service_profile.rb', line 252 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
258 259 260 261 262 263 264 265 266 267 268 269 270 |
# File 'lib/zitadel/client/models/user_service_profile.rb', line 258 def to_hash hash = {} # Calls super.to_hash if parent exists self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
246 247 248 |
# File 'lib/zitadel/client/models/user_service_profile.rb', line 246 def to_s to_hash.to_s end |