Class: Zitadel::Client::Models::UserServiceUser
- Inherits:
-
Object
- Object
- Zitadel::Client::Models::UserServiceUser
- Defined in:
- lib/zitadel/client/models/user_service_user.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#details ⇒ Object
Returns the value of attribute details.
-
#human ⇒ Object
Returns the value of attribute human.
-
#login_names ⇒ Object
Returns the value of attribute login_names.
-
#machine ⇒ Object
Returns the value of attribute machine.
-
#preferred_login_name ⇒ Object
Returns the value of attribute preferred_login_name.
-
#state ⇒ Object
Returns the value of attribute state.
-
#user_id ⇒ Object
Returns the value of attribute user_id.
-
#username ⇒ Object
Returns the value of attribute username.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UserServiceUser
constructor
Initializes the object.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UserServiceUser
Initializes the object
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/zitadel/client/models/user_service_user.rb', line 102 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) # MODIFIED: Updated class name in error message fail ArgumentError, "The input argument (attributes) must be a hash in `Zitadel::Client::Models::UserServiceUser` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) # MODIFIED: Updated class name in error message fail ArgumentError, "`#{k}` is not a valid attribute in `Zitadel::Client::Models::UserServiceUser`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'user_id') self.user_id = attributes[:'user_id'] end if attributes.key?(:'details') self.details = attributes[:'details'] end if attributes.key?(:'state') self.state = attributes[:'state'] end if attributes.key?(:'username') self.username = attributes[:'username'] end if attributes.key?(:'login_names') if (value = attributes[:'login_names']).is_a?(Array) self.login_names = value end end if attributes.key?(:'preferred_login_name') self.preferred_login_name = attributes[:'preferred_login_name'] end if attributes.key?(:'human') self.human = attributes[:'human'] end if attributes.key?(:'machine') self.machine = attributes[:'machine'] end end |
Instance Attribute Details
#details ⇒ Object
Returns the value of attribute details.
20 21 22 |
# File 'lib/zitadel/client/models/user_service_user.rb', line 20 def details @details end |
#human ⇒ Object
Returns the value of attribute human.
30 31 32 |
# File 'lib/zitadel/client/models/user_service_user.rb', line 30 def human @human end |
#login_names ⇒ Object
Returns the value of attribute login_names.
26 27 28 |
# File 'lib/zitadel/client/models/user_service_user.rb', line 26 def login_names @login_names end |
#machine ⇒ Object
Returns the value of attribute machine.
32 33 34 |
# File 'lib/zitadel/client/models/user_service_user.rb', line 32 def machine @machine end |
#preferred_login_name ⇒ Object
Returns the value of attribute preferred_login_name.
28 29 30 |
# File 'lib/zitadel/client/models/user_service_user.rb', line 28 def preferred_login_name @preferred_login_name end |
#state ⇒ Object
Returns the value of attribute state.
22 23 24 |
# File 'lib/zitadel/client/models/user_service_user.rb', line 22 def state @state end |
#user_id ⇒ Object
Returns the value of attribute user_id.
18 19 20 |
# File 'lib/zitadel/client/models/user_service_user.rb', line 18 def user_id @user_id end |
#username ⇒ Object
Returns the value of attribute username.
24 25 26 |
# File 'lib/zitadel/client/models/user_service_user.rb', line 24 def username @username end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 |
# File 'lib/zitadel/client/models/user_service_user.rb', line 207 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf/anyOf constructs that resolve to a model name # MODIFIED: Ensure model is looked up in the Models namespace # 'type' here is expected to be the simple class name (e.g., "User", "OrderDetails") klass = Zitadel::Client::Models.const_get(type) # The `klass.build` method is for oneOf/anyOf types (defined in partial_oneof_module.mustache / partial_anyof_module.mustache) # The `klass.build_from_hash` is for regular model types (defined in this base_object.mustache itself) if klass.respond_to?(:openapi_one_of) || klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_allOf) klass.build(value) # For oneOf/anyOf/allOf, delegate to their specific build method else klass.build_from_hash(value) # For regular models end end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
71 72 73 |
# File 'lib/zitadel/client/models/user_service_user.rb', line 71 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
76 77 78 |
# File 'lib/zitadel/client/models/user_service_user.rb', line 76 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/zitadel/client/models/user_service_user.rb', line 57 def self.attribute_map { :'user_id' => :'userId', :'details' => :'details', :'state' => :'state', :'username' => :'username', :'login_names' => :'loginNames', :'preferred_login_name' => :'preferredLoginName', :'human' => :'human', :'machine' => :'machine' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/zitadel/client/models/user_service_user.rb', line 183 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) # `new` will call the initialize method of the specific model class. end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
95 96 97 98 |
# File 'lib/zitadel/client/models/user_service_user.rb', line 95 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/zitadel/client/models/user_service_user.rb', line 81 def self.openapi_types { :'user_id' => :'String', :'details' => :'UserServiceDetails', :'state' => :'UserServiceUserState', :'username' => :'String', :'login_names' => :'Array<String>', :'preferred_login_name' => :'String', :'human' => :'UserServiceHumanUser', :'machine' => :'UserServiceMachineUser' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/zitadel/client/models/user_service_user.rb', line 155 def ==(o) return true if self.equal?(o) self.class == o.class && user_id == o.user_id && details == o.details && state == o.state && username == o.username && login_names == o.login_names && preferred_login_name == o.preferred_login_name && human == o.human && machine == o.machine end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
286 287 288 289 290 291 292 293 294 295 296 297 298 |
# File 'lib/zitadel/client/models/user_service_user.rb', line 286 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
170 171 172 |
# File 'lib/zitadel/client/models/user_service_user.rb', line 170 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
176 177 178 |
# File 'lib/zitadel/client/models/user_service_user.rb', line 176 def hash [user_id, details, state, username, login_names, preferred_login_name, human, machine].hash end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
262 263 264 |
# File 'lib/zitadel/client/models/user_service_user.rb', line 262 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
268 269 270 271 272 273 274 275 276 277 278 279 280 |
# File 'lib/zitadel/client/models/user_service_user.rb', line 268 def to_hash hash = {} # Calls super.to_hash if parent exists self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
256 257 258 |
# File 'lib/zitadel/client/models/user_service_user.rb', line 256 def to_s to_hash.to_s end |