Class: Zitadel::Client::Models::UserServiceVerifyU2FRegistrationRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/zitadel/client/models/user_service_verify_u2_f_registration_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UserServiceVerifyU2FRegistrationRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Models attributes in the form of hash



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/zitadel/client/models/user_service_verify_u2_f_registration_request.rb', line 65

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    # MODIFIED: Updated class name in error message
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zitadel::Client::Models::UserServiceVerifyU2FRegistrationRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      # MODIFIED: Updated class name in error message
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zitadel::Client::Models::UserServiceVerifyU2FRegistrationRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'user_id')
    self.user_id = attributes[:'user_id']
  end

  if attributes.key?(:'u2f_id')
    self.u2f_id = attributes[:'u2f_id']
  end

  if attributes.key?(:'public_key_credential')
    if (value = attributes[:'public_key_credential']).is_a?(Hash)
      self.public_key_credential = value
    end
  end

  if attributes.key?(:'token_name')
    self.token_name = attributes[:'token_name']
  end
end

Instance Attribute Details

#public_key_credentialObject

‘Struct` represents a structured data value, consisting of fields which map to dynamically typed values. In some languages, `Struct` might be supported by a native representation. For example, in scripting languages like JS a struct is represented as an object. The details of that representation are described together with the proto support for the language. The JSON representation for `Struct` is JSON object.



23
24
25
# File 'lib/zitadel/client/models/user_service_verify_u2_f_registration_request.rb', line 23

def public_key_credential
  @public_key_credential
end

#token_nameObject

Returns the value of attribute token_name.



25
26
27
# File 'lib/zitadel/client/models/user_service_verify_u2_f_registration_request.rb', line 25

def token_name
  @token_name
end

#u2f_idObject

Returns the value of attribute u2f_id.



20
21
22
# File 'lib/zitadel/client/models/user_service_verify_u2_f_registration_request.rb', line 20

def u2f_id
  @u2f_id
end

#user_idObject

Returns the value of attribute user_id.



18
19
20
# File 'lib/zitadel/client/models/user_service_verify_u2_f_registration_request.rb', line 18

def user_id
  @user_id
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/zitadel/client/models/user_service_verify_u2_f_registration_request.rb', line 150

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf/anyOf constructs that resolve to a model name
    # MODIFIED: Ensure model is looked up in the Models namespace
    # 'type' here is expected to be the simple class name (e.g., "User", "OrderDetails")
    klass = Zitadel::Client::Models.const_get(type)
    # The `klass.build` method is for oneOf/anyOf types (defined in partial_oneof_module.mustache / partial_anyof_module.mustache)
    # The `klass.build_from_hash` is for regular model types (defined in this base_object.mustache itself)
    if klass.respond_to?(:openapi_one_of) || klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_allOf)
      klass.build(value) # For oneOf/anyOf/allOf, delegate to their specific build method
    else
      klass.build_from_hash(value) # For regular models
    end
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



38
39
40
# File 'lib/zitadel/client/models/user_service_verify_u2_f_registration_request.rb', line 38

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



43
44
45
# File 'lib/zitadel/client/models/user_service_verify_u2_f_registration_request.rb', line 43

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



28
29
30
31
32
33
34
35
# File 'lib/zitadel/client/models/user_service_verify_u2_f_registration_request.rb', line 28

def self.attribute_map
  {
    :'user_id' => :'userId',
    :'u2f_id' => :'u2fId',
    :'public_key_credential' => :'publicKeyCredential',
    :'token_name' => :'tokenName'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Models attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'lib/zitadel/client/models/user_service_verify_u2_f_registration_request.rb', line 126

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash) # `new` will call the initialize method of the specific model class.
end

.openapi_nullableObject

List of attributes with nullable: true



58
59
60
61
# File 'lib/zitadel/client/models/user_service_verify_u2_f_registration_request.rb', line 58

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



48
49
50
51
52
53
54
55
# File 'lib/zitadel/client/models/user_service_verify_u2_f_registration_request.rb', line 48

def self.openapi_types
  {
    :'user_id' => :'String',
    :'u2f_id' => :'String',
    :'public_key_credential' => :'Hash<String, Object>',
    :'token_name' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



102
103
104
105
106
107
108
109
# File 'lib/zitadel/client/models/user_service_verify_u2_f_registration_request.rb', line 102

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      user_id == o.user_id &&
      u2f_id == o.u2f_id &&
      public_key_credential == o.public_key_credential &&
      token_name == o.token_name
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/zitadel/client/models/user_service_verify_u2_f_registration_request.rb', line 229

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


113
114
115
# File 'lib/zitadel/client/models/user_service_verify_u2_f_registration_request.rb', line 113

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



119
120
121
# File 'lib/zitadel/client/models/user_service_verify_u2_f_registration_request.rb', line 119

def hash
  [user_id, u2f_id, public_key_credential, token_name].hash
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



205
206
207
# File 'lib/zitadel/client/models/user_service_verify_u2_f_registration_request.rb', line 205

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/zitadel/client/models/user_service_verify_u2_f_registration_request.rb', line 211

def to_hash
  hash = {} # Calls super.to_hash if parent exists
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



199
200
201
# File 'lib/zitadel/client/models/user_service_verify_u2_f_registration_request.rb', line 199

def to_s
  to_hash.to_s
end