Class: Zitadel::Client::Auth::NoAuthAuthenticator
- Inherits:
-
Authenticator
- Object
- Authenticator
- Zitadel::Client::Auth::NoAuthAuthenticator
- Defined in:
- lib/zitadel/client/auth/no_auth_authenticator.rb,
sig/lib.rbs
Overview
A simple authenticator that performs no authentication.
This authenticator is useful for cases where no token or credentials are required. It simply returns an empty dictionary for authentication headers.
Instance Attribute Summary
Attributes inherited from Authenticator
Instance Method Summary collapse
-
#auth_headers ⇒ Hash{String => String}
Returns an empty dictionary since no authentication is performed.
-
#initialize(host = 'http://localhost') ⇒ NoAuthAuthenticator
constructor
Initializes the NoAuthAuthenticator with a default host.
Constructor Details
#initialize(host = 'http://localhost') ⇒ NoAuthAuthenticator
Initializes the NoAuthAuthenticator with a default host.
18 19 20 |
# File 'lib/zitadel/client/auth/no_auth_authenticator.rb', line 18 def initialize(host = 'http://localhost') super end |
Instance Method Details
#auth_headers ⇒ Hash{String => String}
Returns an empty dictionary since no authentication is performed.
29 30 31 |
# File 'lib/zitadel/client/auth/no_auth_authenticator.rb', line 29 def auth_headers {} end |