Class: Zitadel::Client::Models::ActionServiceUpdateTargetRequest
- Inherits:
-
Object
- Object
- Zitadel::Client::Models::ActionServiceUpdateTargetRequest
- Defined in:
- lib/zitadel/client/models/action_service_update_target_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#endpoint ⇒ Object
The new URL of the endpoint to call.
-
#expiration_signing_key ⇒ Object
A Duration represents a signed, fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
-
#id ⇒ Object
The unique identifier of the target to update.
-
#name ⇒ Object
Optionally, update the name of the target.
-
#payload_type ⇒ Object
Returns the value of attribute payload_type.
-
#rest_async ⇒ Object
Returns the value of attribute rest_async.
-
#rest_call ⇒ Object
Returns the value of attribute rest_call.
-
#rest_webhook ⇒ Object
Returns the value of attribute rest_webhook.
-
#timeout ⇒ Object
A Duration represents a signed, fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ActionServiceUpdateTargetRequest
constructor
Initializes the object.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ActionServiceUpdateTargetRequest
Initializes the object
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/zitadel/client/models/action_service_update_target_request.rb', line 113 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) # MODIFIED: Updated class name in error message fail ArgumentError, "The input argument (attributes) must be a hash in `Zitadel::Client::Models::ActionServiceUpdateTargetRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) # MODIFIED: Updated class name in error message fail ArgumentError, "`#{k}` is not a valid attribute in `Zitadel::Client::Models::ActionServiceUpdateTargetRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'timeout') self.timeout = attributes[:'timeout'] end if attributes.key?(:'endpoint') self.endpoint = attributes[:'endpoint'] end if attributes.key?(:'expiration_signing_key') self.expiration_signing_key = attributes[:'expiration_signing_key'] end if attributes.key?(:'payload_type') self.payload_type = attributes[:'payload_type'] end if attributes.key?(:'rest_async') self.rest_async = attributes[:'rest_async'] end if attributes.key?(:'rest_call') self.rest_call = attributes[:'rest_call'] end if attributes.key?(:'rest_webhook') self.rest_webhook = attributes[:'rest_webhook'] end end |
Instance Attribute Details
#endpoint ⇒ Object
The new URL of the endpoint to call. If not set, the endpoint will not be changed.
28 29 30 |
# File 'lib/zitadel/client/models/action_service_update_target_request.rb', line 28 def endpoint @endpoint end |
#expiration_signing_key ⇒ Object
A Duration represents a signed, fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". It is related to Timestamp in that the difference between two Timestamp values is a Duration and it can be added or subtracted from a Timestamp. Range is approximately -10,000 years. # Examples Example 1: Compute Duration from two Timestamps in pseudo code. Timestamp start = …; Timestamp end = …; Duration duration = …; duration.seconds = end.seconds - start.seconds; duration.nanos = end.nanos - start.nanos; if (duration.seconds < 0 && duration.nanos > 0) { duration.seconds = 1; duration.nanos -= 1000000000; } else if (duration.seconds > 0 && duration.nanos < 0) { duration.seconds -= 1; duration.nanos = 1000000000; } Example 2: Compute Timestamp from Timestamp Duration in pseudo code. Timestamp start = …; Duration duration = …; Timestamp end = …; end.seconds = start.seconds + duration.seconds; end.nanos = start.nanos + duration.nanos; if (end.nanos < 0) { end.seconds -= 1; end.nanos = 1000000000; } else if (end.nanos >= 1000000000) { end.seconds = 1; end.nanos -= 1000000000; } Example 3: Compute Duration from datetime.timedelta in Python. td = datetime.timedelta(days=3, minutes=10) duration = Duration() duration.FromTimedelta(td) # JSON Mapping In JSON format, the Duration type is encoded as a string rather than an object, where the string ends in the suffix "s" (indicating seconds) and is preceded by the number of seconds, with nanoseconds expressed as fractional seconds. For example, 3 seconds with 0 nanoseconds should be encoded in JSON format as "3s", while 3 seconds and 1 nanosecond should be expressed in JSON format as "3.000000001s", and 3 seconds and 1 microsecond should be expressed in JSON format as "3.000001s".
31 32 33 |
# File 'lib/zitadel/client/models/action_service_update_target_request.rb', line 31 def expiration_signing_key @expiration_signing_key end |
#id ⇒ Object
The unique identifier of the target to update.
19 20 21 |
# File 'lib/zitadel/client/models/action_service_update_target_request.rb', line 19 def id @id end |
#name ⇒ Object
Optionally, update the name of the target. If not set, the name will not be changed.
22 23 24 |
# File 'lib/zitadel/client/models/action_service_update_target_request.rb', line 22 def name @name end |
#payload_type ⇒ Object
Returns the value of attribute payload_type.
33 34 35 |
# File 'lib/zitadel/client/models/action_service_update_target_request.rb', line 33 def payload_type @payload_type end |
#rest_async ⇒ Object
Returns the value of attribute rest_async.
35 36 37 |
# File 'lib/zitadel/client/models/action_service_update_target_request.rb', line 35 def rest_async @rest_async end |
#rest_call ⇒ Object
Returns the value of attribute rest_call.
37 38 39 |
# File 'lib/zitadel/client/models/action_service_update_target_request.rb', line 37 def rest_call @rest_call end |
#rest_webhook ⇒ Object
Returns the value of attribute rest_webhook.
39 40 41 |
# File 'lib/zitadel/client/models/action_service_update_target_request.rb', line 39 def rest_webhook @rest_webhook end |
#timeout ⇒ Object
A Duration represents a signed, fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". It is related to Timestamp in that the difference between two Timestamp values is a Duration and it can be added or subtracted from a Timestamp. Range is approximately -10,000 years. # Examples Example 1: Compute Duration from two Timestamps in pseudo code. Timestamp start = …; Timestamp end = …; Duration duration = …; duration.seconds = end.seconds - start.seconds; duration.nanos = end.nanos - start.nanos; if (duration.seconds < 0 && duration.nanos > 0) { duration.seconds = 1; duration.nanos -= 1000000000; } else if (duration.seconds > 0 && duration.nanos < 0) { duration.seconds -= 1; duration.nanos = 1000000000; } Example 2: Compute Timestamp from Timestamp Duration in pseudo code. Timestamp start = …; Duration duration = …; Timestamp end = …; end.seconds = start.seconds + duration.seconds; end.nanos = start.nanos + duration.nanos; if (end.nanos < 0) { end.seconds -= 1; end.nanos = 1000000000; } else if (end.nanos >= 1000000000) { end.seconds = 1; end.nanos -= 1000000000; } Example 3: Compute Duration from datetime.timedelta in Python. td = datetime.timedelta(days=3, minutes=10) duration = Duration() duration.FromTimedelta(td) # JSON Mapping In JSON format, the Duration type is encoded as a string rather than an object, where the string ends in the suffix "s" (indicating seconds) and is preceded by the number of seconds, with nanoseconds expressed as fractional seconds. For example, 3 seconds with 0 nanoseconds should be encoded in JSON format as "3s", while 3 seconds and 1 nanosecond should be expressed in JSON format as "3.000000001s", and 3 seconds and 1 microsecond should be expressed in JSON format as "3.000001s".
25 26 27 |
# File 'lib/zitadel/client/models/action_service_update_target_request.rb', line 25 def timeout @timeout end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 |
# File 'lib/zitadel/client/models/action_service_update_target_request.rb', line 221 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf/anyOf constructs that resolve to a model name # MODIFIED: Ensure model is looked up in the Models namespace # 'type' here is expected to be the simple class name (e.g., "User", "OrderDetails") klass = Zitadel::Client::Models.const_get(type) # The `klass.build` method is for oneOf/anyOf types (defined in partial_oneof_module.mustache / partial_anyof_module.mustache) # The `klass.build_from_hash` is for regular model types (defined in this base_object.mustache itself) if klass.respond_to?(:openapi_one_of) || klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_allOf) klass.build(value) # For oneOf/anyOf/allOf, delegate to their specific build method else klass.build_from_hash(value) # For regular models end end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
79 80 81 |
# File 'lib/zitadel/client/models/action_service_update_target_request.rb', line 79 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
84 85 86 |
# File 'lib/zitadel/client/models/action_service_update_target_request.rb', line 84 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/zitadel/client/models/action_service_update_target_request.rb', line 64 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'timeout' => :'timeout', :'endpoint' => :'endpoint', :'expiration_signing_key' => :'expirationSigningKey', :'payload_type' => :'payloadType', :'rest_async' => :'restAsync', :'rest_call' => :'restCall', :'rest_webhook' => :'restWebhook' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 |
# File 'lib/zitadel/client/models/action_service_update_target_request.rb', line 197 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) # `new` will call the initialize method of the specific model class. end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
104 105 106 107 108 109 |
# File 'lib/zitadel/client/models/action_service_update_target_request.rb', line 104 def self.openapi_nullable Set.new([ :'name', :'endpoint', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/zitadel/client/models/action_service_update_target_request.rb', line 89 def self.openapi_types { :'id' => :'String', :'name' => :'String', :'timeout' => :'String', :'endpoint' => :'String', :'expiration_signing_key' => :'String', :'payload_type' => :'ActionServicePayloadType', :'rest_async' => :'Object', :'rest_call' => :'ActionServiceRESTCall', :'rest_webhook' => :'ActionServiceRESTWebhook' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
168 169 170 171 172 173 174 175 176 177 178 179 180 |
# File 'lib/zitadel/client/models/action_service_update_target_request.rb', line 168 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && timeout == o.timeout && endpoint == o.endpoint && expiration_signing_key == o.expiration_signing_key && payload_type == o.payload_type && rest_async == o.rest_async && rest_call == o.rest_call && rest_webhook == o.rest_webhook end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
300 301 302 303 304 305 306 307 308 309 310 311 312 |
# File 'lib/zitadel/client/models/action_service_update_target_request.rb', line 300 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
184 185 186 |
# File 'lib/zitadel/client/models/action_service_update_target_request.rb', line 184 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
190 191 192 |
# File 'lib/zitadel/client/models/action_service_update_target_request.rb', line 190 def hash [id, name, timeout, endpoint, expiration_signing_key, payload_type, rest_async, rest_call, rest_webhook].hash end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
276 277 278 |
# File 'lib/zitadel/client/models/action_service_update_target_request.rb', line 276 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
282 283 284 285 286 287 288 289 290 291 292 293 294 |
# File 'lib/zitadel/client/models/action_service_update_target_request.rb', line 282 def to_hash hash = {} # Calls super.to_hash if parent exists self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
270 271 272 |
# File 'lib/zitadel/client/models/action_service_update_target_request.rb', line 270 def to_s to_hash.to_s end |