Class: Zitadel::Client::Models::BetaActionServiceCreateTargetRequest
- Inherits:
-
Object
- Object
- Zitadel::Client::Models::BetaActionServiceCreateTargetRequest
- Defined in:
- lib/zitadel/client/models/beta_action_service_create_target_request.rb
Instance Attribute Summary collapse
-
#endpoint ⇒ Object
Returns the value of attribute endpoint.
-
#name ⇒ Object
Returns the value of attribute name.
-
#rest_async ⇒ Object
Returns the value of attribute rest_async.
-
#rest_call ⇒ Object
Returns the value of attribute rest_call.
-
#rest_webhook ⇒ Object
Returns the value of attribute rest_webhook.
-
#timeout ⇒ Object
A Duration represents a signed, fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BetaActionServiceCreateTargetRequest
constructor
Initializes the object.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ BetaActionServiceCreateTargetRequest
Initializes the object
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/zitadel/client/models/beta_action_service_create_target_request.rb', line 73 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) # MODIFIED: Updated class name in error message fail ArgumentError, "The input argument (attributes) must be a hash in `Zitadel::Client::Models::BetaActionServiceCreateTargetRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) # MODIFIED: Updated class name in error message fail ArgumentError, "`#{k}` is not a valid attribute in `Zitadel::Client::Models::BetaActionServiceCreateTargetRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'timeout') self.timeout = attributes[:'timeout'] end if attributes.key?(:'endpoint') self.endpoint = attributes[:'endpoint'] end if attributes.key?(:'rest_async') self.rest_async = attributes[:'rest_async'] end if attributes.key?(:'rest_call') self.rest_call = attributes[:'rest_call'] end if attributes.key?(:'rest_webhook') self.rest_webhook = attributes[:'rest_webhook'] end end |
Instance Attribute Details
#endpoint ⇒ Object
Returns the value of attribute endpoint.
23 24 25 |
# File 'lib/zitadel/client/models/beta_action_service_create_target_request.rb', line 23 def endpoint @endpoint end |
#name ⇒ Object
Returns the value of attribute name.
18 19 20 |
# File 'lib/zitadel/client/models/beta_action_service_create_target_request.rb', line 18 def name @name end |
#rest_async ⇒ Object
Returns the value of attribute rest_async.
25 26 27 |
# File 'lib/zitadel/client/models/beta_action_service_create_target_request.rb', line 25 def rest_async @rest_async end |
#rest_call ⇒ Object
Returns the value of attribute rest_call.
27 28 29 |
# File 'lib/zitadel/client/models/beta_action_service_create_target_request.rb', line 27 def rest_call @rest_call end |
#rest_webhook ⇒ Object
Returns the value of attribute rest_webhook.
29 30 31 |
# File 'lib/zitadel/client/models/beta_action_service_create_target_request.rb', line 29 def rest_webhook @rest_webhook end |
#timeout ⇒ Object
A Duration represents a signed, fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". It is related to Timestamp in that the difference between two Timestamp values is a Duration and it can be added or subtracted from a Timestamp. Range is approximately -10,000 years. # Examples Example 1: Compute Duration from two Timestamps in pseudo code. Timestamp start = …; Timestamp end = …; Duration duration = …; duration.seconds = end.seconds - start.seconds; duration.nanos = end.nanos - start.nanos; if (duration.seconds < 0 && duration.nanos > 0) { duration.seconds = 1; duration.nanos -= 1000000000; } else if (duration.seconds > 0 && duration.nanos < 0) { duration.seconds -= 1; duration.nanos = 1000000000; } Example 2: Compute Timestamp from Timestamp Duration in pseudo code. Timestamp start = …; Duration duration = …; Timestamp end = …; end.seconds = start.seconds + duration.seconds; end.nanos = start.nanos + duration.nanos; if (end.nanos < 0) { end.seconds -= 1; end.nanos = 1000000000; } else if (end.nanos >= 1000000000) { end.seconds = 1; end.nanos -= 1000000000; } Example 3: Compute Duration from datetime.timedelta in Python. td = datetime.timedelta(days=3, minutes=10) duration = Duration() duration.FromTimedelta(td) # JSON Mapping In JSON format, the Duration type is encoded as a string rather than an object, where the string ends in the suffix "s" (indicating seconds) and is preceded by the number of seconds, with nanoseconds expressed as fractional seconds. For example, 3 seconds with 0 nanoseconds should be encoded in JSON format as "3s", while 3 seconds and 1 nanosecond should be expressed in JSON format as "3.000000001s", and 3 seconds and 1 microsecond should be expressed in JSON format as "3.000001s".
21 22 23 |
# File 'lib/zitadel/client/models/beta_action_service_create_target_request.rb', line 21 def timeout @timeout end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'lib/zitadel/client/models/beta_action_service_create_target_request.rb', line 166 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf/anyOf constructs that resolve to a model name # MODIFIED: Ensure model is looked up in the Models namespace # 'type' here is expected to be the simple class name (e.g., "User", "OrderDetails") klass = Zitadel::Client::Models.const_get(type) # The `klass.build` method is for oneOf/anyOf types (defined in partial_oneof_module.mustache / partial_anyof_module.mustache) # The `klass.build_from_hash` is for regular model types (defined in this base_object.mustache itself) if klass.respond_to?(:openapi_one_of) || klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_allOf) klass.build(value) # For oneOf/anyOf/allOf, delegate to their specific build method else klass.build_from_hash(value) # For regular models end end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
44 45 46 |
# File 'lib/zitadel/client/models/beta_action_service_create_target_request.rb', line 44 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
49 50 51 |
# File 'lib/zitadel/client/models/beta_action_service_create_target_request.rb', line 49 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
32 33 34 35 36 37 38 39 40 41 |
# File 'lib/zitadel/client/models/beta_action_service_create_target_request.rb', line 32 def self.attribute_map { :'name' => :'name', :'timeout' => :'timeout', :'endpoint' => :'endpoint', :'rest_async' => :'restAsync', :'rest_call' => :'restCall', :'rest_webhook' => :'restWebhook' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/zitadel/client/models/beta_action_service_create_target_request.rb', line 142 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) # `new` will call the initialize method of the specific model class. end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
66 67 68 69 |
# File 'lib/zitadel/client/models/beta_action_service_create_target_request.rb', line 66 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
54 55 56 57 58 59 60 61 62 63 |
# File 'lib/zitadel/client/models/beta_action_service_create_target_request.rb', line 54 def self.openapi_types { :'name' => :'String', :'timeout' => :'String', :'endpoint' => :'String', :'rest_async' => :'Object', :'rest_call' => :'BetaActionServiceRESTCall', :'rest_webhook' => :'BetaActionServiceRESTWebhook' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
116 117 118 119 120 121 122 123 124 125 |
# File 'lib/zitadel/client/models/beta_action_service_create_target_request.rb', line 116 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && timeout == o.timeout && endpoint == o.endpoint && rest_async == o.rest_async && rest_call == o.rest_call && rest_webhook == o.rest_webhook end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
245 246 247 248 249 250 251 252 253 254 255 256 257 |
# File 'lib/zitadel/client/models/beta_action_service_create_target_request.rb', line 245 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
129 130 131 |
# File 'lib/zitadel/client/models/beta_action_service_create_target_request.rb', line 129 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
135 136 137 |
# File 'lib/zitadel/client/models/beta_action_service_create_target_request.rb', line 135 def hash [name, timeout, endpoint, rest_async, rest_call, rest_webhook].hash end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
221 222 223 |
# File 'lib/zitadel/client/models/beta_action_service_create_target_request.rb', line 221 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
227 228 229 230 231 232 233 234 235 236 237 238 239 |
# File 'lib/zitadel/client/models/beta_action_service_create_target_request.rb', line 227 def to_hash hash = {} # Calls super.to_hash if parent exists self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
215 216 217 |
# File 'lib/zitadel/client/models/beta_action_service_create_target_request.rb', line 215 def to_s to_hash.to_s end |