Class: Zitadel::Client::Models::BetaAuthorizationServiceAuthorization
- Inherits:
-
Object
- Object
- Zitadel::Client::Models::BetaAuthorizationServiceAuthorization
- Defined in:
- lib/zitadel/client/models/beta_authorization_service_authorization.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#change_date ⇒ Object
A Timestamp represents a point in time independent of any time zone or local calendar, encoded as a count of seconds and fractions of seconds at nanosecond resolution.
-
#creation_date ⇒ Object
A Timestamp represents a point in time independent of any time zone or local calendar, encoded as a count of seconds and fractions of seconds at nanosecond resolution.
-
#granted_organization_id ⇒ Object
ID of the organization the project is granted to, only provided if it is a granted project.
-
#id ⇒ Object
ID is the unique identifier of the authorization.
-
#organization_id ⇒ Object
The unique identifier of the organization the authorization belongs to.
-
#project_grant_id ⇒ Object
ID of the granted project, only provided if it is a granted project.
-
#project_id ⇒ Object
ID is the unique identifier of the project the user was granted the authorization for.
-
#project_name ⇒ Object
Name is the name of the project the user was granted the authorization for.
-
#project_organization_id ⇒ Object
OrganizationID is the ID of the organization the project belongs to.
-
#roles ⇒ Object
Roles contains the roles the user was granted for the project.
-
#state ⇒ Object
Returns the value of attribute state.
-
#user ⇒ Object
Returns the value of attribute user.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BetaAuthorizationServiceAuthorization
constructor
Initializes the object.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ BetaAuthorizationServiceAuthorization
Initializes the object
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/zitadel/client/models/beta_authorization_service_authorization.rb', line 130 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) # MODIFIED: Updated class name in error message fail ArgumentError, "The input argument (attributes) must be a hash in `Zitadel::Client::Models::BetaAuthorizationServiceAuthorization` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) # MODIFIED: Updated class name in error message fail ArgumentError, "`#{k}` is not a valid attribute in `Zitadel::Client::Models::BetaAuthorizationServiceAuthorization`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'project_id') self.project_id = attributes[:'project_id'] end if attributes.key?(:'project_name') self.project_name = attributes[:'project_name'] end if attributes.key?(:'project_organization_id') self.project_organization_id = attributes[:'project_organization_id'] end if attributes.key?(:'project_grant_id') self.project_grant_id = attributes[:'project_grant_id'] end if attributes.key?(:'granted_organization_id') self.granted_organization_id = attributes[:'granted_organization_id'] end if attributes.key?(:'organization_id') self.organization_id = attributes[:'organization_id'] end if attributes.key?(:'creation_date') self.creation_date = attributes[:'creation_date'] end if attributes.key?(:'change_date') self.change_date = attributes[:'change_date'] end if attributes.key?(:'state') self.state = attributes[:'state'] end if attributes.key?(:'user') self.user = attributes[:'user'] end if attributes.key?(:'roles') if (value = attributes[:'roles']).is_a?(Array) self.roles = value end end end |
Instance Attribute Details
#change_date ⇒ Object
A Timestamp represents a point in time independent of any time zone or local calendar, encoded as a count of seconds and fractions of seconds at nanosecond resolution. The count is relative to an epoch at UTC midnight on January 1, 1970, in the proleptic Gregorian calendar which extends the Gregorian calendar backwards to year one. All minutes are 60 seconds long. Leap seconds are "smeared" so that no leap second table is needed for interpretation, using a [24-hour linear smear](developers.google.com/time/smear). The range is from 0001-01-01T00:00:00Z to 9999-12-31T23:59:59.999999999Z. By restricting to that range, we ensure that we can convert to and from [RFC 3339](www.ietf.org/rfc/rfc3339.txt) date strings. # Examples Example 1: Compute Timestamp from POSIX ‘time()`. Timestamp timestamp; timestamp.set_seconds(time(NULL)); timestamp.set_nanos(0); Example 2: Compute Timestamp from POSIX `gettimeofday()`. struct timeval tv; gettimeofday(&tv, NULL); Timestamp timestamp; timestamp.set_seconds(tv.tv_sec); timestamp.set_nanos(tv.tv_usec * 1000); Example 3: Compute Timestamp from Win32 `GetSystemTimeAsFileTime()`. FILETIME ft; GetSystemTimeAsFileTime(&ft); UINT64 ticks = (((UINT64)ft.dwHighDateTime) << 32) | ft.dwLowDateTime; // A Windows tick is 100 nanoseconds. Windows epoch 1601-01-01T00:00:00Z // is 11644473600 seconds before Unix epoch 1970-01-01T00:00:00Z. Timestamp timestamp; timestamp.set_seconds((INT64) ((ticks / 10000000) - 11644473600LL)); timestamp.set_nanos((INT32) ((ticks % 10000000) * 100)); Example 4: Compute Timestamp from Java `System.currentTimeMillis()`. long millis = System.currentTimeMillis(); Timestamp timestamp = Timestamp.newBuilder().setSeconds(millis / 1000) .setNanos((int) ((millis % 1000) * 1000000)).build(); Example 5: Compute Timestamp from Java `Instant.now()`. Instant now = Instant.now(); Timestamp timestamp = Timestamp.newBuilder().setSeconds(now.getEpochSecond()) .setNanos(now.getNano()).build(); Example 6: Compute Timestamp from current time in Python. timestamp = Timestamp() timestamp.GetCurrentTime() # JSON Mapping In JSON format, the Timestamp type is encoded as a string in the [RFC 3339](www.ietf.org/rfc/rfc3339.txt) format. That is, the format is "year-month-dayThour:min:secZ" where year is always expressed using four digits while month, day, hour, min, and sec are zero-padded to two digits each. The fractional seconds, which can go up to 9 digits (i.e. up to 1 nanosecond resolution), are optional. The "Z" suffix indicates the timezone ("UTC"); the timezone is required. A proto3 JSON serializer should always use UTC (as indicated by "Z") when printing the Timestamp type and a proto3 JSON parser should be able to accept both UTC and other timezones (as indicated by an offset). For example, "2017-01-15T01:30:15.01Z" encodes 15.01 seconds past 01:30 UTC on January 15, 2017. In JavaScript, one can convert a Date object to this format using the standard [toISOString()](developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString) method. In Python, a standard `datetime.datetime` object can be converted to this format using [`strftime`](docs.python.org/2/library/time.html#time.strftime) with the time format spec ’%Y-%m-%dT%H:%M:%S.%fZ’. Likewise, in Java, one can use the Joda Time’s [‘ISODateTimeFormat.dateTime()`]( joda-time.sourceforge.net/apidocs/org/joda/time/format/ISODateTimeFormat.html#dateTime() ) to obtain a formatter capable of generating timestamps in this format.
43 44 45 |
# File 'lib/zitadel/client/models/beta_authorization_service_authorization.rb', line 43 def change_date @change_date end |
#creation_date ⇒ Object
A Timestamp represents a point in time independent of any time zone or local calendar, encoded as a count of seconds and fractions of seconds at nanosecond resolution. The count is relative to an epoch at UTC midnight on January 1, 1970, in the proleptic Gregorian calendar which extends the Gregorian calendar backwards to year one. All minutes are 60 seconds long. Leap seconds are "smeared" so that no leap second table is needed for interpretation, using a [24-hour linear smear](developers.google.com/time/smear). The range is from 0001-01-01T00:00:00Z to 9999-12-31T23:59:59.999999999Z. By restricting to that range, we ensure that we can convert to and from [RFC 3339](www.ietf.org/rfc/rfc3339.txt) date strings. # Examples Example 1: Compute Timestamp from POSIX ‘time()`. Timestamp timestamp; timestamp.set_seconds(time(NULL)); timestamp.set_nanos(0); Example 2: Compute Timestamp from POSIX `gettimeofday()`. struct timeval tv; gettimeofday(&tv, NULL); Timestamp timestamp; timestamp.set_seconds(tv.tv_sec); timestamp.set_nanos(tv.tv_usec * 1000); Example 3: Compute Timestamp from Win32 `GetSystemTimeAsFileTime()`. FILETIME ft; GetSystemTimeAsFileTime(&ft); UINT64 ticks = (((UINT64)ft.dwHighDateTime) << 32) | ft.dwLowDateTime; // A Windows tick is 100 nanoseconds. Windows epoch 1601-01-01T00:00:00Z // is 11644473600 seconds before Unix epoch 1970-01-01T00:00:00Z. Timestamp timestamp; timestamp.set_seconds((INT64) ((ticks / 10000000) - 11644473600LL)); timestamp.set_nanos((INT32) ((ticks % 10000000) * 100)); Example 4: Compute Timestamp from Java `System.currentTimeMillis()`. long millis = System.currentTimeMillis(); Timestamp timestamp = Timestamp.newBuilder().setSeconds(millis / 1000) .setNanos((int) ((millis % 1000) * 1000000)).build(); Example 5: Compute Timestamp from Java `Instant.now()`. Instant now = Instant.now(); Timestamp timestamp = Timestamp.newBuilder().setSeconds(now.getEpochSecond()) .setNanos(now.getNano()).build(); Example 6: Compute Timestamp from current time in Python. timestamp = Timestamp() timestamp.GetCurrentTime() # JSON Mapping In JSON format, the Timestamp type is encoded as a string in the [RFC 3339](www.ietf.org/rfc/rfc3339.txt) format. That is, the format is "year-month-dayThour:min:secZ" where year is always expressed using four digits while month, day, hour, min, and sec are zero-padded to two digits each. The fractional seconds, which can go up to 9 digits (i.e. up to 1 nanosecond resolution), are optional. The "Z" suffix indicates the timezone ("UTC"); the timezone is required. A proto3 JSON serializer should always use UTC (as indicated by "Z") when printing the Timestamp type and a proto3 JSON parser should be able to accept both UTC and other timezones (as indicated by an offset). For example, "2017-01-15T01:30:15.01Z" encodes 15.01 seconds past 01:30 UTC on January 15, 2017. In JavaScript, one can convert a Date object to this format using the standard [toISOString()](developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString) method. In Python, a standard `datetime.datetime` object can be converted to this format using [`strftime`](docs.python.org/2/library/time.html#time.strftime) with the time format spec ’%Y-%m-%dT%H:%M:%S.%fZ’. Likewise, in Java, one can use the Joda Time’s [‘ISODateTimeFormat.dateTime()`]( joda-time.sourceforge.net/apidocs/org/joda/time/format/ISODateTimeFormat.html#dateTime() ) to obtain a formatter capable of generating timestamps in this format.
40 41 42 |
# File 'lib/zitadel/client/models/beta_authorization_service_authorization.rb', line 40 def creation_date @creation_date end |
#granted_organization_id ⇒ Object
ID of the organization the project is granted to, only provided if it is a granted project.
34 35 36 |
# File 'lib/zitadel/client/models/beta_authorization_service_authorization.rb', line 34 def granted_organization_id @granted_organization_id end |
#id ⇒ Object
ID is the unique identifier of the authorization.
19 20 21 |
# File 'lib/zitadel/client/models/beta_authorization_service_authorization.rb', line 19 def id @id end |
#organization_id ⇒ Object
The unique identifier of the organization the authorization belongs to.
37 38 39 |
# File 'lib/zitadel/client/models/beta_authorization_service_authorization.rb', line 37 def organization_id @organization_id end |
#project_grant_id ⇒ Object
ID of the granted project, only provided if it is a granted project.
31 32 33 |
# File 'lib/zitadel/client/models/beta_authorization_service_authorization.rb', line 31 def project_grant_id @project_grant_id end |
#project_id ⇒ Object
ID is the unique identifier of the project the user was granted the authorization for.
22 23 24 |
# File 'lib/zitadel/client/models/beta_authorization_service_authorization.rb', line 22 def project_id @project_id end |
#project_name ⇒ Object
Name is the name of the project the user was granted the authorization for.
25 26 27 |
# File 'lib/zitadel/client/models/beta_authorization_service_authorization.rb', line 25 def project_name @project_name end |
#project_organization_id ⇒ Object
OrganizationID is the ID of the organization the project belongs to.
28 29 30 |
# File 'lib/zitadel/client/models/beta_authorization_service_authorization.rb', line 28 def project_organization_id @project_organization_id end |
#roles ⇒ Object
Roles contains the roles the user was granted for the project.
50 51 52 |
# File 'lib/zitadel/client/models/beta_authorization_service_authorization.rb', line 50 def roles @roles end |
#state ⇒ Object
Returns the value of attribute state.
45 46 47 |
# File 'lib/zitadel/client/models/beta_authorization_service_authorization.rb', line 45 def state @state end |
#user ⇒ Object
Returns the value of attribute user.
47 48 49 |
# File 'lib/zitadel/client/models/beta_authorization_service_authorization.rb', line 47 def user @user end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 |
# File 'lib/zitadel/client/models/beta_authorization_service_authorization.rb', line 255 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf/anyOf constructs that resolve to a model name # MODIFIED: Ensure model is looked up in the Models namespace # 'type' here is expected to be the simple class name (e.g., "User", "OrderDetails") klass = Zitadel::Client::Models.const_get(type) # The `klass.build` method is for oneOf/anyOf types (defined in partial_oneof_module.mustache / partial_anyof_module.mustache) # The `klass.build_from_hash` is for regular model types (defined in this base_object.mustache itself) if klass.respond_to?(:openapi_one_of) || klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_allOf) klass.build(value) # For oneOf/anyOf/allOf, delegate to their specific build method else klass.build_from_hash(value) # For regular models end end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
93 94 95 |
# File 'lib/zitadel/client/models/beta_authorization_service_authorization.rb', line 93 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
98 99 100 |
# File 'lib/zitadel/client/models/beta_authorization_service_authorization.rb', line 98 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/zitadel/client/models/beta_authorization_service_authorization.rb', line 75 def self.attribute_map { :'id' => :'id', :'project_id' => :'projectId', :'project_name' => :'projectName', :'project_organization_id' => :'projectOrganizationId', :'project_grant_id' => :'projectGrantId', :'granted_organization_id' => :'grantedOrganizationId', :'organization_id' => :'organizationId', :'creation_date' => :'creationDate', :'change_date' => :'changeDate', :'state' => :'state', :'user' => :'user', :'roles' => :'roles' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/zitadel/client/models/beta_authorization_service_authorization.rb', line 231 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) # `new` will call the initialize method of the specific model class. end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
121 122 123 124 125 126 |
# File 'lib/zitadel/client/models/beta_authorization_service_authorization.rb', line 121 def self.openapi_nullable Set.new([ :'project_grant_id', :'granted_organization_id', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/zitadel/client/models/beta_authorization_service_authorization.rb', line 103 def self.openapi_types { :'id' => :'String', :'project_id' => :'String', :'project_name' => :'String', :'project_organization_id' => :'String', :'project_grant_id' => :'String', :'granted_organization_id' => :'String', :'organization_id' => :'String', :'creation_date' => :'Time', :'change_date' => :'Time', :'state' => :'BetaAuthorizationServiceState', :'user' => :'BetaAuthorizationServiceUser', :'roles' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 |
# File 'lib/zitadel/client/models/beta_authorization_service_authorization.rb', line 199 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && project_id == o.project_id && project_name == o.project_name && project_organization_id == o.project_organization_id && project_grant_id == o.project_grant_id && granted_organization_id == o.granted_organization_id && organization_id == o.organization_id && creation_date == o.creation_date && change_date == o.change_date && state == o.state && user == o.user && roles == o.roles end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
334 335 336 337 338 339 340 341 342 343 344 345 346 |
# File 'lib/zitadel/client/models/beta_authorization_service_authorization.rb', line 334 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
218 219 220 |
# File 'lib/zitadel/client/models/beta_authorization_service_authorization.rb', line 218 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
224 225 226 |
# File 'lib/zitadel/client/models/beta_authorization_service_authorization.rb', line 224 def hash [id, project_id, project_name, project_organization_id, project_grant_id, granted_organization_id, organization_id, creation_date, change_date, state, user, roles].hash end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
310 311 312 |
# File 'lib/zitadel/client/models/beta_authorization_service_authorization.rb', line 310 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
316 317 318 319 320 321 322 323 324 325 326 327 328 |
# File 'lib/zitadel/client/models/beta_authorization_service_authorization.rb', line 316 def to_hash hash = {} # Calls super.to_hash if parent exists self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
304 305 306 |
# File 'lib/zitadel/client/models/beta_authorization_service_authorization.rb', line 304 def to_s to_hash.to_s end |