Class: Zitadel::Client::Models::BetaUserServiceSearchQuery
- Inherits:
-
Object
- Object
- Zitadel::Client::Models::BetaUserServiceSearchQuery
- Defined in:
- lib/zitadel/client/models/beta_user_service_search_query.rb
Instance Attribute Summary collapse
-
#and_query ⇒ Object
Returns the value of attribute and_query.
-
#display_name_query ⇒ Object
Returns the value of attribute display_name_query.
-
#email_query ⇒ Object
Returns the value of attribute email_query.
-
#first_name_query ⇒ Object
Returns the value of attribute first_name_query.
-
#in_user_emails_query ⇒ Object
Returns the value of attribute in_user_emails_query.
-
#in_user_ids_query ⇒ Object
Returns the value of attribute in_user_ids_query.
-
#last_name_query ⇒ Object
Returns the value of attribute last_name_query.
-
#login_name_query ⇒ Object
Returns the value of attribute login_name_query.
-
#nick_name_query ⇒ Object
Returns the value of attribute nick_name_query.
-
#not_query ⇒ Object
Returns the value of attribute not_query.
-
#or_query ⇒ Object
Returns the value of attribute or_query.
-
#organization_id_query ⇒ Object
Returns the value of attribute organization_id_query.
-
#phone_query ⇒ Object
Returns the value of attribute phone_query.
-
#state_query ⇒ Object
Returns the value of attribute state_query.
-
#type_query ⇒ Object
Returns the value of attribute type_query.
-
#user_name_query ⇒ Object
Returns the value of attribute user_name_query.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BetaUserServiceSearchQuery
constructor
Initializes the object.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ BetaUserServiceSearchQuery
Initializes the object
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/zitadel/client/models/beta_user_service_search_query.rb', line 112 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) # MODIFIED: Updated class name in error message fail ArgumentError, "The input argument (attributes) must be a hash in `Zitadel::Client::Models::BetaUserServiceSearchQuery` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) # MODIFIED: Updated class name in error message fail ArgumentError, "`#{k}` is not a valid attribute in `Zitadel::Client::Models::BetaUserServiceSearchQuery`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'and_query') self.and_query = attributes[:'and_query'] end if attributes.key?(:'display_name_query') self.display_name_query = attributes[:'display_name_query'] end if attributes.key?(:'email_query') self.email_query = attributes[:'email_query'] end if attributes.key?(:'first_name_query') self.first_name_query = attributes[:'first_name_query'] end if attributes.key?(:'in_user_emails_query') self.in_user_emails_query = attributes[:'in_user_emails_query'] end if attributes.key?(:'in_user_ids_query') self.in_user_ids_query = attributes[:'in_user_ids_query'] end if attributes.key?(:'last_name_query') self.last_name_query = attributes[:'last_name_query'] end if attributes.key?(:'login_name_query') self.login_name_query = attributes[:'login_name_query'] end if attributes.key?(:'nick_name_query') self.nick_name_query = attributes[:'nick_name_query'] end if attributes.key?(:'not_query') self.not_query = attributes[:'not_query'] end if attributes.key?(:'or_query') self.or_query = attributes[:'or_query'] end if attributes.key?(:'organization_id_query') self.organization_id_query = attributes[:'organization_id_query'] end if attributes.key?(:'phone_query') self.phone_query = attributes[:'phone_query'] end if attributes.key?(:'state_query') self.state_query = attributes[:'state_query'] end if attributes.key?(:'type_query') self.type_query = attributes[:'type_query'] end if attributes.key?(:'user_name_query') self.user_name_query = attributes[:'user_name_query'] end end |
Instance Attribute Details
#and_query ⇒ Object
Returns the value of attribute and_query.
18 19 20 |
# File 'lib/zitadel/client/models/beta_user_service_search_query.rb', line 18 def and_query @and_query end |
#display_name_query ⇒ Object
Returns the value of attribute display_name_query.
20 21 22 |
# File 'lib/zitadel/client/models/beta_user_service_search_query.rb', line 20 def display_name_query @display_name_query end |
#email_query ⇒ Object
Returns the value of attribute email_query.
22 23 24 |
# File 'lib/zitadel/client/models/beta_user_service_search_query.rb', line 22 def email_query @email_query end |
#first_name_query ⇒ Object
Returns the value of attribute first_name_query.
24 25 26 |
# File 'lib/zitadel/client/models/beta_user_service_search_query.rb', line 24 def first_name_query @first_name_query end |
#in_user_emails_query ⇒ Object
Returns the value of attribute in_user_emails_query.
26 27 28 |
# File 'lib/zitadel/client/models/beta_user_service_search_query.rb', line 26 def in_user_emails_query @in_user_emails_query end |
#in_user_ids_query ⇒ Object
Returns the value of attribute in_user_ids_query.
28 29 30 |
# File 'lib/zitadel/client/models/beta_user_service_search_query.rb', line 28 def in_user_ids_query @in_user_ids_query end |
#last_name_query ⇒ Object
Returns the value of attribute last_name_query.
30 31 32 |
# File 'lib/zitadel/client/models/beta_user_service_search_query.rb', line 30 def last_name_query @last_name_query end |
#login_name_query ⇒ Object
Returns the value of attribute login_name_query.
32 33 34 |
# File 'lib/zitadel/client/models/beta_user_service_search_query.rb', line 32 def login_name_query @login_name_query end |
#nick_name_query ⇒ Object
Returns the value of attribute nick_name_query.
34 35 36 |
# File 'lib/zitadel/client/models/beta_user_service_search_query.rb', line 34 def nick_name_query @nick_name_query end |
#not_query ⇒ Object
Returns the value of attribute not_query.
36 37 38 |
# File 'lib/zitadel/client/models/beta_user_service_search_query.rb', line 36 def not_query @not_query end |
#or_query ⇒ Object
Returns the value of attribute or_query.
38 39 40 |
# File 'lib/zitadel/client/models/beta_user_service_search_query.rb', line 38 def or_query @or_query end |
#organization_id_query ⇒ Object
Returns the value of attribute organization_id_query.
40 41 42 |
# File 'lib/zitadel/client/models/beta_user_service_search_query.rb', line 40 def organization_id_query @organization_id_query end |
#phone_query ⇒ Object
Returns the value of attribute phone_query.
42 43 44 |
# File 'lib/zitadel/client/models/beta_user_service_search_query.rb', line 42 def phone_query @phone_query end |
#state_query ⇒ Object
Returns the value of attribute state_query.
44 45 46 |
# File 'lib/zitadel/client/models/beta_user_service_search_query.rb', line 44 def state_query @state_query end |
#type_query ⇒ Object
Returns the value of attribute type_query.
46 47 48 |
# File 'lib/zitadel/client/models/beta_user_service_search_query.rb', line 46 def type_query @type_query end |
#user_name_query ⇒ Object
Returns the value of attribute user_name_query.
48 49 50 |
# File 'lib/zitadel/client/models/beta_user_service_search_query.rb', line 48 def user_name_query @user_name_query end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 |
# File 'lib/zitadel/client/models/beta_user_service_search_query.rb', line 255 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf/anyOf constructs that resolve to a model name # MODIFIED: Ensure model is looked up in the Models namespace # 'type' here is expected to be the simple class name (e.g., "User", "OrderDetails") klass = Zitadel::Client::Models.const_get(type) # The `klass.build` method is for oneOf/anyOf types (defined in partial_oneof_module.mustache / partial_anyof_module.mustache) # The `klass.build_from_hash` is for regular model types (defined in this base_object.mustache itself) if klass.respond_to?(:openapi_one_of) || klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_allOf) klass.build(value) # For oneOf/anyOf/allOf, delegate to their specific build method else klass.build_from_hash(value) # For regular models end end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
73 74 75 |
# File 'lib/zitadel/client/models/beta_user_service_search_query.rb', line 73 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
78 79 80 |
# File 'lib/zitadel/client/models/beta_user_service_search_query.rb', line 78 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/zitadel/client/models/beta_user_service_search_query.rb', line 51 def self.attribute_map { :'and_query' => :'andQuery', :'display_name_query' => :'displayNameQuery', :'email_query' => :'emailQuery', :'first_name_query' => :'firstNameQuery', :'in_user_emails_query' => :'inUserEmailsQuery', :'in_user_ids_query' => :'inUserIdsQuery', :'last_name_query' => :'lastNameQuery', :'login_name_query' => :'loginNameQuery', :'nick_name_query' => :'nickNameQuery', :'not_query' => :'notQuery', :'or_query' => :'orQuery', :'organization_id_query' => :'organizationIdQuery', :'phone_query' => :'phoneQuery', :'state_query' => :'stateQuery', :'type_query' => :'typeQuery', :'user_name_query' => :'userNameQuery' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/zitadel/client/models/beta_user_service_search_query.rb', line 231 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) # `new` will call the initialize method of the specific model class. end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
105 106 107 108 |
# File 'lib/zitadel/client/models/beta_user_service_search_query.rb', line 105 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/zitadel/client/models/beta_user_service_search_query.rb', line 83 def self.openapi_types { :'and_query' => :'BetaUserServiceAndQuery', :'display_name_query' => :'BetaUserServiceDisplayNameQuery', :'email_query' => :'BetaUserServiceEmailQuery', :'first_name_query' => :'BetaUserServiceFirstNameQuery', :'in_user_emails_query' => :'BetaUserServiceInUserEmailsQuery', :'in_user_ids_query' => :'BetaUserServiceInUserIDQuery', :'last_name_query' => :'BetaUserServiceLastNameQuery', :'login_name_query' => :'BetaUserServiceLoginNameQuery', :'nick_name_query' => :'BetaUserServiceNickNameQuery', :'not_query' => :'BetaUserServiceNotQuery', :'or_query' => :'BetaUserServiceOrQuery', :'organization_id_query' => :'BetaUserServiceOrganizationIdQuery', :'phone_query' => :'BetaUserServicePhoneQuery', :'state_query' => :'BetaUserServiceStateQuery', :'type_query' => :'BetaUserServiceTypeQuery', :'user_name_query' => :'BetaUserServiceUserNameQuery' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 |
# File 'lib/zitadel/client/models/beta_user_service_search_query.rb', line 195 def ==(o) return true if self.equal?(o) self.class == o.class && and_query == o.and_query && display_name_query == o.display_name_query && email_query == o.email_query && first_name_query == o.first_name_query && in_user_emails_query == o.in_user_emails_query && in_user_ids_query == o.in_user_ids_query && last_name_query == o.last_name_query && login_name_query == o.login_name_query && nick_name_query == o.nick_name_query && not_query == o.not_query && or_query == o.or_query && organization_id_query == o.organization_id_query && phone_query == o.phone_query && state_query == o.state_query && type_query == o.type_query && user_name_query == o.user_name_query end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
334 335 336 337 338 339 340 341 342 343 344 345 346 |
# File 'lib/zitadel/client/models/beta_user_service_search_query.rb', line 334 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
218 219 220 |
# File 'lib/zitadel/client/models/beta_user_service_search_query.rb', line 218 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
224 225 226 |
# File 'lib/zitadel/client/models/beta_user_service_search_query.rb', line 224 def hash [and_query, display_name_query, email_query, first_name_query, in_user_emails_query, in_user_ids_query, last_name_query, login_name_query, nick_name_query, not_query, or_query, organization_id_query, phone_query, state_query, type_query, user_name_query].hash end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
310 311 312 |
# File 'lib/zitadel/client/models/beta_user_service_search_query.rb', line 310 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
316 317 318 319 320 321 322 323 324 325 326 327 328 |
# File 'lib/zitadel/client/models/beta_user_service_search_query.rb', line 316 def to_hash hash = {} # Calls super.to_hash if parent exists self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
304 305 306 |
# File 'lib/zitadel/client/models/beta_user_service_search_query.rb', line 304 def to_s to_hash.to_s end |