Class: Zitadel::Client::Models::IdentityProviderServiceIDPConfig
- Inherits:
-
Object
- Object
- Zitadel::Client::Models::IdentityProviderServiceIDPConfig
- Defined in:
- lib/zitadel/client/models/identity_provider_service_i_d_p_config.rb
Instance Attribute Summary collapse
-
#apple ⇒ Object
Returns the value of attribute apple.
-
#azure_ad ⇒ Object
Returns the value of attribute azure_ad.
-
#github ⇒ Object
Returns the value of attribute github.
-
#github_es ⇒ Object
Returns the value of attribute github_es.
-
#gitlab ⇒ Object
Returns the value of attribute gitlab.
-
#gitlab_self_hosted ⇒ Object
Returns the value of attribute gitlab_self_hosted.
-
#google ⇒ Object
Returns the value of attribute google.
-
#jwt ⇒ Object
Returns the value of attribute jwt.
-
#ldap ⇒ Object
Returns the value of attribute ldap.
-
#oauth ⇒ Object
Returns the value of attribute oauth.
-
#oidc ⇒ Object
Returns the value of attribute oidc.
-
#options ⇒ Object
Returns the value of attribute options.
-
#saml ⇒ Object
Returns the value of attribute saml.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ IdentityProviderServiceIDPConfig
constructor
Initializes the object.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ IdentityProviderServiceIDPConfig
Initializes the object
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/zitadel/client/models/identity_provider_service_i_d_p_config.rb', line 100 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) # MODIFIED: Updated class name in error message fail ArgumentError, "The input argument (attributes) must be a hash in `Zitadel::Client::Models::IdentityProviderServiceIDPConfig` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) # MODIFIED: Updated class name in error message fail ArgumentError, "`#{k}` is not a valid attribute in `Zitadel::Client::Models::IdentityProviderServiceIDPConfig`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'options') self. = attributes[:'options'] end if attributes.key?(:'apple') self.apple = attributes[:'apple'] end if attributes.key?(:'azure_ad') self.azure_ad = attributes[:'azure_ad'] end if attributes.key?(:'github') self.github = attributes[:'github'] end if attributes.key?(:'github_es') self.github_es = attributes[:'github_es'] end if attributes.key?(:'gitlab') self.gitlab = attributes[:'gitlab'] end if attributes.key?(:'gitlab_self_hosted') self.gitlab_self_hosted = attributes[:'gitlab_self_hosted'] end if attributes.key?(:'google') self.google = attributes[:'google'] end if attributes.key?(:'jwt') self.jwt = attributes[:'jwt'] end if attributes.key?(:'ldap') self.ldap = attributes[:'ldap'] end if attributes.key?(:'oauth') self.oauth = attributes[:'oauth'] end if attributes.key?(:'oidc') self.oidc = attributes[:'oidc'] end if attributes.key?(:'saml') self.saml = attributes[:'saml'] end end |
Instance Attribute Details
#apple ⇒ Object
Returns the value of attribute apple.
20 21 22 |
# File 'lib/zitadel/client/models/identity_provider_service_i_d_p_config.rb', line 20 def apple @apple end |
#azure_ad ⇒ Object
Returns the value of attribute azure_ad.
22 23 24 |
# File 'lib/zitadel/client/models/identity_provider_service_i_d_p_config.rb', line 22 def azure_ad @azure_ad end |
#github ⇒ Object
Returns the value of attribute github.
24 25 26 |
# File 'lib/zitadel/client/models/identity_provider_service_i_d_p_config.rb', line 24 def github @github end |
#github_es ⇒ Object
Returns the value of attribute github_es.
26 27 28 |
# File 'lib/zitadel/client/models/identity_provider_service_i_d_p_config.rb', line 26 def github_es @github_es end |
#gitlab ⇒ Object
Returns the value of attribute gitlab.
28 29 30 |
# File 'lib/zitadel/client/models/identity_provider_service_i_d_p_config.rb', line 28 def gitlab @gitlab end |
#gitlab_self_hosted ⇒ Object
Returns the value of attribute gitlab_self_hosted.
30 31 32 |
# File 'lib/zitadel/client/models/identity_provider_service_i_d_p_config.rb', line 30 def gitlab_self_hosted @gitlab_self_hosted end |
#google ⇒ Object
Returns the value of attribute google.
32 33 34 |
# File 'lib/zitadel/client/models/identity_provider_service_i_d_p_config.rb', line 32 def google @google end |
#jwt ⇒ Object
Returns the value of attribute jwt.
34 35 36 |
# File 'lib/zitadel/client/models/identity_provider_service_i_d_p_config.rb', line 34 def jwt @jwt end |
#ldap ⇒ Object
Returns the value of attribute ldap.
36 37 38 |
# File 'lib/zitadel/client/models/identity_provider_service_i_d_p_config.rb', line 36 def ldap @ldap end |
#oauth ⇒ Object
Returns the value of attribute oauth.
38 39 40 |
# File 'lib/zitadel/client/models/identity_provider_service_i_d_p_config.rb', line 38 def oauth @oauth end |
#oidc ⇒ Object
Returns the value of attribute oidc.
40 41 42 |
# File 'lib/zitadel/client/models/identity_provider_service_i_d_p_config.rb', line 40 def oidc @oidc end |
#options ⇒ Object
Returns the value of attribute options.
18 19 20 |
# File 'lib/zitadel/client/models/identity_provider_service_i_d_p_config.rb', line 18 def @options end |
#saml ⇒ Object
Returns the value of attribute saml.
42 43 44 |
# File 'lib/zitadel/client/models/identity_provider_service_i_d_p_config.rb', line 42 def saml @saml end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 |
# File 'lib/zitadel/client/models/identity_provider_service_i_d_p_config.rb', line 228 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf/anyOf constructs that resolve to a model name # MODIFIED: Ensure model is looked up in the Models namespace # 'type' here is expected to be the simple class name (e.g., "User", "OrderDetails") klass = Zitadel::Client::Models.const_get(type) # The `klass.build` method is for oneOf/anyOf types (defined in partial_oneof_module.mustache / partial_anyof_module.mustache) # The `klass.build_from_hash` is for regular model types (defined in this base_object.mustache itself) if klass.respond_to?(:openapi_one_of) || klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_allOf) klass.build(value) # For oneOf/anyOf/allOf, delegate to their specific build method else klass.build_from_hash(value) # For regular models end end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
64 65 66 |
# File 'lib/zitadel/client/models/identity_provider_service_i_d_p_config.rb', line 64 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
69 70 71 |
# File 'lib/zitadel/client/models/identity_provider_service_i_d_p_config.rb', line 69 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/zitadel/client/models/identity_provider_service_i_d_p_config.rb', line 45 def self.attribute_map { :'options' => :'options', :'apple' => :'apple', :'azure_ad' => :'azureAd', :'github' => :'github', :'github_es' => :'githubEs', :'gitlab' => :'gitlab', :'gitlab_self_hosted' => :'gitlabSelfHosted', :'google' => :'google', :'jwt' => :'jwt', :'ldap' => :'ldap', :'oauth' => :'oauth', :'oidc' => :'oidc', :'saml' => :'saml' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 |
# File 'lib/zitadel/client/models/identity_provider_service_i_d_p_config.rb', line 204 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) # `new` will call the initialize method of the specific model class. end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
93 94 95 96 |
# File 'lib/zitadel/client/models/identity_provider_service_i_d_p_config.rb', line 93 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/zitadel/client/models/identity_provider_service_i_d_p_config.rb', line 74 def self.openapi_types { :'options' => :'IdentityProviderServiceOptions', :'apple' => :'IdentityProviderServiceAppleConfig', :'azure_ad' => :'IdentityProviderServiceAzureADConfig', :'github' => :'IdentityProviderServiceGitHubConfig', :'github_es' => :'IdentityProviderServiceGitHubEnterpriseServerConfig', :'gitlab' => :'IdentityProviderServiceGitLabConfig', :'gitlab_self_hosted' => :'IdentityProviderServiceGitLabSelfHostedConfig', :'google' => :'IdentityProviderServiceGoogleConfig', :'jwt' => :'IdentityProviderServiceJWTConfig', :'ldap' => :'IdentityProviderServiceLDAPConfig', :'oauth' => :'IdentityProviderServiceOAuthConfig', :'oidc' => :'IdentityProviderServiceGenericOIDCConfig', :'saml' => :'IdentityProviderServiceSAMLConfig' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/zitadel/client/models/identity_provider_service_i_d_p_config.rb', line 171 def ==(o) return true if self.equal?(o) self.class == o.class && == o. && apple == o.apple && azure_ad == o.azure_ad && github == o.github && github_es == o.github_es && gitlab == o.gitlab && gitlab_self_hosted == o.gitlab_self_hosted && google == o.google && jwt == o.jwt && ldap == o.ldap && oauth == o.oauth && oidc == o.oidc && saml == o.saml end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
307 308 309 310 311 312 313 314 315 316 317 318 319 |
# File 'lib/zitadel/client/models/identity_provider_service_i_d_p_config.rb', line 307 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
191 192 193 |
# File 'lib/zitadel/client/models/identity_provider_service_i_d_p_config.rb', line 191 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
197 198 199 |
# File 'lib/zitadel/client/models/identity_provider_service_i_d_p_config.rb', line 197 def hash [, apple, azure_ad, github, github_es, gitlab, gitlab_self_hosted, google, jwt, ldap, oauth, oidc, saml].hash end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
283 284 285 |
# File 'lib/zitadel/client/models/identity_provider_service_i_d_p_config.rb', line 283 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
289 290 291 292 293 294 295 296 297 298 299 300 301 |
# File 'lib/zitadel/client/models/identity_provider_service_i_d_p_config.rb', line 289 def to_hash hash = {} # Calls super.to_hash if parent exists self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
277 278 279 |
# File 'lib/zitadel/client/models/identity_provider_service_i_d_p_config.rb', line 277 def to_s to_hash.to_s end |