Class: Zitadel::Client::Models::IdentityProviderServiceLDAPConfig
- Inherits:
-
Object
- Object
- Zitadel::Client::Models::IdentityProviderServiceLDAPConfig
- Defined in:
- lib/zitadel/client/models/identity_provider_service_l_d_a_p_config.rb
Instance Attribute Summary collapse
-
#attributes ⇒ Object
Returns the value of attribute attributes.
-
#base_dn ⇒ Object
Returns the value of attribute base_dn.
-
#bind_dn ⇒ Object
Returns the value of attribute bind_dn.
-
#root_ca ⇒ Object
Returns the value of attribute root_ca.
-
#servers ⇒ Object
Returns the value of attribute servers.
-
#start_tls ⇒ Object
Returns the value of attribute start_tls.
-
#timeout ⇒ Object
A Duration represents a signed, fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
-
#user_base ⇒ Object
Returns the value of attribute user_base.
-
#user_filters ⇒ Object
Returns the value of attribute user_filters.
-
#user_object_classes ⇒ Object
Returns the value of attribute user_object_classes.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ IdentityProviderServiceLDAPConfig
constructor
Initializes the object.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ IdentityProviderServiceLDAPConfig
Initializes the object
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/zitadel/client/models/identity_provider_service_l_d_a_p_config.rb', line 89 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) # MODIFIED: Updated class name in error message fail ArgumentError, "The input argument (attributes) must be a hash in `Zitadel::Client::Models::IdentityProviderServiceLDAPConfig` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) # MODIFIED: Updated class name in error message fail ArgumentError, "`#{k}` is not a valid attribute in `Zitadel::Client::Models::IdentityProviderServiceLDAPConfig`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'servers') if (value = attributes[:'servers']).is_a?(Array) self.servers = value end end if attributes.key?(:'start_tls') self.start_tls = attributes[:'start_tls'] end if attributes.key?(:'base_dn') self.base_dn = attributes[:'base_dn'] end if attributes.key?(:'bind_dn') self.bind_dn = attributes[:'bind_dn'] end if attributes.key?(:'user_base') self.user_base = attributes[:'user_base'] end if attributes.key?(:'user_object_classes') if (value = attributes[:'user_object_classes']).is_a?(Array) self.user_object_classes = value end end if attributes.key?(:'user_filters') if (value = attributes[:'user_filters']).is_a?(Array) self.user_filters = value end end if attributes.key?(:'timeout') self.timeout = attributes[:'timeout'] end if attributes.key?(:'attributes') self.attributes = attributes[:'attributes'] end if attributes.key?(:'root_ca') self.root_ca = attributes[:'root_ca'] end end |
Instance Attribute Details
#attributes ⇒ Object
Returns the value of attribute attributes.
35 36 37 |
# File 'lib/zitadel/client/models/identity_provider_service_l_d_a_p_config.rb', line 35 def attributes @attributes end |
#base_dn ⇒ Object
Returns the value of attribute base_dn.
22 23 24 |
# File 'lib/zitadel/client/models/identity_provider_service_l_d_a_p_config.rb', line 22 def base_dn @base_dn end |
#bind_dn ⇒ Object
Returns the value of attribute bind_dn.
24 25 26 |
# File 'lib/zitadel/client/models/identity_provider_service_l_d_a_p_config.rb', line 24 def bind_dn @bind_dn end |
#root_ca ⇒ Object
Returns the value of attribute root_ca.
37 38 39 |
# File 'lib/zitadel/client/models/identity_provider_service_l_d_a_p_config.rb', line 37 def root_ca @root_ca end |
#servers ⇒ Object
Returns the value of attribute servers.
18 19 20 |
# File 'lib/zitadel/client/models/identity_provider_service_l_d_a_p_config.rb', line 18 def servers @servers end |
#start_tls ⇒ Object
Returns the value of attribute start_tls.
20 21 22 |
# File 'lib/zitadel/client/models/identity_provider_service_l_d_a_p_config.rb', line 20 def start_tls @start_tls end |
#timeout ⇒ Object
A Duration represents a signed, fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". It is related to Timestamp in that the difference between two Timestamp values is a Duration and it can be added or subtracted from a Timestamp. Range is approximately -10,000 years. # Examples Example 1: Compute Duration from two Timestamps in pseudo code. Timestamp start = …; Timestamp end = …; Duration duration = …; duration.seconds = end.seconds - start.seconds; duration.nanos = end.nanos - start.nanos; if (duration.seconds < 0 && duration.nanos > 0) { duration.seconds = 1; duration.nanos -= 1000000000; } else if (duration.seconds > 0 && duration.nanos < 0) { duration.seconds -= 1; duration.nanos = 1000000000; } Example 2: Compute Timestamp from Timestamp Duration in pseudo code. Timestamp start = …; Duration duration = …; Timestamp end = …; end.seconds = start.seconds + duration.seconds; end.nanos = start.nanos + duration.nanos; if (end.nanos < 0) { end.seconds -= 1; end.nanos = 1000000000; } else if (end.nanos >= 1000000000) { end.seconds = 1; end.nanos -= 1000000000; } Example 3: Compute Duration from datetime.timedelta in Python. td = datetime.timedelta(days=3, minutes=10) duration = Duration() duration.FromTimedelta(td) # JSON Mapping In JSON format, the Duration type is encoded as a string rather than an object, where the string ends in the suffix "s" (indicating seconds) and is preceded by the number of seconds, with nanoseconds expressed as fractional seconds. For example, 3 seconds with 0 nanoseconds should be encoded in JSON format as "3s", while 3 seconds and 1 nanosecond should be expressed in JSON format as "3.000000001s", and 3 seconds and 1 microsecond should be expressed in JSON format as "3.000001s".
33 34 35 |
# File 'lib/zitadel/client/models/identity_provider_service_l_d_a_p_config.rb', line 33 def timeout @timeout end |
#user_base ⇒ Object
Returns the value of attribute user_base.
26 27 28 |
# File 'lib/zitadel/client/models/identity_provider_service_l_d_a_p_config.rb', line 26 def user_base @user_base end |
#user_filters ⇒ Object
Returns the value of attribute user_filters.
30 31 32 |
# File 'lib/zitadel/client/models/identity_provider_service_l_d_a_p_config.rb', line 30 def user_filters @user_filters end |
#user_object_classes ⇒ Object
Returns the value of attribute user_object_classes.
28 29 30 |
# File 'lib/zitadel/client/models/identity_provider_service_l_d_a_p_config.rb', line 28 def user_object_classes @user_object_classes end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 |
# File 'lib/zitadel/client/models/identity_provider_service_l_d_a_p_config.rb', line 208 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf/anyOf constructs that resolve to a model name # MODIFIED: Ensure model is looked up in the Models namespace # 'type' here is expected to be the simple class name (e.g., "User", "OrderDetails") klass = Zitadel::Client::Models.const_get(type) # The `klass.build` method is for oneOf/anyOf types (defined in partial_oneof_module.mustache / partial_anyof_module.mustache) # The `klass.build_from_hash` is for regular model types (defined in this base_object.mustache itself) if klass.respond_to?(:openapi_one_of) || klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_allOf) klass.build(value) # For oneOf/anyOf/allOf, delegate to their specific build method else klass.build_from_hash(value) # For regular models end end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
56 57 58 |
# File 'lib/zitadel/client/models/identity_provider_service_l_d_a_p_config.rb', line 56 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
61 62 63 |
# File 'lib/zitadel/client/models/identity_provider_service_l_d_a_p_config.rb', line 61 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
40 41 42 43 44 45 46 47 48 49 50 51 52 53 |
# File 'lib/zitadel/client/models/identity_provider_service_l_d_a_p_config.rb', line 40 def self.attribute_map { :'servers' => :'servers', :'start_tls' => :'startTls', :'base_dn' => :'baseDn', :'bind_dn' => :'bindDn', :'user_base' => :'userBase', :'user_object_classes' => :'userObjectClasses', :'user_filters' => :'userFilters', :'timeout' => :'timeout', :'attributes' => :'attributes', :'root_ca' => :'rootCa' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'lib/zitadel/client/models/identity_provider_service_l_d_a_p_config.rb', line 184 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) # `new` will call the initialize method of the specific model class. end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
82 83 84 85 |
# File 'lib/zitadel/client/models/identity_provider_service_l_d_a_p_config.rb', line 82 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/zitadel/client/models/identity_provider_service_l_d_a_p_config.rb', line 66 def self.openapi_types { :'servers' => :'Array<String>', :'start_tls' => :'Boolean', :'base_dn' => :'String', :'bind_dn' => :'String', :'user_base' => :'String', :'user_object_classes' => :'Array<String>', :'user_filters' => :'Array<String>', :'timeout' => :'String', :'attributes' => :'IdentityProviderServiceLDAPAttributes', :'root_ca' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/zitadel/client/models/identity_provider_service_l_d_a_p_config.rb', line 154 def ==(o) return true if self.equal?(o) self.class == o.class && servers == o.servers && start_tls == o.start_tls && base_dn == o.base_dn && bind_dn == o.bind_dn && user_base == o.user_base && user_object_classes == o.user_object_classes && user_filters == o.user_filters && timeout == o.timeout && attributes == o.attributes && root_ca == o.root_ca end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
287 288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'lib/zitadel/client/models/identity_provider_service_l_d_a_p_config.rb', line 287 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
171 172 173 |
# File 'lib/zitadel/client/models/identity_provider_service_l_d_a_p_config.rb', line 171 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
177 178 179 |
# File 'lib/zitadel/client/models/identity_provider_service_l_d_a_p_config.rb', line 177 def hash [servers, start_tls, base_dn, bind_dn, user_base, user_object_classes, user_filters, timeout, attributes, root_ca].hash end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
263 264 265 |
# File 'lib/zitadel/client/models/identity_provider_service_l_d_a_p_config.rb', line 263 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
269 270 271 272 273 274 275 276 277 278 279 280 281 |
# File 'lib/zitadel/client/models/identity_provider_service_l_d_a_p_config.rb', line 269 def to_hash hash = {} # Calls super.to_hash if parent exists self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
257 258 259 |
# File 'lib/zitadel/client/models/identity_provider_service_l_d_a_p_config.rb', line 257 def to_s to_hash.to_s end |