Class: Zitadel::Client::Models::IdentityProviderServiceSAMLConfig
- Inherits:
-
Object
- Object
- Zitadel::Client::Models::IdentityProviderServiceSAMLConfig
- Defined in:
- lib/zitadel/client/models/identity_provider_service_s_a_m_l_config.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#binding ⇒ Object
Returns the value of attribute binding.
-
#federated_logout_enabled ⇒ Object
Boolean weather federated logout is enabled.
-
#metadata_xml ⇒ Object
Metadata of the SAML identity provider.
-
#name_id_format ⇒ Object
Returns the value of attribute name_id_format.
-
#signature_algorithm ⇒ Object
Returns the value of attribute signature_algorithm.
-
#transient_mapping_attribute_name ⇒ Object
Optional name of the attribute, which will be used to map the user in case the nameid-format returned is ‘urn:oasis:names:tc:SAML:2.0:nameid-format:transient`.
-
#with_signed_request ⇒ Object
Boolean which defines if the authentication requests are signed.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ IdentityProviderServiceSAMLConfig
constructor
Initializes the object.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ IdentityProviderServiceSAMLConfig
Initializes the object
104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/zitadel/client/models/identity_provider_service_s_a_m_l_config.rb', line 104 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) # MODIFIED: Updated class name in error message fail ArgumentError, "The input argument (attributes) must be a hash in `Zitadel::Client::Models::IdentityProviderServiceSAMLConfig` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) # MODIFIED: Updated class name in error message fail ArgumentError, "`#{k}` is not a valid attribute in `Zitadel::Client::Models::IdentityProviderServiceSAMLConfig`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'metadata_xml') self. = attributes[:'metadata_xml'] end if attributes.key?(:'binding') self.binding = attributes[:'binding'] end if attributes.key?(:'with_signed_request') self.with_signed_request = attributes[:'with_signed_request'] end if attributes.key?(:'name_id_format') self.name_id_format = attributes[:'name_id_format'] end if attributes.key?(:'transient_mapping_attribute_name') self.transient_mapping_attribute_name = attributes[:'transient_mapping_attribute_name'] end if attributes.key?(:'federated_logout_enabled') self.federated_logout_enabled = attributes[:'federated_logout_enabled'] end if attributes.key?(:'signature_algorithm') self.signature_algorithm = attributes[:'signature_algorithm'] end end |
Instance Attribute Details
#binding ⇒ Object
Returns the value of attribute binding.
21 22 23 |
# File 'lib/zitadel/client/models/identity_provider_service_s_a_m_l_config.rb', line 21 def binding @binding end |
#federated_logout_enabled ⇒ Object
Boolean weather federated logout is enabled. If enabled, ZITADEL will send a logout request to the identity provider, if the user terminates the session in ZITADEL. Be sure to provide a SLO endpoint as part of the metadata.
32 33 34 |
# File 'lib/zitadel/client/models/identity_provider_service_s_a_m_l_config.rb', line 32 def federated_logout_enabled @federated_logout_enabled end |
#metadata_xml ⇒ Object
Metadata of the SAML identity provider.
19 20 21 |
# File 'lib/zitadel/client/models/identity_provider_service_s_a_m_l_config.rb', line 19 def @metadata_xml end |
#name_id_format ⇒ Object
Returns the value of attribute name_id_format.
26 27 28 |
# File 'lib/zitadel/client/models/identity_provider_service_s_a_m_l_config.rb', line 26 def name_id_format @name_id_format end |
#signature_algorithm ⇒ Object
Returns the value of attribute signature_algorithm.
34 35 36 |
# File 'lib/zitadel/client/models/identity_provider_service_s_a_m_l_config.rb', line 34 def signature_algorithm @signature_algorithm end |
#transient_mapping_attribute_name ⇒ Object
Optional name of the attribute, which will be used to map the user in case the nameid-format returned is ‘urn:oasis:names:tc:SAML:2.0:nameid-format:transient`.
29 30 31 |
# File 'lib/zitadel/client/models/identity_provider_service_s_a_m_l_config.rb', line 29 def transient_mapping_attribute_name @transient_mapping_attribute_name end |
#with_signed_request ⇒ Object
Boolean which defines if the authentication requests are signed.
24 25 26 |
# File 'lib/zitadel/client/models/identity_provider_service_s_a_m_l_config.rb', line 24 def with_signed_request @with_signed_request end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/zitadel/client/models/identity_provider_service_s_a_m_l_config.rb', line 202 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf/anyOf constructs that resolve to a model name # MODIFIED: Ensure model is looked up in the Models namespace # 'type' here is expected to be the simple class name (e.g., "User", "OrderDetails") klass = Zitadel::Client::Models.const_get(type) # The `klass.build` method is for oneOf/anyOf types (defined in partial_oneof_module.mustache / partial_anyof_module.mustache) # The `klass.build_from_hash` is for regular model types (defined in this base_object.mustache itself) if klass.respond_to?(:openapi_one_of) || klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_allOf) klass.build(value) # For oneOf/anyOf/allOf, delegate to their specific build method else klass.build_from_hash(value) # For regular models end end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
72 73 74 |
# File 'lib/zitadel/client/models/identity_provider_service_s_a_m_l_config.rb', line 72 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
77 78 79 |
# File 'lib/zitadel/client/models/identity_provider_service_s_a_m_l_config.rb', line 77 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/zitadel/client/models/identity_provider_service_s_a_m_l_config.rb', line 59 def self.attribute_map { :'metadata_xml' => :'metadataXml', :'binding' => :'binding', :'with_signed_request' => :'withSignedRequest', :'name_id_format' => :'nameIdFormat', :'transient_mapping_attribute_name' => :'transientMappingAttributeName', :'federated_logout_enabled' => :'federatedLogoutEnabled', :'signature_algorithm' => :'signatureAlgorithm' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'lib/zitadel/client/models/identity_provider_service_s_a_m_l_config.rb', line 178 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) # `new` will call the initialize method of the specific model class. end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
95 96 97 98 99 100 |
# File 'lib/zitadel/client/models/identity_provider_service_s_a_m_l_config.rb', line 95 def self.openapi_nullable Set.new([ :'transient_mapping_attribute_name', :'federated_logout_enabled', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/zitadel/client/models/identity_provider_service_s_a_m_l_config.rb', line 82 def self.openapi_types { :'metadata_xml' => :'String', :'binding' => :'IdentityProviderServiceSAMLBinding', :'with_signed_request' => :'Boolean', :'name_id_format' => :'IdentityProviderServiceSAMLNameIDFormat', :'transient_mapping_attribute_name' => :'String', :'federated_logout_enabled' => :'Boolean', :'signature_algorithm' => :'IdentityProviderServiceSAMLSignatureAlgorithm' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/zitadel/client/models/identity_provider_service_s_a_m_l_config.rb', line 151 def ==(o) return true if self.equal?(o) self.class == o.class && == o. && binding == o.binding && with_signed_request == o.with_signed_request && name_id_format == o.name_id_format && transient_mapping_attribute_name == o.transient_mapping_attribute_name && federated_logout_enabled == o.federated_logout_enabled && signature_algorithm == o.signature_algorithm end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
281 282 283 284 285 286 287 288 289 290 291 292 293 |
# File 'lib/zitadel/client/models/identity_provider_service_s_a_m_l_config.rb', line 281 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
165 166 167 |
# File 'lib/zitadel/client/models/identity_provider_service_s_a_m_l_config.rb', line 165 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
171 172 173 |
# File 'lib/zitadel/client/models/identity_provider_service_s_a_m_l_config.rb', line 171 def hash [, binding, with_signed_request, name_id_format, transient_mapping_attribute_name, federated_logout_enabled, signature_algorithm].hash end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
257 258 259 |
# File 'lib/zitadel/client/models/identity_provider_service_s_a_m_l_config.rb', line 257 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/zitadel/client/models/identity_provider_service_s_a_m_l_config.rb', line 263 def to_hash hash = {} # Calls super.to_hash if parent exists self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
251 252 253 |
# File 'lib/zitadel/client/models/identity_provider_service_s_a_m_l_config.rb', line 251 def to_s to_hash.to_s end |